@@ -20,15 +20,15 @@
 */
 
 #include <QCheckBox>
-#include <Qt3Support/Q3GroupBox>
-#include <QLayout>
 #include <QPushButton>
 
+
 //Added by qt3to4:
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QGridLayout>
 #include <QBoxLayout>
+#include <QGroupBox>
 
 #include <kcmodule.h>
 #include <kaboutdata.h>
@@ -63,7 +63,7 @@ extern "C"
 
     XGetKeyboardControl(QX11Info::display(), &kbd);
 
-    KConfig _config( "kcmbellrc", KConfig::CascadeConfig  );
+    KConfig _config( "kcmbellrc", KConfig::NoGlobals  );
     KConfigGroup config(&_config, "General");
 
     kbdc.bell_percent = config.readEntry("Volume", kbd.bell_percent);
@@ -83,8 +83,8 @@ KBellConfig::KBellConfig(QWidget *parent, const QVariantList &args):
   layout->setSpacing(KDialog::spacingHint());
 
   int row = 0;
-  Q3GroupBox *box = new Q3GroupBox( i18n("Bell Settings"), this );
-  box->setColumnLayout( 0, Qt::Horizontal );
+  QGroupBox *box = new QGroupBox(i18n("Bell Settings"), this );
+  new QVBoxLayout( box );
   layout->addWidget(box);
   layout->addStretch();
   QGridLayout *grid = new QGridLayout();
@@ -117,7 +117,7 @@ KBellConfig::KBellConfig(QWidget *parent, const QVariantList &args):
   m_volume->setWhatsThis( i18n("Here you can customize the volume of the system bell. For further"
     " customization of the bell, see the \"Accessibility\" control module.") );
 
-  m_pitch = new KIntNumInput(m_volume, 800, box);
+  m_pitch = new KIntNumInput(800, box);
   m_pitch->setLabel(i18n("&Pitch:"));
   m_pitch->setRange(20, 2000, 20);
   m_pitch->setSuffix(i18n(" Hz"));
@@ -126,7 +126,7 @@ KBellConfig::KBellConfig(QWidget *parent, const QVariantList &args):
   m_pitch->setWhatsThis( i18n("Here you can customize the pitch of the system bell. For further"
     " customization of the bell, see the \"Accessibility\" control module.") );
 
-  m_duration = new KIntNumInput(m_pitch, 100, box);
+  m_duration = new KIntNumInput(100, box);
   m_duration->setLabel(i18n("&Duration:"));
   m_duration->setRange(1, 1000, 50);
   m_duration->setSuffix(i18n(" msec"));
@@ -171,7 +171,7 @@ void KBellConfig::load()
   m_pitch->setValue(kbd.bell_pitch);
   m_duration->setValue(kbd.bell_duration);
 
-  KConfig _cfg("kdeglobals", KConfig::CascadeConfig);
+  KConfig _cfg("kdeglobals", KConfig::NoGlobals);
   KConfigGroup cfg(&_cfg, "General");
   m_useBell->setChecked(cfg.readEntry("UseSystemBell", false));
   useBell(m_useBell->isChecked());
@@ -192,7 +192,7 @@ void KBellConfig::save()
                          KBBellPercent | KBBellPitch | KBBellDuration,
                          &kbd);
 
-  KConfig _config("kcmbellrc", KConfig::CascadeConfig);
+  KConfig _config("kcmbellrc", KConfig::NoGlobals);
   KConfigGroup config(&_config, "General");
   config.writeEntry("Volume",bellVolume);
   config.writeEntry("Pitch",bellPitch);
@@ -200,7 +200,7 @@ void KBellConfig::save()
 
   config.sync();
 
-  KConfig _cfg("kdeglobals", KConfig::CascadeConfig);
+  KConfig _cfg("kdeglobals", KConfig::NoGlobals);
   KConfigGroup cfg(&_cfg, "General");
   cfg.writeEntry("UseSystemBell", m_useBell->isChecked());
   cfg.sync();
