@@ -5,9 +5,10 @@
  *
  * ----
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License version 2 as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,16 +22,17 @@
  */
 
 #include "FcEngine.h"
-#include <QCoreApplication>
-#include <QTextStream>
-#include <QPainter>
-#include <QFontDatabase>
-#include <QWidget>
-#include <QFile>
-#include <kprinter.h>
-#include <kcmdlineargs.h>
-#include <kaboutdata.h>
-#include <kapplication.h>
+#include <QtCore/QCoreApplication>
+#include <QtCore/QTextStream>
+#include <QtGui/QPainter>
+#include <QtGui/QFontDatabase>
+#include <QtGui/QWidget>
+#include <QtCore/QFile>
+#include <QtGui/QPrinter>
+#include <QtGui/QPrintDialog>
+#include <KDE/KCmdLineArgs>
+#include <KDE/KAboutData>
+#include <KDE/KApplication>
 #ifdef HAVE_LOCALE_H
 #include <locale.h>
 #endif
@@ -88,11 +90,12 @@ static void printItems(const QList<Misc::TFont> &items, int size, QWidget *paren
             appFont[(*it).family]=-1;
     }
 #endif
-    KPrinter printer;
+    QPrinter     printer;
+    QPrintDialog dialog(&printer, parent);
 
-    printer.setFullPage(true);
+    dialog.setWindowTitle(i18n("Print"));
 
-    if(printer.setup(parent))
+    if(dialog.exec())
     {
         QPainter   painter;
         QFont      sans("sans", 12, QFont::Bold);
