@@ -5,9 +5,10 @@
  *
  * ----
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License version 2 as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,28 +26,28 @@
 #include "Fc.h"
 #include "JobRunner.h"
 #include "FontList.h"
-#include <kglobal.h>
-#include <kiconloader.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kdesu/su.h>
-#include <kfileitem.h>
-#include <kpropertiesdialog.h>
-#include <kshell.h>
-#include <QLabel>
-#include <QTimer>
-#include <QGridLayout>
-#include <QDir>
-#include <QFileInfoList>
-#include <QFileInfo>
-#include <QHeaderView>
-#include <QDateTime>
-#include <QMenu>
-#include <QContextMenuEvent>
-#include <QAction>
-#include <QApplication>
-#include <QDesktopWidget>
-#include <QProcess>
+#include <KDE/KGlobal>
+#include <KDE/KIconLoader>
+#include <KDE/KLocale>
+#include <KDE/KMessageBox>
+#include <KDE/SuProcess>
+#include <KDE/KFileItem>
+#include <KDE/KPropertiesDialog>
+#include <KDE/KShell>
+#include <QtGui/QLabel>
+#include <QtCore/QTimer>
+#include <QtGui/QGridLayout>
+#include <QtCore/QDir>
+#include <QtCore/QFileInfoList>
+#include <QtCore/QFileInfo>
+#include <QtGui/QHeaderView>
+#include <QtCore/QDateTime>
+#include <QtGui/QMenu>
+#include <QtGui/QContextMenuEvent>
+#include <QtGui/QAction>
+#include <QtGui/QApplication>
+#include <QtGui/QDesktopWidget>
+#include <QtCore/QProcess>
 
 using namespace KDESu;
 
@@ -160,7 +161,7 @@ void CDuplicatesDialog::scanFinished()
                 }
                 top->setExpanded(true);
                 top->setData(COL_FILE, Qt::DecorationRole,
-                             QVariant(SmallIcon(t1>tt ? "font-type1" : "font-truetype")));
+                             QVariant(SmallIcon(t1>tt ? "application-x-font-type1" : "application-x-font-ttf")));
                 top->setFont(COL_FILE, boldFont);
             }
             itsView->setSortingEnabled(true);
@@ -511,7 +512,7 @@ CFontFileListView::CFontFileListView(QWidget *parent)
     headers.append(i18n("Date"));
     headers.append(i18n("Links To"));
     setHeaderLabels(headers);
-    headerItem()->setData(COL_TRASH, Qt::DecorationRole, QVariant(SmallIcon("edit-trash")));
+    headerItem()->setData(COL_TRASH, Qt::DecorationRole, QVariant(SmallIcon("user-trash")));
     setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
     setSelectionMode(ExtendedSelection);
     sortByColumn(COL_FILE, Qt::AscendingOrder);
