@@ -797,6 +797,7 @@ QVariant CFontList::headerData(int section, Qt::Orientation orientation,
                 if(COL_STATUS==section)
                     return i18n("This column shows the status of the font family, and of the "
                                 "individual font styles.");
+                break;
             case Qt::WhatsThisRole:
                 return whatsThis();
             default:
@@ -928,8 +929,8 @@ void CFontList::getFoundries(QSet<QString> &foundries) const
 QString CFontList::whatsThis() const
 {
     return i18n("<p>This list shows your installed fonts. The fonts are grouped by family, and the"
-                  " number in square brackets represents the number of styles that the family is "
-                  " avaiable in. e.g.</p>"
+                  " number in square brackets represents the number of styles that the family is"
+                  " available in. e.g.</p>"
                   "<ul>"
                     "<li>Times [4]"
                         "<ul><li>Regular</li>"
