@@ -5,9 +5,10 @@
  *
  * ----
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License version 2 as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -24,15 +25,16 @@
 #include "Fc.h"
 #include "Misc.h"
 #include "KfiConstants.h"
-#include <QDir>
-#include <QDomDocument>
-#include <QDomElement>
-#include <QDomNode>
-#include <QFile>
-#include <QTextStream>
-#include <klockfile.h>
-#include <ksavefile.h>
-#include <klocale.h>
+#include <QtCore/QDir>
+#include <QtXml/QDomDocument>
+#include <QtXml/QDomElement>
+#include <QtXml/QDomNode>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+#include <KDE/KLockFile>
+#include <KDE/KSaveFile>
+#include <KDE/KLocale>
+#include <KDE/KStandardDirs>
 #include <fontconfig/fontconfig.h>
 #include <stdio.h>
 
@@ -185,51 +187,30 @@ void CDisabledFonts::createWritingSystemMap()
                     ((qulonglong)1)<<theirLanguageForWritingSystem[i].ws;
 }
 
-CDisabledFonts::CDisabledFonts(const QString &path, bool sys)
+CDisabledFonts::CDisabledFonts(bool sys)
               : itsTimeStamp(0),
                 itsModified(false),
                 itsMods(0)
 {
-    QString p;
+    QString path;
 
     createWritingSystemMap();
 
-    if(path.isEmpty())
-    {
-        if(Misc::root() || sys)
-            p=KFI_ROOT_CFG_DIR;
-        else
-        {
-            FcStrList *list=FcConfigGetFontDirs(FcInitLoadConfig());
-            FcChar8   *dir;
-            QString   home(QDir::homePath()),
-                      defaultDir(home+"/.fonts");
-
-            while((dir=FcStrListNext(list)))
-            {
-                QString d((const char *)dir);
-
-                if(0==d.indexOf(home))
-                    if(d==defaultDir)
-                    {
-                        p=defaultDir;
-                        break;
-                    }
-                    else if(p.isEmpty())
-                        p=d;
-            }
-
-            if(p.isEmpty())
-                p=defaultDir;
-        }
-    }
+    if(Misc::root() || sys)
+        path=KFI_ROOT_CFG_DIR;
     else
-        p=path;
+    {
+        path=KGlobal::dirs()->localxdgconfdir();
 
-    itsFileName=p+'/'+FILE_NAME".xml";
+        if(!Misc::dExists(path))
+            Misc::createDir(path);
+    }
+
+    itsFileName=path+'/'+FILE_NAME".xml";
 
     itsModifiable=Misc::fWritable(itsFileName) ||
                   (!Misc::fExists(itsFileName) && Misc::dWritable(Misc::getDir(itsFileName)));
+
     load();
     if(itsModified)
         save();
