@@ -5,9 +5,10 @@
  *
  * ----
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License version 2 as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -22,18 +23,18 @@
 
 #include "FcEngine.h"
 
-#include <QPainter>
-#include <QPixmap>
-#include <QFile>
-#include <QTextStream>
-#include <QX11Info>
-#include <kurl.h>
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <kglobalsettings.h>
-#include <kio/netaccess.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <QtGui/QPainter>
+#include <QtGui/QPixmap>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+#include <QtGui/QX11Info>
+#include <KDE/KUrl>
+#include <KDE/KConfig>
+#include <KDE/KConfigGroup>
+#include <KDE/KGlobalSettings>
+#include <KDE/KIO/NetAccess>
+#include <KDE/KGlobal>
+#include <KDE/KLocale>
 #include <math.h>
 #include <X11/Xlib.h>
 #include <X11/Xft/Xft.h>
@@ -504,10 +505,10 @@ bool CFcEngine::drawPreview(const QString &item, QPixmap &pix, int h, quint32 st
                                             text.length());
                             if(needResize)
                                 pix=pix.scaledToHeight(h);
-                            pix.resize(extents.width+(2*constOffset)<constInitialWidth
-                                           ? extents.width+(2*constOffset)
-                                           : constInitialWidth,
-                                       h);
+                            pix = pix.copy(0, 0, extents.width+(2*constOffset)<constInitialWidth
+                                                    ? extents.width+(2*constOffset)
+                                                    : constInitialWidth,
+                                           h);
                             rv=true;
                         }
                         else
@@ -535,10 +536,10 @@ bool CFcEngine::drawPreview(const QString &item, QPixmap &pix, int h, quint32 st
                                 }
                                 if(needResize)
                                     pix=pix.scaledToHeight(h);
-                                pix.resize(x+constOffset<constInitialWidth
-                                               ? x+constOffset
-                                               : constInitialWidth,
-                                           h);
+                                pix = pix.copy(0, 0, x+constOffset<constInitialWidth
+                                                        ? x+constOffset
+                                                        : constInitialWidth,
+                                               h);
                                 XftUnlockFace(xftFont);
                                 rv=true;
                             }
@@ -934,7 +935,7 @@ QFont CFcEngine::getQFont(const QString &family, quint32 style, int size)
 bool CFcEngine::parseUrl(const KUrl &url, int faceNo)
 {
 #ifdef KFI_FC_DEBUG
-    kDebug() << "parseUrl(" << url.prettyUrl() << ", " << faceNo << ")";
+    kDebug() << url.prettyUrl() << ' ' << faceNo;
 #endif
     if(faceNo<0)
         faceNo=0;
@@ -944,7 +945,6 @@ bool CFcEngine::parseUrl(const KUrl &url, int faceNo)
 
     reinit();
 
-    //kDebug() << "parseUrl:" << url.prettyUrl();
     // Possible urls:
     //
     //    fonts:/times.ttf
@@ -967,11 +967,11 @@ bool CFcEngine::parseUrl(const KUrl &url, int faceNo)
                                           KFI_KIO_FACE, 0);
 #ifdef KFI_FC_DEBUG
             kDebug() << "Stated fonts:/ url, name:" << name << " itsFileName:" << itsFileName
-                         << " style:" << style << " itsIndex:" << itsIndex;
+                     << " style:" << style << " itsIndex:" << itsIndex;
 #endif
         }
 #ifdef KFI_FC_DEBUG
-kDebug() << "isHidden:" << hidden;
+        kDebug() << "isHidden:" << hidden;
 #endif
         if(hidden)
             name=itsFileName;
@@ -1149,7 +1149,7 @@ XftFont * CFcEngine::queryFont()
     static const int constQuerySize=8;
 
 #ifdef KFI_FC_DEBUG
-    kDebug() << "queryFont";
+    kDebug();
 #endif
 
     XftFont *f=getFont(constQuerySize);
@@ -1177,7 +1177,7 @@ XftFont * CFcEngine::queryFont()
         }
     }
 #ifdef KFI_FC_DEBUG
-    kDebug() << "queryFont - ret" << (int)f;
+    kDebug() << "ret" << (int)f;
 #endif
     return f;
 }
@@ -1187,7 +1187,7 @@ XftFont * CFcEngine::getFont(int size)
     XftFont *f=NULL;
 
 #ifdef KFI_FC_DEBUG
-    kDebug() << "getFont:" << QString(itsInstalled ? itsName : itsFileName) << ' ' << size;
+    kDebug() << QString(itsInstalled ? itsName : itsFileName) << ' ' << size;
 #endif
 
     if(itsInstalled)
@@ -1222,7 +1222,7 @@ XftFont * CFcEngine::getFont(int size)
     }
 
 #ifdef KFI_FC_DEBUG
-    kDebug() << "getFont, ret: " << (int)f;
+    kDebug() << "ret: " << (int)f;
 #endif
 
     return f;
@@ -1299,7 +1299,7 @@ bool CFcEngine::isCorrect(XftFont *f, bool checkFamily)
 void CFcEngine::getSizes()
 {
 #ifdef KFI_FC_DEBUG
-    kDebug() << "getSizes";
+    kDebug();
 #endif
 
     XftFont *f=queryFont();
@@ -1422,7 +1422,7 @@ void CFcEngine::getSizes()
     if(0==itsAlphaSize && itsSizes.count())
         itsAlphaSize=itsSizes[0];
 #ifdef KFI_FC_DEBUG
-    kDebug() << "getSizes, end";
+    kDebug() << "end";
 #endif
 }
 
