@@ -8,9 +8,10 @@
  *
  * ----
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License version 2 as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,11 +26,11 @@
 
 #include <config-workspace.h>
 
-#include <QVector>
-#include <QFont>
-#include <QColor>
-#include <kurl.h>
-#include <kdeversion.h>
+#include <QtCore/QVector>
+#include <QtCore/QRect>
+#include <QtGui/QFont>
+#include <QtGui/QColor>
+#include <KDE/KUrl>
 #include <fontconfig/fontconfig.h>
 #include "KfiConstants.h"
 #include "Misc.h"
