@@ -5,9 +5,10 @@
  *
  * ----
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License version 2 as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,12 +24,11 @@
 #include "FontPreview.h"
 #include "FcEngine.h"
 #include "CharTip.h"
-#include <kapplication.h>
-#include <klocale.h>
-#include <QPainter>
-#include <QPixmap>
-#include <QPaintEvent>
-#include <QMouseEvent>
+#include <KDE/KApplication>
+#include <KDE/KLocale>
+#include <QtGui/QPainter>
+#include <QtGui/QPaintEvent>
+#include <QtGui/QMouseEvent>
 #include <stdlib.h>
 
 namespace KFI
