@@ -5,9 +5,10 @@
  *
  * ----
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License version 2 as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,40 +26,37 @@
 #include "KfiConstants.h"
 #include "FcEngine.h"
 #include "PreviewSelectAction.h"
-#include <QGridLayout>
-#include <QBoxLayout>
-#include <QPushButton>
-#include <QFrame>
-#include <QFile>
-#include <QLabel>
-#include <QValidator>
-#include <QRegExp>
-#include <QTimer>
-#include <QApplication>
-#include <QGroupBox>
-#include <QProcess>
-#include <klocale.h>
-#include <kio/netaccess.h>
-#include <kio/job.h>
-#include <kio/jobuidelegate.h>
-#include <kglobal.h>
-#include <kcomponentdata.h>
-#include <kmessagebox.h>
-#include <knuminput.h>
-#include <kstandardaction.h>
-#include <kaction.h>
-#include <kinputdialog.h>
-#include <kdialog.h>
-#include <ktoolbarlabelaction.h>
-#include <kactioncollection.h>
-#include <kicon.h>
-#include <kmimetype.h>
-//#include <kfilemetainfo.h>
-#include <kzip.h>
-#include <ktempdir.h>
-#include <kstandarddirs.h>
-#include <KPluginFactory>
-#include <KPluginLoader>
+#include <QtGui/QGridLayout>
+#include <QtGui/QBoxLayout>
+#include <QtGui/QPushButton>
+#include <QtGui/QFrame>
+#include <QtCore/QFile>
+#include <QtGui/QLabel>
+#include <QtGui/QValidator>
+#include <QtCore/QRegExp>
+#include <QtCore/QTimer>
+#include <QtGui/QApplication>
+#include <QtGui/QGroupBox>
+#include <QtCore/QProcess>
+#include <KDE/KLocale>
+#include <KDE/KIO/NetAccess>
+#include <KDE/KIO/Job>
+#include <KDE/KIO/JobUiDelegate>
+#include <KDE/KGlobal>
+#include <KDE/KActionCollection>
+#include <KDE/KComponentData>
+#include <KDE/KMessageBox>
+#include <KDE/KIntNumInput>
+#include <KDE/KInputDialog>
+#include <KDE/KDialog>
+#include <KDE/KIcon>
+#include <KDE/KMimeType>
+//#include <KDE/KFileMetaInfo>
+#include <KDE/KZip>
+#include <KDE/KTempDir>
+#include <KDE/KStandardDirs>
+#include <KDE/KPluginFactory>
+#include <KDE/KPluginLoader>
 #include <fontconfig/fontconfig.h>
 
 // Enable the following to allow printing of non-installed fonts. Does not seem to work :-(
@@ -70,7 +68,7 @@ namespace KFI
 K_PLUGIN_FACTORY(CFontViewPartFactory, registerPlugin<CFontViewPart>();)
 K_EXPORT_PLUGIN(CFontViewPartFactory("kfontview"))
 
-CFontViewPart::CFontViewPart(QWidget *parentWidget, QObject *parent, const QList<QVariant> &args)
+CFontViewPart::CFontViewPart(QWidget *parentWidget, QObject *parent, const QList<QVariant> &)
              : KParts::ReadOnlyPart(parent),
                itsConfig(KGlobal::config()),
                itsProc(NULL),
@@ -121,6 +119,7 @@ CFontViewPart::CFontViewPart(QWidget *parentWidget, QObject *parent, const QList
     itsPreview->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
     itsFaceLabel=new QLabel(i18n("Show Face:"), itsFaceWidget);
     itsFaceSelector=new KIntNumInput(1, itsFaceWidget);
+    itsFaceSelector->setSliderEnabled(false);
     itsInstallButton=new QPushButton(i18n("Install..."), controls);
     itsInstallButton->setEnabled(false);
     previewLayout->addWidget(itsPreview);
@@ -141,12 +140,10 @@ CFontViewPart::CFontViewPart(QWidget *parentWidget, QObject *parent, const QList
     connect(itsFaceSelector, SIGNAL(valueChanged(int)), SLOT(showFace(int)));
 
     itsChangeTextAction=actionCollection()->addAction("changeText");
-    itsChangeTextAction->setIcon(KIcon("text"));
+    itsChangeTextAction->setIcon(KIcon("edit-rename"));
     itsChangeTextAction->setText(i18n("Change Text..."));
     connect(itsChangeTextAction, SIGNAL(triggered(bool)), SLOT(changeText()));
 
-    KToolBarLabelAction *toolbarLabelAction = new KToolBarLabelAction(i18n("Display:"), this);
-    actionCollection()->addAction("displayLabel", toolbarLabelAction);
     CPreviewSelectAction *displayTypeAction=new CPreviewSelectAction(this, CPreviewSelectAction::BlocksAndScripts);
     actionCollection()->addAction("displayType", displayTypeAction);
     connect(displayTypeAction, SIGNAL(range(const QList<CFcEngine::TRange> &)),
@@ -339,7 +336,7 @@ void CFontViewPart::timeout()
     if(!isFonts && CFcEngine::instance()->getNumIndexes()>1)
     {
         showFs=true;
-        itsFaceSelector->setRange(1, CFcEngine::instance()->getNumIndexes(), 1, false);
+        itsFaceSelector->setRange(1, CFcEngine::instance()->getNumIndexes(), 1);
         itsFaceSelector->blockSignals(true);
         itsFaceSelector->setValue(1);
         itsFaceSelector->blockSignals(false);
@@ -421,32 +418,39 @@ void CFontViewPart::changeText()
 
 void CFontViewPart::print()
 {
-    QStringList args;
+    QString exe(KStandardDirs::findExe(QLatin1String(KFI_PRINTER), KStandardDirs::installPath("libexec")));
 
-    if(KFI_KIO_FONTS_PROTOCOL==url().protocol())
-    {
-        Misc::TFont info;
-
-        CFcEngine::instance()->getInfo(url(), 0, info);
-
-        args << "--embed" << QString().sprintf("0x%x", (unsigned int)(itsFrame->topLevelWidget()->winId()))
-             << "--caption" << KGlobal::caption().toUtf8()
-             << "--icon" << "kfontview"
-             << "--size" << "0"
-             << "--pfont" << QString(info.family+','+QString().setNum(info.styleInfo));
-    }
-#ifdef KFI_PRINT_APP_FONTS
+    if(exe.isEmpty())
+        KMessageBox::error(itsFrame, i18n("Failed to locate font printer."));
     else
-        args << "--embed" << QString().sprintf("0x%x", (unsigned int)(itsFrame->topLevelWidget()->winId()))
-             << "--caption" << KGlobal::caption().toUtf8()
-             << "--icon" << "kfontview"
-             << "--size " << "0"
-             << localFilePath()
-             << QString().setNum(KFI_NO_STYLE_INFO);
+    {
+        QStringList args;
+
+        if(KFI_KIO_FONTS_PROTOCOL==url().protocol())
+        {
+            Misc::TFont info;
+
+            CFcEngine::instance()->getInfo(url(), 0, info);
+
+            args << "--embed" << QString().sprintf("0x%x", (unsigned int)(itsFrame->topLevelWidget()->winId()))
+                << "--caption" << KGlobal::caption().toUtf8()
+                << "--icon" << "kfontview"
+                << "--size" << "0"
+                << "--pfont" << QString(info.family+','+QString().setNum(info.styleInfo));
+        }
+#ifdef KFI_PRINT_APP_FONTS
+        else
+            args << "--embed" << QString().sprintf("0x%x", (unsigned int)(itsFrame->topLevelWidget()->winId()))
+                << "--caption" << KGlobal::caption().toUtf8()
+                << "--icon" << "kfontview"
+                << "--size " << "0"
+                << localFilePath()
+                << QString().setNum(KFI_NO_STYLE_INFO);
 #endif
 
-    if(args.count())
-        QProcess::startDetached(KFI_PRINTER, args);
+        if(args.count())
+            QProcess::startDetached(exe, args);
+    }
 }
 
 void CFontViewPart::displayType(const QList<CFcEngine::TRange> &range)
@@ -529,8 +533,7 @@ void CFontViewPart::stat(const QString &path)
     else
         statUrl=KUrl(path);
 
-    KIO::StatJob * job = KIO::stat(statUrl, 
-       statUrl.isLocalFile() ? KIO::HideProgressInfo : KIO::DefaultFlags);
+    KIO::StatJob * job = KIO::stat(statUrl, KIO::HideProgressInfo);
     job->ui()->setWindow(itsFrame->parentWidget());
     job->setSide(KIO::StatJob::SourceSide);
     connect(job, SIGNAL(result (KJob *)), this, SLOT(statResult(KJob *)));
