@@ -44,7 +44,8 @@ KxkbWidget::KxkbWidget(int controlType):
 void KxkbWidget::setCurrentLayout(const LayoutUnit& layoutUnit)
 {
 	setToolTip(m_descriptionMap[layoutUnit.toPair()]);
-	const QPixmap& icon = LayoutIcon::getInstance().findPixmap(layoutUnit.layout, m_showFlag, layoutUnit.displayName);
+	const QPixmap& icon = 
+            LayoutIcon::getInstance().findPixmap(layoutUnit.layout, m_showFlag, layoutUnit.getDisplayName());
 //	kDebug() << "setting pixmap: " << icon.width();
 	setPixmap( icon );
 	kDebug() << "setting text: " << layoutUnit.layout;
@@ -54,8 +55,8 @@ void KxkbWidget::setCurrentLayout(const LayoutUnit& layoutUnit)
 void KxkbWidget::setError(const QString& layoutInfo)
 {
     QString msg = i18n("Error changing keyboard layout to '%1'", layoutInfo);
-	setToolTip(msg);
-	setPixmap(LayoutIcon::getInstance().findPixmap("error", m_showFlag));
+    setToolTip(msg);
+    setPixmap(LayoutIcon::getInstance().findPixmap("error", false));
 }
 
 
@@ -74,22 +75,23 @@ void KxkbWidget::initLayoutList(const QList<LayoutUnit>& layouts, const XkbRules
 //    menu->addTitle( qApp->windowIcon(), KGlobal::caption() );
 //    menu->setTitle( KGlobal::mainComponent().aboutData()->programName() );
 
-	for(QList<QAction*>::Iterator it=m_actions.begin(); it != m_actions.end(); it++ )
-			menu->removeAction(*it);
-	m_actions.clear();
+    for(QList<QAction*>::Iterator it=m_actions.begin(); it != m_actions.end(); it++ )
+	menu->removeAction(*it);
+    m_actions.clear();
 	
-	int cnt = 0;
+    int cnt = 0;
     QList<LayoutUnit>::ConstIterator it;
     for (it=layouts.begin(); it != layouts.end(); ++it)
     {
 		const QString layoutName = (*it).layout;
 		const QString variantName = (*it).variant;
 
-		const QPixmap& layoutPixmap = LayoutIcon::getInstance().findPixmap(layoutName, m_showFlag, (*it).displayName);
+		const QPixmap& layoutPixmap = 
+                    LayoutIcon::getInstance().findPixmap(layoutName, m_showFlag, (*it).getDisplayName());
 //         const QPixmap pix = iconeffect.apply(layoutPixmap, KIcon::Small, KIcon::DefaultState);
 
 		QString layoutString = rules.layouts()[layoutName];
-		QString fullName = i18n( layoutString.toLatin1().constData() );
+		QString fullName = layoutString;
 		if( variantName.isEmpty() == false )
 			fullName += " (" + variantName + ')';
 //		menu->insertItem(pix, fullName, START_MENU_ID + cnt, m_menuStartIndex + cnt);
@@ -103,7 +105,7 @@ void KxkbWidget::initLayoutList(const QList<LayoutUnit>& layouts, const XkbRules
 
 		cnt++;
     }
-	menu->insertActions(m_configSeparator, m_actions);
+    menu->insertActions(m_configSeparator, m_actions);
 
 	// if show config, if show help
 //	if( menu->indexOf(CONFIG_MENU_ID) == -1 ) {
@@ -119,9 +121,9 @@ void KxkbWidget::initLayoutList(const QList<LayoutUnit>& layouts, const XkbRules
 		helpAction->setData(HELP_MENU_ID);
 		menu->addAction(helpAction);
 	}
-	else {
-	    kDebug() << "indicator with menu 'layouts only' requested";
-	}
+//	else {
+//	    kDebug() << "indicator with menu 'layouts only' requested";
+//	}
 
 //	menu->update();
 
@@ -155,44 +157,39 @@ void KxkbSysTrayIcon::trayActivated(QSystemTrayIcon::ActivationReason reason)
 
 void KxkbSysTrayIcon::setPixmap(const QPixmap& pixmap)
 {
-//	kDebug() << "setting icon to tray";
-	m_indicatorWidget->setIcon( pixmap );
-// 	if( ! m_indicatorWidget->isVisible() )
-		m_indicatorWidget->show();
+    m_indicatorWidget->setIcon( pixmap );
 }
 
 // ----------------------------
 
-void MyWidget::mousePressEvent ( QMouseEvent * event ) {
-	if (event->button() == Qt::LeftButton)
-		emit leftClick();
-	else
-		emit rightClick(event->pos());
-}
-
 KxkbLabel::KxkbLabel(int controlType, QWidget* parent):
 		KxkbWidget(controlType),
 		m_displayMode(ICON)
 {
-	m_indicatorWidget = new MyWidget(parent); 
-	m_menu = new QMenu(m_indicatorWidget);
-	
-	connect(m_indicatorWidget, SIGNAL(leftClick()), this, SIGNAL(iconToggled())); 
-	connect(m_indicatorWidget, SIGNAL(rightClick(const QPoint&)), this, SLOT(rightClick(const QPoint&))); 
-	connect(contextMenu(), SIGNAL(triggered(QAction*)), this, SIGNAL(menuTriggered(QAction*)));
-	show();
+    m_indicatorWidget = new QPushButton(parent);
+
+    m_indicatorWidget->setFlat(true);
+    m_indicatorWidget->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum));
+
+    connect( m_indicatorWidget, SIGNAL(clicked(bool)), this, SIGNAL(iconToggled()) );
+//    connect( m_indicatorWidget, SIGNAL(toggled(bool)), this, SIGNAL(iconToggled()) );
+
+    m_menu = new QMenu(m_indicatorWidget);
+    if( m_controlType >= KxkbWidget::MENU_LAYOUTS_ONLY ) {
+        m_indicatorWidget->setContextMenuPolicy(Qt::CustomContextMenu);
+        connect(m_indicatorWidget, SIGNAL(customContextMenuRequested(const QPoint &)), 
+                    this, SLOT(contextMenuEvent(const QPoint&)));
+    }
 }
 
-void KxkbLabel::rightClick(const QPoint& pos) {
-	QMenu* menu = contextMenu();
-	menu->exec(m_indicatorWidget->mapToGlobal(pos));
+void KxkbLabel::contextMenuEvent(const QPoint& pos)
+{
+    QMenu* menu = contextMenu();
+    menu->exec(pos);
 }
 
 void KxkbLabel::setPixmap(const QPixmap& pixmap)
 {
-	m_indicatorWidget->setIconSize(QSize(24,24));
-	m_indicatorWidget->setIcon( pixmap );
-
-	if( ! m_indicatorWidget->isVisible() )
-		m_indicatorWidget->show();
+    m_indicatorWidget->setIconSize(QSize(24,24));
+    m_indicatorWidget->setIcon( pixmap );
 }
