@@ -73,7 +73,7 @@ extern "C"
     KDE_EXPORT void kcminit_style()
     {
         uint flags = KRdbExportQtSettings | KRdbExportQtColors | KRdbExportXftSettings;
-        KConfig _config( "kcmdisplayrc", KConfig::CascadeConfig  );
+        KConfig _config( "kcmdisplayrc", KConfig::NoGlobals  );
         KConfigGroup config(&_config, "X11");
 
         // This key is written by the "colors" module.
@@ -494,6 +494,15 @@ void KCMStyle::styleSpecificConfig()
 	delete dial;
 }
 
+void KCMStyle::changeEvent( QEvent *event )
+{
+	KCModule::changeEvent( event );
+	if ( event->type() == QEvent::PaletteChange ) {
+		// Force re-rendering of the preview, to apply new palette
+		switchStyle(currentStyle(), true);
+	}
+}
+
 void KCMStyle::load()
 {
 	KConfig config( "kdeglobals", KConfig::FullConfig );
@@ -631,7 +640,7 @@ void KCMStyle::save()
 	if (m_bStyleDirty | m_bEffectsDirty)	// Export only if necessary
 	{
 		uint flags = KRdbExportQtSettings;
-		KConfig _kconfig( "kcmdisplayrc", KConfig::CascadeConfig  );
+		KConfig _kconfig( "kcmdisplayrc", KConfig::NoGlobals  );
 		KConfigGroup kconfig(&_kconfig, "X11");
 		bool exportKDEColors = kconfig.readEntry("exportKDEColors", true);
 		if (exportKDEColors)
@@ -658,16 +667,6 @@ void KCMStyle::save()
 #endif
 	}
 
-	//update kicker to re-used tooltips kicker parameter otherwise, it overwritted
-	//by style tooltips parameters.
-	QByteArray data;
-#ifdef __GNUC__
-#warning "kde4: who is org.kde.kicker?"
-#endif
-#ifdef Q_WS_X11
-	QDBusInterface kicker( "org.kde.kicker", "/kicker");
-	kicker.call("configure");
-#endif
 	// Clean up
 	m_bEffectsDirty  = false;
 	m_bToolbarsDirty = false;
@@ -704,11 +703,9 @@ void KCMStyle::defaults()
 	int item = 0;
 	bool found;
 
-	found = findStyle( "plastique", item ); //### KStyle::defaultStyle()
+	found = findStyle( KStyle::defaultStyle(), item );
 	if (!found)
-		found = findStyle( "highcolor", item );
-	if (!found)
-		found = findStyle( "default", item );
+		found = findStyle( "plastique", item );
 	if (!found)
 		found = findStyle( "windows", item );
 	if (!found)
@@ -835,7 +832,7 @@ void KCMStyle::loadStyle( KConfig& config )
 
 	// Find out which style is currently being used
 	KConfigGroup configGroup = config.group( "General" );
-	QString defaultStyle = "plastique"; //### KDE4: FIXME KStyle::defaultStyle();
+	QString defaultStyle = KStyle::defaultStyle();
 	QString cfgStyle = configGroup.readEntry( "widgetStyle", defaultStyle );
 
 	// Select the current style
@@ -1067,7 +1064,7 @@ void KCMStyle::loadMisc( KConfig& config )
 		comboToolbarIcons->setCurrentIndex(0);
 
 	configGroup = config.group("KDE");
-	cbIconsOnButtons->setChecked(configGroup.readEntry("ShowIconsOnPushButtons", false));
+	cbIconsOnButtons->setChecked(configGroup.readEntry("ShowIconsOnPushButtons", true));
 	cbEnableTooltips->setChecked(!configGroup.readEntry("EffectNoTooltip", false));
 	cbTearOffHandles->setChecked(configGroup.readEntry("InsertTearOffHandle", false));
 
