@@ -50,7 +50,9 @@ const char *td_setup = "auto";
 
 static void deleteXloginResources( void );
 static void loadXloginResources( void );
+static void resetXProperties( void );
 static void setupDisplay( const char *arg );
+static char **dupEnv( void );
 
 
 static Jmp_buf pingTime;
@@ -144,8 +146,11 @@ autoLogon( time_t tdiff )
 		td->hstent->nargs = 0;
 		reStr( &curtype, "classic" );
 		cursource = (td->hstent->rLogin == 1) ? PWSRC_RELOGIN : PWSRC_MANUAL;
-		return 1;
-	} else if (*td->autoUser && !td->autoDelay && (tdiff > 0 || td->autoAgain))
+		return True;
+	} else if (*td->autoUser && !td->autoDelay &&
+	           ((tdiff > 0 && ((td->displayType & d_lifetime) == dTransient ||
+	                           !td->hstent->lastExit)) ||
+	            td->autoAgain))
 	{
 		unsigned int lmask;
 		Window dummy1, dummy2;
@@ -154,22 +159,22 @@ autoLogon( time_t tdiff )
 		               &dummy1, &dummy2, &dummy3, &dummy4, &dummy5, &dummy6,
 		               &lmask );
 		if (lmask & ShiftMask)
-			return 0;
+			return False;
 		doAutoLogon();
-		return 1;
+		return True;
 	}
-	return 0;
+	return False;
 }
 
 
 static const struct {
   int vcode, echo, ndelay;
 } grqs[] = {
-	{ V_GET_TEXT, TRUE, FALSE },
-	{ V_GET_TEXT, FALSE, FALSE },
-	{ V_GET_TEXT, TRUE, FALSE },
-	{ V_GET_TEXT, FALSE, FALSE },
-	{ V_GET_TEXT, FALSE, TRUE },
+	{ V_GET_TEXT, True, False },
+	{ V_GET_TEXT, False, False },
+	{ V_GET_TEXT, True, False },
+	{ V_GET_TEXT, False, False },
+	{ V_GET_TEXT, False, True },
 	{ V_GET_BINARY, 0, 0 }
 };
 
@@ -184,7 +189,7 @@ conv_interact( int what, const char *prompt )
 		unsigned const char *up = (unsigned const char *)prompt;
 		int len = up[3] | (up[2] << 8) | (up[1] << 16) | (up[0] << 24);
 		gSendArr( len, prompt );
-		gSendInt( FALSE ); /* ndelay */
+		gSendInt( False ); /* ndelay */
 		return gRecvArr( &len );
 	} else {
 		gSendStr( prompt );
@@ -203,8 +208,7 @@ conv_interact( int what, const char *prompt )
 			case GCONV_PASS:
 			case GCONV_PASS_ND:
 				/* assert( tag & V_IS_PASSWORD );*/
-				if (curpass)
-					free( curpass );
+				wipeStr( curpass );
 				curpass = ret;
 				break;
 			default:
@@ -231,13 +235,14 @@ int
 ctrlGreeterWait( int wreply )
 {
 	int i, cmd, type, rootok;
-	char *name, *pass, **avptr;
+	char *name, *pass;
+	void **avptr;
 #ifdef XDMCP
 	ARRAY8Ptr aptr;
 #endif
 
 	if (Setjmp( mstrtalk.errjmp )) {
-		closeGreeter( TRUE );
+		closeGreeter( True );
 		sessionExit( EX_UNMANAGE_DPY );
 	}
 
@@ -290,11 +295,11 @@ ctrlGreeterWait( int wreply )
 				switch (type & C_TYPE_MASK) {
 				case C_TYPE_INT:
 					/*debug( " -> int %#x (%d)\n", *(int *)avptr, *(int *)avptr );*/
-					gSendInt( *(long *)avptr );
+					gSendInt( *(int *)avptr );
 					break;
 				case C_TYPE_STR:
 					/*debug( " -> string %\"s\n", *avptr );*/
-					gSendStr( *avptr );
+					gSendStr( *(char **)avptr );
 					break;
 				case C_TYPE_ARGV:
 					/*debug( " -> sending argv %\"[{s\n", *(char ***)avptr );*/
@@ -360,14 +365,14 @@ ctrlGreeterWait( int wreply )
 			break;
 		case G_VerifyRootOK:
 			debug( "G_VerifyRootOK\n" );
-			rootok = TRUE;
+			rootok = True;
 			goto doverify;
 		case G_Verify:
 			debug( "G_Verify\n" );
-			rootok = FALSE;
+			rootok = False;
 		  doverify:
 			if (curuser) { free( curuser ); curuser = 0; }
-			if (curpass) { free( curpass ); curpass = 0; }
+			wipeStr( curpass ); curpass = 0;
 			if (curtype) free( curtype );
 			curtype = gRecvStr();
 			debug( " type %\"s\n", curtype );
@@ -381,7 +386,7 @@ ctrlGreeterWait( int wreply )
 		case G_AutoLogin:
 			debug( "G_AutoLogin\n" );
 			doAutoLogon();
-			if (verify( conv_auto, FALSE )) {
+			if (verify( conv_auto, False )) {
 				debug( " -> return success\n" );
 				gSendInt( V_OK );
 			} else
@@ -430,13 +435,13 @@ openGreeter()
 	loadXloginResources();
 
 	grttalk.pipe = &grtproc.pipe;
-	env = systemEnv( (char *)0 );
+	env = systemEnv( dupEnv(), 0 );
 	if (gOpen( &grtproc, (char **)0, "_greet", env, name, &td->gpipe ))
 		sessionExit( EX_UNMANAGE_DPY );
 	freeStrArr( env );
-	if ((cmd = ctrlGreeterWait( TRUE ))) {
+	if ((cmd = ctrlGreeterWait( True ))) {
 		logError( "Received unknown or unexpected command %d from greeter\n", cmd );
-		closeGreeter( TRUE );
+		closeGreeter( True );
 		sessionExit( EX_UNMANAGE_DPY );
 	}
 	debug( "%s ready\n", name );
@@ -482,7 +487,7 @@ finishGreet()
 	if (grtproc.pid > 0) {
 		gSet( &grttalk );
 		gSendInt( V_OK );
-		if ((ret = closeGreeter( FALSE )) != EX_NORMAL) {
+		if ((ret = closeGreeter( False )) != EX_NORMAL) {
 			logError( "Abnormal greeter termination, code %d, sig %d\n",
 			          wcCode( ret ), wcSig( ret ) );
 			sessionExit( EX_RESERVER_DPY );
@@ -506,6 +511,7 @@ static Jmp_buf abortSession;
 static void
 catchTerm( int n ATTR_UNUSED )
 {
+	Signal( SIGTERM, SIG_IGN );
 	Longjmp( abortSession, EX_AL_RESERVER_DPY );
 }
 
@@ -545,11 +551,12 @@ manageSession( struct display *d )
 	int ex, cmd;
 	volatile int clientPid = -1;
 	volatile time_t tdiff = 0;
+	sigset_t ss;
 
 	td = d;
 	debug( "manageSession %s\n", d->name );
 	if ((ex = Setjmp( abortSession ))) {
-		closeGreeter( TRUE );
+		closeGreeter( True );
 		if (clientPid > 0)
 			abortClient( clientPid );
 		sessionExit( ex );
@@ -570,28 +577,15 @@ manageSession( struct display *d )
 		/* NOTREACHED */
 #endif
 
-	if (d->hstent->sdRec.how) {
-		openGreeter();
-		gSendInt( G_ConfShutdown );
-		gSendInt( d->hstent->sdRec.how );
-		gSendInt( d->hstent->sdRec.uid );
-		gSendStr( d->hstent->sdRec.osname );
-		if ((cmd = ctrlGreeterWait( TRUE )) != G_Ready) {
-			logError( "Received unknown command %d from greeter\n", cmd );
-			closeGreeter( TRUE );
-		}
-		goto regreet;
-	}
-
 	tdiff = time( 0 ) - td->hstent->lastExit - td->openDelay;
 	if (autoLogon( tdiff )) {
-		if (!verify( conv_auto, FALSE ))
+		if (!verify( conv_auto, False ))
 			goto gcont;
 	} else {
 	  regreet:
 		openGreeter();
 		if (Setjmp( idleTOJmp )) {
-			closeGreeter( TRUE );
+			closeGreeter( True );
 			sessionExit( EX_NORMAL );
 		}
 		Signal( SIGALRM, IdleTimeout );
@@ -607,7 +601,7 @@ manageSession( struct display *d )
 			           (tdiff > 0 || td->autoAgain)) ?
 			              G_GreetTimed : G_Greet );
 		  gcont:
-			cmd = ctrlGreeterWait( TRUE );
+			cmd = ctrlGreeterWait( True );
 #ifdef XDMCP
 		  recmd:
 			if (cmd == G_DChoose) {
@@ -622,10 +616,10 @@ manageSession( struct display *d )
 			if (cmd == G_Ready)
 				break;
 			if (cmd == -2)
-				closeGreeter( FALSE );
+				closeGreeter( False );
 			else {
 				logError( "Received unknown command %d from greeter\n", cmd );
-				closeGreeter( TRUE );
+				closeGreeter( True );
 			}
 			goto regreet;
 		}
@@ -667,6 +661,25 @@ manageSession( struct display *d )
 			sleep( 10 );
 		sessionExit( EX_AL_RESERVER_DPY );
 	}
+
+	sigemptyset( &ss );
+	sigaddset( &ss, SIGTERM );
+	sigprocmask( SIG_BLOCK, &ss, 0 );
+	clientExited();
+	sigprocmask( SIG_UNBLOCK, &ss, 0 );
+
+	gSet( &mstrtalk );
+	gSendInt( D_UnUser );
+	if (gRecvInt()) {
+		resetXProperties();
+		openGreeter();
+		gSendInt( G_ConfShutdown );
+		if ((cmd = ctrlGreeterWait( True )) != G_Ready) {
+			logError( "Received unknown command %d from greeter\n", cmd );
+			closeGreeter( True );
+		}
+	}
+
 	sessionExit( EX_NORMAL ); /* XXX maybe EX_REMANAGE_DPY? -- enable in dm.c! */
 }
 
@@ -679,7 +692,7 @@ loadXloginResources()
 	char **env;
 
 	if (!xResLoaded && td->resources[0] && access( td->resources, 4 ) == 0) {
-		env = systemEnv( (char *)0 );
+		env = systemEnv( 0, 0 );
 		if ((args = parseArgs( (char **)0, td->xrdb )) &&
 		    (args = addStrArr( args, td->resources, -1 )))
 		{
@@ -688,7 +701,7 @@ loadXloginResources()
 			freeStrArr( args );
 		}
 		freeStrArr( env );
-		xResLoaded = TRUE;
+		xResLoaded = True;
 	}
 }
 
@@ -697,7 +710,7 @@ setupDisplay( const char *arg )
 {
 	char **env;
 
-	env = systemEnv( (char *)0 );
+	env = systemEnv( 0, 0 );
 	(void)source( env, td->setup, arg );
 	freeStrArr( env );
 }
@@ -710,13 +723,33 @@ deleteXloginResources()
 
 	if (!xResLoaded)
 		return;
-	xResLoaded = FALSE;
+	xResLoaded = False;
 	prop = XInternAtom( dpy, "SCREEN_RESOURCES", True );
 	XDeleteProperty( dpy, RootWindow( dpy, 0 ), XA_RESOURCE_MANAGER );
 	if (prop)
 		for (i = ScreenCount(dpy); --i >= 0; )
 			XDeleteProperty( dpy, RootWindow( dpy, i ), prop );
-	XSync( dpy, 0 );
+	XSync( dpy, False );
+}
+
+void
+resetXProperties()
+{
+	int i, j, nprops;
+	char *name;
+	Atom *props;
+
+	for (i = ScreenCount(dpy); --i >= 0; )
+		if ((props = XListProperties( dpy, RootWindow( dpy, i ), &nprops ))) {
+			for (j = 0; j < nprops; j++)
+				if ((name = XGetAtomName( dpy, props[j] ))) {
+					if (!memcmp( name, "_NET_", 5 ))
+						XDeleteProperty( dpy, RootWindow( dpy, i ), props[j] );
+					XFree( name );
+				}
+			XFree( props );
+		}
+	XSync( dpy, False );
 }
 
 
@@ -739,6 +772,19 @@ source( char **env, const char *file, const char *arg )
 	return 0;
 }
 
+static char **
+dupEnv( void )
+{
+	int i, l = arrLen( environ );
+	char **env;
+	if (!(env = Malloc( (l + 1) * sizeof(char *) )))
+		return 0;
+	for (i = 0; i < l; i++)
+		strDup( env + i, environ[i] );
+	env[i] = 0;
+	return env;
+}
+
 char **
 inheritEnv( char **env, const char **what )
 {
@@ -751,31 +797,16 @@ inheritEnv( char **env, const char **what )
 }
 
 char **
-baseEnv( const char *user )
+baseEnv( char **env, const char *user )
 {
-	char **env;
-
-	env = 0;
-
-#ifdef _AIX
-	/* we need the tags SYSENVIRON: and USRENVIRON: in the call to setpenv() */
-	env = setEnv( env, "SYSENVIRON:", 0 );
-#endif
+	if (!env)
+		env = inheritEnv( 0, (const char **)exportList );
 
 	if (user) {
 		env = setEnv( env, "USER", user );
-#ifdef _AIX
-		env = setEnv( env, "LOGIN", user );
-#endif
 		env = setEnv( env, "LOGNAME", user );
 	}
 
-#ifdef _AIX
-	env = setEnv( env, "USRENVIRON:", 0 );
-#endif
-
-	env = inheritEnv( env, (const char **)exportList );
-
 	env = setEnv( env, "DISPLAY",
 	              memcmp( td->name, "localhost:", 10 ) ?
 	              td->name : td->name + 9 );
@@ -796,11 +827,9 @@ baseEnv( const char *user )
 }
 
 char **
-systemEnv( const char *user )
+systemEnv( char **env, const char *user )
 {
-	char **env;
-
-	env = baseEnv( user );
+	env = baseEnv( env, user );
 	if (td->authFile)
 		env = setEnv( env, "XAUTHORITY", td->authFile );
 	env = setEnv( env, "PATH", td->systemPath );
