@@ -38,6 +38,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <signal.h>
 #include <setjmp.h>
 #include <ctype.h>
+#include <locale.h>
 #include <time.h>
 #include <errno.h>
 #include <fcntl.h>
@@ -403,22 +404,9 @@ secureDisplay( Display *dpy )
 	if (!_grabServer)
 	{
 		XUngrabServer( dpy );
-		XSync( dpy, 0 );
+		XSync( dpy, False );
 	}
 	debug( "secureDisplay %s done\n", dname );
-#if defined(HAVE_XKB) && defined(HAVE_XKBSETPERCLIENTCONTROLS)
-	/*
-	 * Activate the correct mapping for modifiers in XKB extension as
-	 * grabbed keyboard has its own mapping by default
-	 */
-	{
-		int opcode, evbase, errbase, majret, minret;
-		unsigned int value = XkbPCF_GrabsUseXKBStateMask;
-		if (XkbQueryExtension( dpy, &opcode, &evbase,
-		                       &errbase, &majret, &minret ))
-			XkbSetPerClientControls( dpy, value, &value );
-	}
-#endif
 }
 
 void
@@ -427,39 +415,70 @@ unsecureDisplay( Display *dpy )
 	debug( "Unsecure display %s\n", dname );
 	if (_grabServer) {
 		XUngrabServer( dpy );
-		XSync( dpy, 0 );
+		XSync( dpy, False );
 	}
 }
 
+#define GRABEVENTS \
+	ButtonPressMask | ButtonReleaseMask | PointerMotionMask | \
+	EnterWindowMask | LeaveWindowMask
+
 void
 secureKeyboard( Display *dpy )
 {
-	debug( "secureKeyboard %s\n", dname );
 	(void)alarm( (unsigned)_grabTimeout );
 	(void)signal( SIGALRM, syncTimeout );
 	if (setjmp( syncJump ) ||
-	    XGrabKeyboard( dpy, DefaultRootWindow( dpy ), True, GrabModeAsync,
-	                   GrabModeAsync, CurrentTime ) != GrabSuccess)
+	    XGrabKeyboard( dpy, DefaultRootWindow( dpy ), True,
+	                   GrabModeAsync, GrabModeAsync,
+	                   CurrentTime ) != GrabSuccess)
 	{
 		(void)alarm( 0 );
 		(void)signal( SIGALRM, SIG_DFL );
 		logError( "Keyboard on display %s could not be secured\n", dname );
-		sleep( 10 );
 		exit( EX_RESERVER_DPY );
 	}
 	(void)alarm( 0 );
 	(void)signal( SIGALRM, SIG_DFL );
-	XSetInputFocus( dpy, None, None, CurrentTime );
-	debug( "secureKeyboard %s done\n", dname );
 }
 
 void
-unsecureKeyboard( Display *dpy )
+securePointer( Display *dpy )
 {
-	debug( "Unsecure keyboard %s\n", dname );
+	(void)alarm( (unsigned)_grabTimeout );
+	(void)signal( SIGALRM, syncTimeout );
+	if (setjmp( syncJump ) ||
+	    XGrabPointer( dpy, DefaultRootWindow( dpy ), True, GRABEVENTS,
+	                  GrabModeAsync, GrabModeAsync,
+	                  None, None, CurrentTime ) != GrabSuccess)
+	{
+		(void)alarm( 0 );
+		(void)signal( SIGALRM, SIG_DFL );
+		logError( "Pointer on display %s could not be secured\n", dname );
+		exit( EX_RESERVER_DPY );
+	}
+	(void)alarm( 0 );
+	(void)signal( SIGALRM, SIG_DFL );
+}
+
+void
+secureInputs( Display *dpy )
+{
+	debug( "secureInputs %s\n", dname );
+	secureKeyboard( dpy );
+	securePointer( dpy );
+	XSetInputFocus( dpy, None, None, CurrentTime );
+	debug( "secureInputs %s done\n", dname );
+}
+
+void
+unsecureInputs( Display *dpy )
+{
+	debug( "unsecureInputs %s\n", dname );
 	XSetInputFocus( dpy, PointerRoot, PointerRoot, CurrentTime );
 	XUngrabKeyboard( dpy, CurrentTime );
-	XSync( dpy, 0 );
+	XUngrabPointer( dpy, CurrentTime );
+	XSync( dpy, False );
 }
 
 static jmp_buf pingTime;
@@ -489,20 +508,20 @@ pingServer( Display *dpy )
 	(void)alarm( _pingTimeout * 60 );
 	if (!setjmp( pingTime )) {
 		debug( "Ping server\n" );
-		XSync( dpy, 0 );
+		XSync( dpy, False );
 	} else {
 		debug( "Server dead\n" );
 		(void)alarm( 0 );
 		(void)signal( SIGALRM, SIG_DFL );
 		XSetIOErrorHandler( oldError );
-		return 0;
+		return False;
 	}
 	(void)alarm( 0 );
 	(void)signal( SIGALRM, oldSig );
 	(void)alarm( oldAlarm );
 	debug( "Server alive\n" );
 	XSetIOErrorHandler( oldError );
-	return 1;
+	return True;
 }
 
 /*
@@ -574,9 +593,9 @@ xkbSetModifier( Display *dpy, const char *name, int sts )
 	unsigned int mask;
 
 	if (!(mask = xkbModifierMask( dpy, name )))
-		return 0;
+		return False;
 	XkbLockModifiers( dpy, XkbUseCoreKbd, mask, sts ? mask : 0 );
-	return 1;
+	return True;
 }
 #endif /* HAVE_XKB */
 
@@ -625,11 +644,11 @@ setupModifiers( Display *mdpy, int numlock )
 	if (numlock == 2)
 		return;
 	newnumstate = numlock;
-	nummodified = 1;
+	nummodified = True;
 	dpy = mdpy;
 #ifdef HAVE_XKB
 	if (xkbInit( mdpy )) {
-		havexkb = 1;
+		havexkb = True;
 		oldnumstate = xkbGetModifierState( mdpy, "NumLock" );
 		xkbSetModifier( mdpy, "NumLock", numlock );
 		return;
@@ -698,6 +717,18 @@ cleanup( void )
 	}
 }
 
+static int
+goodLocale( const char *var )
+{
+	char *l = getenv( var );
+	if (!l)
+		return False;
+	if (*l && strcmp( l, "C" ) && strcmp( l, "POSIX" ))
+		return True;
+	unsetenv( l );
+	return False;
+}
+
 extern void kg_main( const char *argv0 );
 
 int
@@ -745,7 +776,28 @@ main( int argc ATTR_UNUSED, char **argv )
 		logPanic( "Cannot save $HOME\n" );
 	atexit( cleanup );
 
-	setenv( "LC_ALL", _language, 1 );
+	if (*_language) {
+		/*
+		 * Make reasonably sure the locale is not POSIX. This will still fail
+		 * if all of the following apply:
+		 * - LANG, LC_MESSAGES & LC_ALL resolve to POSIX
+		 * - an abbreviated locale is configured (the kcm does this)
+		 * - the en_US locale is not installed
+		 */
+		if (!goodLocale( "LC_ALL" ) &&
+		    !goodLocale( "LC_MESSAGES" ) &&
+		    !goodLocale( "LANG" ))
+		{
+			if (strchr( _language, '_' ) && setlocale( LC_ALL, _language ))
+				setenv( "LANG", _language, 1 );
+			else if (setlocale( LC_ALL, "en_US" ))
+				setenv( "LANG", "en_US", 1 );
+			else
+				logError( "Cannot set locale. Translations will not work.\n" );
+		}
+
+		setenv( "LANGUAGE", _language, 1 );
+	}
 
 	kg_main( argv[0] );
 
