@@ -63,7 +63,9 @@ sigAlarm( int )
 }
 
 GreeterApp::GreeterApp( int argc, char **argv ) :
-	inherited( argc, argv )
+	inherited( argc, argv ),
+	regrabPtr( false ), regrabKbd( false ),
+	dragWidget( 0 )
 {
 	pingInterval = _isLocal ? 0 : _pingInterval;
 	if (pingInterval) {
@@ -73,17 +75,20 @@ GreeterApp::GreeterApp( int argc, char **argv ) :
 		sa.sa_handler = sigAlarm;
 		sigaction( SIGALRM, &sa, 0 );
 		alarm( pingInterval * 70 ); // sic! give the "proper" pinger enough time
-		startTimer( pingInterval * 60000 );
-	}
+		pingTimerId = startTimer( pingInterval * 60000 );
+	} else
+		pingTimerId = 0;
 }
 
 void
-GreeterApp::timerEvent( QTimerEvent * )
+GreeterApp::timerEvent( QTimerEvent *ev )
 {
-	alarm( 0 );
-	if (!pingServer( QX11Info::display() ))
-		::exit( EX_RESERVER_DPY );
-	alarm( pingInterval * 70 ); // sic! give the "proper" pinger enough time
+	if (ev->timerId() == pingTimerId) {
+		alarm( 0 );
+		if (!pingServer( QX11Info::display() ))
+			::exit( EX_RESERVER_DPY );
+		alarm( pingInterval * 70 ); // sic! give the "proper" pinger enough time
+	}
 }
 
 bool
@@ -92,6 +97,26 @@ GreeterApp::x11EventFilter( XEvent * ev )
 	KeySym sym;
 
 	switch (ev->type) {
+	case FocusIn:
+	case FocusOut:
+		if (ev->xfocus.mode == NotifyUngrab) {
+			if (!regrabKbd) {
+				secureKeyboard( QX11Info::display() );
+				regrabKbd = true;
+			}
+		} else
+			regrabKbd = false;
+		break;
+	case EnterNotify:
+	case LeaveNotify:
+		if (ev->xcrossing.mode == NotifyUngrab) {
+			if (!regrabPtr) {
+				securePointer( QX11Info::display() );
+				regrabPtr = true;
+			}
+		} else
+			regrabPtr = false;
+		break;
 	case KeyPress:
 		sym = XLookupKeysym( &ev->xkey, 0 );
 		if (sym != XK_Return && !IsModifierKey( sym ))
@@ -108,6 +133,42 @@ GreeterApp::x11EventFilter( XEvent * ev )
 	case MotionNotify:
 		if (ev->xbutton.state & Button3Mask)
 			ev->xbutton.state = (ev->xbutton.state & ~Button3Mask) | Button1Mask;
+		switch (ev->type) {
+		case ButtonPress:
+			if (((ev->xbutton.state & Mod1Mask) && ev->xbutton.button == 1) ||
+			    dragWidget)
+			{
+				if (!dragWidget &&
+				    ev->xbutton.window != QX11Info::appRootWindow( _greeterScreen ) &&
+				    (dragWidget = QWidget::find( ev->xbutton.window )))
+				{
+					dragWidget = dragWidget->topLevelWidget();
+					dialogStartPos = dragWidget->geometry().center();
+					mouseStartPos = QPoint( ev->xbutton.x_root, ev->xbutton.y_root );
+					setOverrideCursor( QCursor( Qt::SizeAllCursor ) );
+				}
+				return true;
+			}
+			break;
+		case ButtonRelease:
+			if (dragWidget) {
+				restoreOverrideCursor();
+				dragWidget = 0;
+				return true;
+			}
+			break;
+		case MotionNotify:
+			if (dragWidget) {
+				QRect grt( dragWidget->rect() );
+				grt.moveCenter( dialogStartPos +
+				                QPoint( ev->xbutton.x_root, ev->xbutton.y_root ) -
+				                mouseStartPos );
+				FDialog::fitInto( qApp->desktop()->screenGeometry( _greeterScreen ), grt );
+				dragWidget->setGeometry( grt );
+				return true;
+			}
+			break;
+		}
 		break;
 	}
 	return false;
@@ -119,12 +180,14 @@ static int
 xIOErr( Display * )
 {
 	exit( EX_RESERVER_DPY );
+	// Bogus return value, notreached
+	return 0;
 }
 
 void
 kg_main( const char *argv0 )
 {
-	static char *argv[] = { (char *)"kdmgreet", (char *)"-nograb", 0 };
+	static char *argv[] = { (char *)"kdmgreet", 0 };
 
 	KCrash::setFlags( KCrash::KeepFDs | KCrash::SaferDialog | KCrash::AlwaysDirectly );
 	KCrash::setApplicationName( QLatin1String( argv[0] ) );
@@ -132,12 +195,14 @@ kg_main( const char *argv0 )
 	XSetIOErrorHandler( xIOErr );
 	KComponentData inst( argv[0] );
 	GreeterApp app( as(argv) - 1, argv );
+	foreach (const QString &dir, KGlobal::dirs()->resourceDirs( "qtplugins" ))
+		app.addLibraryPath( dir );
 	initQAppConfig();
 	KGlobalSettings::self();
 
 	Display *dpy = QX11Info::display();
 
-	_colorScheme = KStandardDirs::locate( "data", "kdisplay/color-schemes/" + _colorScheme + ".kcsrc" );
+	_colorScheme = KStandardDirs::locate( "data", "color-schemes/" + _colorScheme + ".colors" );
 	if (!_colorScheme.isEmpty()) {
 		KSharedConfigPtr config = KSharedConfig::openConfig( _colorScheme, KConfig::SimpleConfig );
 		app.setPalette( KGlobalSettings::createApplicationPalette( config ) );
@@ -157,11 +222,8 @@ kg_main( const char *argv0 )
 			showTypes["reboot"] = true;
 			// "suspend" not implemented
 		}
-		if (_autoLoginDelay)
-			showTypes["timed"] = false;
 
-		// modes: console{,-fixed,-flexi}, remote{,-flexi}, flexi
-		themer = new KdmThemer( _theme, "console", showTypes, app.desktop()->screen() );
+		themer = new KdmThemer( _theme, showTypes, app.desktop()->screen() );
 		if (!themer->isOK()) {
 			delete themer;
 			themer = 0;
@@ -203,14 +265,16 @@ kg_main( const char *argv0 )
 		int cmd = gRecvInt();
 
 		if (cmd == G_ConfShutdown) {
+			gSet( 1 );
+			gSendInt( G_QryDpyShutdown );
 			int how = gRecvInt(), uid = gRecvInt();
 			char *os = gRecvStr();
+			gSet( 0 );
 			KDMSlimShutdown::externShutdown( how, os, uid );
 			if (os)
 				free( os );
 			gSendInt( G_Ready );
-			_autoLoginDelay = 0;
-			continue;
+			break;
 		}
 
 		if (cmd == G_ErrorGreet) {
