@@ -32,7 +32,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "themer/kdmitem.h"
 
 #include <kguiitem.h>
-#include <klibloader.h>
+#include <klibrary.h>
 #include <klocale.h>
 #include <kpushbutton.h>
 #include <krandom.h>
@@ -451,8 +451,8 @@ void // private static
 KGVerify::vrfMsgBox( QWidget *parent, const QString &user,
                      QMessageBox::Icon type, const QString &mesg )
 {
-	FDialog::box( parent, type, user.isEmpty() ?
-	              mesg : i18n("Logging in %1 ...\n\n", user ) + mesg );
+	KFMsgBox::box( parent, type, user.isEmpty() ?
+	               mesg : i18n("Logging in %1 ...\n\n", user ) + mesg );
 }
 
 static const char *msgs[]= {
@@ -565,6 +565,7 @@ KGVerify::handleFailVerify( QWidget *parent, bool showUser )
 				free( msg );
 			gSendInt( 0 );
 			continue;
+		case V_MSG_INFO_AUTH: // should not happen
 		case V_MSG_INFO:
 			debug( " V_MSG_INFO\n" );
 			msg = gRecvStr();
@@ -683,7 +684,7 @@ KGVerify::handleVerify()
 			debug( " V_MSG_ERR\n" );
 			msg = gRecvStr();
 			debug( "  %s->textMessage(%\"s, true)\n", pName.data(), msg );
-			if (!greet->textMessage( msg, true )) {
+			if (!greet->textMessage( msg, true )) { // XXX little point in filtering
 				debug( "  message passed\n" );
 				vrfErrBox( parent, user, msg );
 			} else
@@ -692,8 +693,8 @@ KGVerify::handleVerify()
 				free( msg );
 			gSendInt( 0 );
 			continue;
-		case V_MSG_INFO:
-			debug( " V_MSG_INFO\n" );
+		case V_MSG_INFO_AUTH:
+			debug( " V_MSG_INFO_AUTH\n" );
 			msg = gRecvStr();
 			debug( "  %s->textMessage(%\"s, false)\n", pName.data(), msg );
 			if (!greet->textMessage( msg, false )) {
@@ -704,6 +705,14 @@ KGVerify::handleVerify()
 			free( msg );
 			gSendInt( 0 );
 			continue;
+		case V_MSG_INFO:
+			debug( " V_MSG_INFO\n" );
+			msg = gRecvStr();
+			debug( "  display %\"s\n", msg );
+			vrfInfoBox( parent, user, msg );
+			free( msg );
+			gSendInt( 0 );
+			continue;
 		}
 
 		// terminal status
@@ -867,7 +876,7 @@ void
 KGVerify::msgBox( QMessageBox::Icon typ, const QString &msg )
 {
 	timer.suspend();
-	FDialog::box( parent, typ, msg );
+	KFMsgBox::box( parent, typ, msg );
 	timer.resume();
 }
 
@@ -895,33 +904,39 @@ KGVerify::init( const QStringList &plugins )
 
 	foreach (QString pg, plugins) {
 		GreeterPluginHandle plugin;
-		QString path = KLibLoader::self()->findLibrary(
-			(pg[0] == '/' ? pg : "kgreet_" + pg ).toLatin1() );
-		if (path.isEmpty()) {
+		KLibrary *lib = new KLibrary( pg[0] == '/' ? pg : "kgreet_" + pg );
+		if (lib->fileName().isEmpty()) {
 			logError( "GreeterPlugin %s does not exist\n", qPrintable( pg ) );
+			delete lib;
 			continue;
 		}
 		uint i, np = greetPlugins.count();
 		for (i = 0; i < np; i++)
-			if (greetPlugins[i].library->fileName() == path)
+			if (greetPlugins[i].library->fileName() == lib->fileName()) {
+				delete lib;
 				goto next;
-		if (!(plugin.library = KLibLoader::self()->library( path.toLatin1() ))) {
+			}
+		if (!lib->load()) {
 			logError( "Cannot load GreeterPlugin %s (%s)\n",
-			          qPrintable( pg ), qPrintable( path ) );
+			          qPrintable( pg ), qPrintable( lib->fileName() ) );
+			delete lib;
 			continue;
 		}
-		plugin.info = (kgreeterplugin_info*)plugin.library->resolveSymbol( "kgreeterplugin_info" );
+		plugin.library = lib;
+		plugin.info = (kgreeterplugin_info*)lib->resolveSymbol( "kgreeterplugin_info" );
 		if (!plugin.info) {
 			logError( "GreeterPlugin %s (%s) is no valid greet widget plugin\n",
-			          qPrintable( pg ), qPrintable( path ) );
-			plugin.library->unload();
+			          qPrintable( pg ), qPrintable( lib->fileName() ) );
+			lib->unload();
+			delete lib;
 			continue;
 		}
 
 		if (!plugin.info->init( QString(), getConf, 0 )) {
 			logError( "GreeterPlugin %s (%s) refuses to serve\n",
-			          qPrintable( pg ), qPrintable( path ) );
-			plugin.library->unload();
+			          qPrintable( pg ), qPrintable( lib->fileName() ) );
+			lib->unload();
+			delete lib;
 			continue;
 		}
 		debug( "GreeterPlugin %s (%s) loaded\n", qPrintable( pg ), plugin.info->name );
