@@ -50,7 +50,7 @@ General_tab::General_tab( QWidget* parent_P, const char* name_P )
                 action_type_combo->insertItem( i,
                     i18n( "K-Menu Entry (simple)" ) );
               break;
-            case Tab_widget::TYPE_DCOP_SHORTCUT:
+            case Tab_widget::TYPE_DBUS_SHORTCUT:
                 action_type_combo->insertItem( i,
                     i18n( "Keyboard Shortcut -> DCOP Call (simple)" ) );
               break;
