@@ -22,41 +22,20 @@
 */
 
 #include <QClipboard>
-#include <QCursor>
-#include <QDateTime>
-#include <QFile>
-#include <QPainter>
-
-#include <QtGui/QMacMime>
-#include <Qt3Support/Q3ColorDrag>
-#include <QPaintEvent>
-#include <QMouseEvent>
-#include <QX11Info>
+#include <QtDBus/QDBusConnection>
 
 #include <kaboutdata.h>
-#include <kaction.h>
-#include <kapplication.h>
-#include <kconfig.h>
-#include <kglobal.h>
-#include <kicon.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <ksavefile.h>
 #include <ksessionmanager.h>
 #include <kstandarddirs.h>
-#include <kstringhandler.h>
 #include <ksystemtrayicon.h>
-#include <k3urldrag.h>
-#include <kwindowsystem.h>
 #include <kdebug.h>
 #include <kglobalsettings.h>
-#include <QtDBus/QDBusConnection>
-#include <kiconloader.h>
-#include <khelpmenu.h>
-#include <kstandardguiitem.h>
 #include <kactioncollection.h>
 #include <ktoggleaction.h>
-#include <kconfiggroup.h>
+#include <KConfigSkeleton>
 
 #include "configdialog.h"
 #include "klipper.h"
@@ -73,6 +52,8 @@
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 
+//#define NOISY_KLIPPER
+
 namespace {
     /**
      * Use this when manipulating the clipboard
@@ -151,16 +132,16 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config)
 
     // we need that collection, otherwise KToggleAction is not happy :}
     //QString defaultGroup( "default" );
-    KActionCollection *collection = new KActionCollection( this );
+    collection = new KActionCollection( this );
     toggleURLGrabAction = new KToggleAction( this );
     collection->addAction( "toggleUrlGrabAction", toggleURLGrabAction );
     toggleURLGrabAction->setEnabled( true );
     //toggleURLGrabAction->setGroup( defaultGroup );
     clearHistoryAction = collection->addAction( "clearHistoryAction" );
-    clearHistoryAction->setIcon( KIcon("history-clear") );
+    clearHistoryAction->setIcon( KIcon("edit-clear-history") );
     clearHistoryAction->setText( i18n("C&lear Clipboard History") );
-    connect(clearHistoryAction, SIGNAL(triggered(bool) ), history(), SLOT( slotClear() ));
-    connect( clearHistoryAction, SIGNAL( activated() ), SLOT( slotClearClipboard() ) );
+    connect(clearHistoryAction, SIGNAL(triggered() ), history(), SLOT( slotClear() ));
+    connect( clearHistoryAction, SIGNAL( triggered() ), SLOT( slotClearClipboard() ) );
     //clearHistoryAction->setGroup( defaultGroup );
     configureAction = collection->addAction( "configureAction" );
     configureAction->setIcon( KIcon("configure") );
@@ -187,19 +168,22 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config)
     connect( poll, SIGNAL( clipboardChanged( bool ) ),
              this, SLOT( newClipData( bool ) ) );
 
-    m_pixmap = KSystemTrayIcon::loadIcon( "klipper" ).pixmap();
+    QAction *a = collection->addAction("show_klipper_popup");
+    a->setText(i18n("Show Klipper Popup-Menu"));
+    qobject_cast<KAction*>(a)->setGlobalShortcut(KShortcut(Qt::ALT+Qt::CTRL+Qt::Key_V));
+    connect(a, SIGNAL(triggered()), SLOT(slotPopupMenu()));
 
-    globalKeys = KGlobalAccel::self();
-    KActionCollection* actionCollection = collection;
-    QAction* a = 0L;
-#ifdef __GNUC__
-#warning TODO PORT ME (KGlobalAccel related)
-#endif
-#include "klipperbindings.cpp"
-    // the keys need to be read from kdeglobals, not kickerrc --ellis, 22/9/02
-    //globalKeys->readSettings();
-    //globalKeys->updateConnections();
-    //toggleURLGrabAction->setShortcut(globalKeys->shortcut("Enable/Disable Clipboard Actions"));
+    a = collection->addAction("repeat_action");
+    a->setText(i18n("Manually Invoke Action on Current Clipboard"));
+    qobject_cast<KAction*>(a)->setGlobalShortcut(KShortcut(Qt::ALT+Qt::CTRL+Qt::Key_R));
+    connect(a, SIGNAL(triggered()), SLOT(slotRepeatAction()));
+
+    a = collection->addAction("clipboard_action");
+    a->setText(i18n("Enable/Disable Clipboard Actions"));
+    qobject_cast<KAction*>(a)->setGlobalShortcut(KShortcut(Qt::ALT+Qt::CTRL+Qt::Key_X));
+    connect(a, SIGNAL(triggered()), SLOT(toggleURLGrabber()));
+
+    toggleURLGrabAction->setShortcut(qobject_cast<KAction*>(collection->action("clipboard_action"))->globalShortcut());
 
     connect( toggleURLGrabAction, SIGNAL( toggled( bool )),
              this, SLOT( setURLGrabberEnabled( bool )));
@@ -388,9 +372,13 @@ void Klipper::saveHistory() {
     QByteArray data;
     QDataStream history_stream( &data, QIODevice::WriteOnly );
     history_stream << klipper_version; // const char*
-    for (  const HistoryItem* item = history()->first(); item; item = history()->next() ) {
+
+    History::iterator it = history()->youngest();
+    while (it.hasNext()) {
+        const HistoryItem *item = it.next();
         history_stream << item;
     }
+
     quint32 crc = crc32( 0, reinterpret_cast<unsigned char *>( data.data() ), data.size() );
     QDataStream ds ( &history_file );
     ds << crc << data;
@@ -476,12 +464,7 @@ void Klipper::saveSession()
 void Klipper::slotSettingsChanged( int category )
 {
     if ( category == (int) KGlobalSettings::SETTINGS_SHORTCUTS ) {
-#ifdef __GNUC__
-#warning TODO PORT ME (KGlobalAccel related)
-#endif
-        //globalKeys->readSettings();
-        //globalKeys->updateConnections();
-        //toggleURLGrabAction->setShortcut(globalKeys->shortcut("Enable/Disable Clipboard Actions"));
+        toggleURLGrabAction->setShortcut(qobject_cast<KAction*>(collection->action("clipboard_action"))->globalShortcut());
     }
 }
 
@@ -502,8 +485,7 @@ void Klipper::slotConfigure()
         readConfiguration( m_config.data() );
     }
 
-    ConfigDialog *dlg = new ConfigDialog( myURLGrabber->actionList(),
-                                          globalKeys, isApplet() );
+    ConfigDialog *dlg = new ConfigDialog( 0, new KConfigSkeleton(), myURLGrabber->actionList(), collection, isApplet() );
     dlg->setKeepContents( bKeepContents );
     dlg->setPopupAtMousePos( bPopupAtMouse );
     dlg->setStripWhiteSpace( myURLGrabber->trimmed() );
@@ -525,12 +507,8 @@ void Klipper::slotConfigure()
         bSynchronize = dlg->synchronize();
         bUseGUIRegExpEditor = dlg->useGUIRegExpEditor();
         dlg->commitShortcuts();
-#ifdef __GNUC__
-#warning TODO PORT ME (KGlobalAccel related)
-#endif
-        //globalKeys->writeSettings();
-        //globalKeys->updateConnections();
-        //toggleURLGrabAction->setShortcut(globalKeys->shortcut("Enable/Disable Clipboard Actions"));
+
+        toggleURLGrabAction->setShortcut(qobject_cast<KAction*>(collection->action("clipboard_action"))->globalShortcut());
 
         myURLGrabber->setActionList( dlg->actionList() );
         myURLGrabber->setPopupTimeout( dlg->popupTimeout() );
@@ -557,7 +535,9 @@ void Klipper::slotQuit()
     }
 
     saveSession();
-    int autoStart = KMessageBox::questionYesNoCancel( 0L, i18n("Should Klipper start automatically\nwhen you login?"), i18n("Automatically Start Klipper?"),KGuiItem(i18n("Start")), KGuiItem(i18n("Do Not Start")) );
+    int autoStart = KMessageBox::questionYesNoCancel(0, i18n("Should Klipper start automatically when you login?"),
+                                                     i18n("Automatically Start Klipper?"), KGuiItem(i18n("Start")),
+                                                     KGuiItem(i18n("Do Not Start")), KStandardGuiItem::cancel(), "StartAutomatically");
 
     KConfigGroup config( KGlobal::config(), "General");
     if ( autoStart == KMessageBox::Yes ) {
@@ -736,9 +716,15 @@ bool Klipper::blockFetchingNewData()
 //   while the user is doing a selection using the mouse, OOo stops updating the clipboard
 //   contents, so in practice it's like the user has selected only the part which was
 //   selected when Klipper asked first.
-	Qt::ButtonState buttonstate = QApplication::mouseButtons();
-    if( ( buttonstate & ( Qt::ShiftModifier | Qt::LeftButton )) == Qt::ShiftModifier // #85198
-        || ( buttonstate & Qt::LeftButton ) == Qt::LeftButton ) { // #80302
+// Use XQueryPointer rather than QApplication::mouseButtons()/keyboardModifiers(), because
+//   Klipper needs the very current state.
+    Window root, child;
+    int root_x, root_y, win_x, win_y;
+    uint state;
+    XQueryPointer( QX11Info::display(), QX11Info::appRootWindow(), &root, &child,
+                   &root_x, &root_y, &win_x, &win_y, &state );
+    if( ( state & ( ShiftMask | Button1Mask )) == ShiftMask // #85198
+        || ( state & Button1Mask ) == Button1Mask ) { // #80302
         m_pendingContentsCheck = true;
         m_pendingCheckTimer.start( 100 );
         return true;
@@ -834,12 +820,10 @@ void Klipper::checkClipData( bool selectionMode )
     if ( selectionMode && bIgnoreSelection )
         return;
 
-    if( selectionMode && bSelectionTextOnly && data->hasText())
+    if( selectionMode && bSelectionTextOnly && !data->hasText())
         return;
 
-#ifdef __GNUC__
-#warning This should be maybe extended for KDE4 or at least get a checkbox somewhere in UI
-#endif
+// TODO: This should be maybe extended for KDE4 or at least get a checkbox somewhere in UI
     if( KUrl::List::canDecode( data ) )
         ; // ok
     else if( data->hasText() )
@@ -944,18 +928,25 @@ void Klipper::slotClearOverflow()
 QStringList Klipper::getClipboardHistoryMenu()
 {
     QStringList menu;
-    for ( const HistoryItem* item = history()->first(); item; item = history()->next() ) {
+
+    History::iterator it = history()->youngest();
+    while (it.hasNext()) {
+        const HistoryItem *item = it.next();
         menu << item->text();
     }
+
     return menu;
 }
 
 QString Klipper::getClipboardHistoryItem(int i)
 {
-    for ( const HistoryItem* item = history()->first(); item; item = history()->next() , i-- ) {
+    History::iterator it = history()->youngest();
+    while (it.hasNext()) {
+        const HistoryItem *item = it.next();
         if ( i == 0 ) {
             return item->text();
         }
+        i--;
     }
     return QString();
 
