@@ -42,6 +42,9 @@
 #include <KTitleWidget>
 #include <KWindowSystem>
 
+#include <Solid/Device>
+#include <Solid/DeviceInterface>
+
 // #include <threadweaver/DebuggingAids.h>
 // #include <ThreadWeaver/Thread>
 #include <ThreadWeaver/Job>
@@ -56,6 +59,7 @@
 #include "runners/shell/shellrunner.h"
 #include "collapsiblewidget.h"
 #include "interfaceadaptor.h"
+#include "krunnersettings.h"
 
 using ThreadWeaver::Weaver;
 using ThreadWeaver::Job;
@@ -137,6 +141,34 @@ class SearchMatch : public QListWidgetItem
             }
         }
 
+        bool operator<(const QListWidgetItem & other) const
+        {
+            // Rules:
+            //      0. Default wins. Always.
+            //      1. Exact trumps informational
+            //      2. Informational trumps possible
+            //      3. Higher relevance wins
+
+            const SearchMatch *otherMatch = dynamic_cast<const SearchMatch*>(&other);
+
+            if (!otherMatch) {
+                return QListWidgetItem::operator<(other);
+            }
+
+            if (otherMatch->m_default) {
+                return true;
+            }
+
+            Plasma::SearchMatch::Type myType = m_action->type();
+            Plasma::SearchMatch::Type otherType = otherMatch->m_action->type();
+
+            if (myType != otherType) {
+                return myType < otherType;
+            }
+
+            return m_action->relevance() < otherMatch->m_action->relevance();
+        }
+
     private:
         bool m_default;
         Plasma::SearchMatch* m_action;
@@ -273,6 +305,11 @@ Interface::Interface(QWidget* parent)
     m_updateTimer.setSingleShot(true);
     connect(&m_updateTimer, SIGNAL(timeout()), this, SLOT(updateMatches()));
 
+    const int numProcs = qMax(Solid::Device::listFromType(Solid::DeviceInterface::Processor).count(), 1);
+    const int numThreads = qMin(KRunnerSettings::maxThreads(), 2 + ((numProcs - 1) * 2));
+    //kDebug() << "setting up" << numThreads << "threads for" << numProcs << "processors";
+    Weaver::instance()->setMaximumNumberOfThreads(numThreads);
+
     QWidget* w = mainWidget();
     m_layout = new QVBoxLayout(w);
     m_layout->setMargin(0);
@@ -289,19 +326,19 @@ Interface::Interface(QWidget* parent)
     m_searchTerm->setLineEdit(lineEdit);
     m_header->setBuddy(m_searchTerm);
     m_layout->addWidget(m_searchTerm);
-    connect(m_searchTerm, SIGNAL(textChanged(QString)),
+    connect(m_searchTerm, SIGNAL(editTextChanged(QString)),
             this, SLOT(queueMatch()));
     connect(m_searchTerm, SIGNAL(returnPressed()),
             this, SLOT(exec()));
 
-    KConfigGroup cg(KGlobal::config(), "General");
-    QStringList executions = cg.readEntry("pastqueries", QStringList());
-    executions << QString();
+    QStringList executions = KRunnerSettings::pastQueries();
     //Handle updates to the completion object as well
     m_searchTerm->setHistoryItems(executions, true);
 
     //TODO: temporary feedback, change later with the "icon parade" :)
     m_matchList = new QListWidget(w);
+    //m_matchList->setSortingEnabled(true);
+
     connect( m_matchList, SIGNAL(itemActivated(QListWidgetItem*)),
              SLOT(matchActivated(QListWidgetItem*)) );
     connect( m_matchList, SIGNAL(itemClicked(QListWidgetItem*)),
@@ -354,11 +391,12 @@ Interface::Interface(QWidget* parent)
     //        SLOT(setWidgetPalettes()));
 
     //TODO: how should we order runners, particularly ones loaded from plugins?
-    m_runners.append( new ShellRunner( this ) );
-    m_runners.append( new ServiceRunner( this ) );
-    m_runners.append( new SessionRunner( this ) );
-    QStringList whitelist = cg.readEntry( "runners",QStringList() );
-    m_runners += Plasma::AbstractRunner::loadRunners( this, whitelist );
+    QStringList whitelist = KRunnerSettings::runners();
+    m_runners += Plasma::AbstractRunner::loadRunners(this, whitelist);
+    // Load Integrated Runners
+    m_runners.prepend( new ShellRunner(this) );
+    m_runners.prepend( new ServiceRunner(this) );
+    m_runners.prepend( new SessionRunner(this) );
 
     connect(&m_context, SIGNAL(matchesChanged()), this, SLOT(queueUpdates()));
 
@@ -369,11 +407,16 @@ Interface::Interface(QWidget* parent)
 
 Interface::~Interface()
 {
-    KConfigGroup cg(KGlobal::config(), "General");
-    cg.writeEntry("pastqueries", m_searchTerm->historyItems());
+    KRunnerSettings::setPastQueries(m_searchTerm->historyItems());
     m_context.clearMatches();
 }
 
+void Interface::clearHistory()
+{
+    m_searchTerm->clearHistory();
+    KRunnerSettings::setPastQueries(m_searchTerm->historyItems());
+}
+
 void Interface::display(const QString& term)
 {
     m_searchTerm->setFocus();
@@ -412,8 +455,8 @@ void Interface::switchUser()
         kDebug() << "Could not find the Sessionrunner; not showing any sessions!";
         return;
     }
-
-    display();
+    //TODO: ugh, magic strings. See runners/sessions/sessionrunner.cpp
+    display("SESSIONS");
     m_header->setText(i18n("Switch users"));
     m_header->setPixmap("system-switch-user");
     m_defaultMatch = 0;
@@ -421,7 +464,7 @@ void Interface::switchUser()
     sessionrunner->match(&m_context);
 
     foreach (Plasma::SearchMatch *action, m_context.exactMatches()) {
-        bool makeDefault = action->type() != Plasma::SearchMatch::InformationalMatch;
+        bool makeDefault = !m_defaultMatch && action->type() != Plasma::SearchMatch::InformationalMatch;
 
         SearchMatch *match = new SearchMatch(action, m_matchList);
 
@@ -435,6 +478,8 @@ void Interface::switchUser()
 
     if (!m_defaultMatch) {
         m_matchList->addItem(i18n("No desktop sessions available"));
+    } else {
+        m_matchList->sortItems(Qt::DescendingOrder);
     }
 }
 
@@ -458,8 +503,7 @@ void Interface::resetInterface()
     m_header->setPixmap("system-search");
     m_defaultMatch = 0;
     m_context.setSearchTerm(QString());
-    m_searchTerm->addItem(QString());
-    m_searchTerm->setCurrentIndex(m_searchTerm->count() - 1);
+    m_searchTerm->setCurrentItem(QString(), true, 0);
     m_matchList->clear();
     m_runButton->setEnabled( false );
     m_optionsButton->setEnabled( false );
@@ -543,10 +587,8 @@ void Interface::match()
 
 void Interface::updateMatches()
 {
-    //FIXME: this induces rediculously bad flicker
     m_matchList->clear();
 
-    int matchCount = 0;
     m_defaultMatch = 0;
     QList<QList<Plasma::SearchMatch *> > matchLists;
     matchLists << m_context.informationalMatches()
@@ -557,8 +599,7 @@ void Interface::updateMatches()
         foreach (Plasma::SearchMatch *action, matchList) {
             bool makeDefault = !m_defaultMatch && action->isEnabled();
 
-            SearchMatch *match = new SearchMatch(action, 0);
-            m_matchList->insertItem(matchCount, match);
+            SearchMatch *match = new SearchMatch(action, m_matchList);
 
             if (makeDefault &&
                 action->relevance() > 0 &&
@@ -569,11 +610,11 @@ void Interface::updateMatches()
                 m_optionsButton->setEnabled(action->runner()->hasMatchOptions());
                 m_runButton->setEnabled(true);
             }
-
-            ++matchCount;
         }
     }
 
+    m_matchList->sortItems(Qt::DescendingOrder);
+
     if (!m_defaultMatch) {
         if (m_execQueued && Weaver::instance()->isIdle() ) {
             m_execQueued = false;
