@@ -39,9 +39,12 @@ class KRunnerDialog : public KDialog
     protected:
         void paintEvent( QPaintEvent *e );
         void resizeEvent( QResizeEvent *e );
+        void mousePressEvent( QMouseEvent *e );
 
     private:
-        Plasma::Svg* m_background;
+        void paintBackground(QPainter* painter, const QRect &exposedRect);
+        Plasma::Svg *m_background;
+        QPixmap *m_cachedBackground;
 };
 
 #endif
