@@ -41,7 +41,6 @@
 #include <Qt3Support/Q3CheckListItem>
 #include <Qt3Support/Q3Header>
 #include <QCheckBox>
-//Added by qt3to4:
 #include <QGridLayout>
 #include <QEvent>
 #include <QFrame>
@@ -49,6 +48,7 @@
 #include <QBoxLayout>
 #include <QTimerEvent>
 #include <QVBoxLayout>
+#include <QFile>
 
 #include <ctype.h>
 #include <unistd.h>
@@ -65,7 +65,8 @@
 #include <QX11Info>
 #include <kauthorized.h>
 
-#include <kxkb_interface.h>
+#include <KPluginLoader>
+#include <KPluginFactory>
 
 #ifndef AF_LOCAL
 # define AF_LOCAL	AF_UNIX
@@ -73,6 +74,7 @@
 
 #define PASSDLG_HIDE_TIMEOUT 10000
 
+
 //===========================================================================
 //
 // Simple dialog for entering a password.
@@ -84,42 +86,45 @@ PasswordDlg::PasswordDlg(LockProcess *parent, GreeterPluginHandle *plugin)
       mUnlockingFailed(false)
 {
     QWidget* w = mainWidget();
-    frame = new QFrame(w);
-    frame->setFrameStyle( QFrame::Panel | QFrame::Raised );
-    frame->setLineWidth( 2 );
 
-    QLabel *pixLabel = new QLabel( frame );
+    QLabel *pixLabel = new QLabel( w );
     pixLabel->setPixmap(DesktopIcon("system-lock-screen"));
 
-    KUser user;
-    QLabel *greetLabel = new QLabel( user.fullName().isEmpty() ?
+    KUser user; QString fullName=user.property(KUser::FullName).toString();
+    QLabel *greetLabel = new QLabel( fullName.isEmpty() ?
             i18n("<nobr><b>The session is locked</b></nobr><br />") :
-            i18n("<nobr><b>The session was locked by %1</b></nobr><br />",  user.fullName() ), frame );
+            i18n("<nobr><b>The session was locked by %1</b></nobr><br />", fullName ), w );
 
-    mStatusLabel = new QLabel( "<b> </b>", frame );
+    mStatusLabel = new QLabel( "<b> </b>", w );
     mStatusLabel->setAlignment( Qt::AlignCenter );
 
     greet = plugin->info->create(this, w, QString(),
                                  KGreeterPlugin::Authenticate,
                                  KGreeterPlugin::ExUnlock);
 
-    KSeparator *sep = new KSeparator( Qt::Horizontal, frame );
+    KSeparator *sep = new KSeparator( Qt::Horizontal, w );
 
-    ok = new KPushButton( i18n("Unl&ock"), frame );
-    cancel = new KPushButton( KStandardGuiItem::cancel(), frame );
-    mNewSessButton = new KPushButton( KGuiItem(i18n("Sw&itch User..."), "fork"), frame );
+    ok = new KPushButton( i18n("Unl&ock"), w );
+    cancel = new KPushButton( KStandardGuiItem::cancel(), w );
+    mNewSessButton = new KPushButton( KGuiItem(i18n("Sw&itch User..."), "fork"), w );
 
-    mLayoutButton = new KPushButton( frame );
-    mLayoutButton->setFlat( true );
-
-    QVBoxLayout *unlockDialogLayout = new QVBoxLayout(w);
-    unlockDialogLayout->addWidget( frame );
+    // Using KXKB component
+    KPluginFactory *kxkbFactory = KPluginLoader("libkdeinit4_kxkb").factory();
+    QWidget *kxkbComponent = NULL;
+    if (kxkbFactory) {
+        kxkbComponent = kxkbFactory->create<QWidget>(this);
+    }
+    else {
+        kDebug() << "can't load kxkb component library";
+    }
 
     QHBoxLayout *layStatus = new QHBoxLayout();
     layStatus->setSpacing( KDialog::spacingHint() );
     layStatus->setMargin( 0 );
     layStatus->addWidget( mStatusLabel );
-    layStatus->addWidget( mLayoutButton );
+
+    if( kxkbComponent )
+        layStatus->addWidget( kxkbComponent, 0, Qt::AlignRight );
 
     QHBoxLayout *layButtons = new QHBoxLayout();
     layButtons->setSpacing( KDialog::spacingHint() );
@@ -129,7 +134,7 @@ PasswordDlg::PasswordDlg(LockProcess *parent, GreeterPluginHandle *plugin)
     layButtons->addWidget( ok );
     layButtons->addWidget( cancel );
 
-    frameLayout = new QGridLayout( frame );
+    frameLayout = new QGridLayout( w );
     frameLayout->setSpacing( KDialog::spacingHint() );
     frameLayout->setMargin( KDialog::marginHint() );
     frameLayout->addWidget( pixLabel, 0, 0, 3, 1, Qt::AlignTop );
@@ -139,7 +144,7 @@ PasswordDlg::PasswordDlg(LockProcess *parent, GreeterPluginHandle *plugin)
     frameLayout->addWidget( sep, 3, 0, 1, 2 );
     frameLayout->addLayout( layButtons, 4, 0, 1, 2 );
 
-    connect(mLayoutButton, SIGNAL(clicked()), this, SLOT(layoutClicked()));
+    setButtons(None);
     connect(cancel, SIGNAL(clicked()), SLOT(reject()));
     connect(ok, SIGNAL(clicked()), SLOT(slotOK()));
     connect(mNewSessButton, SIGNAL(clicked()), SLOT(slotSwitchUser()));
@@ -154,24 +159,7 @@ PasswordDlg::PasswordDlg(LockProcess *parent, GreeterPluginHandle *plugin)
     connect(qApp, SIGNAL(activity()), SLOT(slotActivity()) );
 
     greet->start();
-
-    org::kde::KXKB kxkb("org.kde.kxkb", "/kxkb" , QDBusConnection::sessionBus());
-    if( kxkb.isValid() ) {
-        QDBusReply<QStringList> replyLayouts = kxkb.getLayoutsList();
-        layoutsList = replyLayouts;
-        QDBusReply<QString> replyCurrentLayout = kxkb.getCurrentLayout();
-        QString currentLayout = replyCurrentLayout;
-        if( !currentLayout.isEmpty() && layoutsList.count() > 1 ) {
-            currLayout = layoutsList.indexOf(currentLayout);
-            if (currLayout < 0)
-                setLayoutText("err");
-            else
-                setLayoutText(layoutsList[currLayout]);
-        } else
-            mLayoutButton->hide();
-    } else {
-        mLayoutButton->hide(); // no kxkb running
-    }
+    
     capsLocked();
 }
 
@@ -181,27 +169,6 @@ PasswordDlg::~PasswordDlg()
     delete greet;
 }
 
-void PasswordDlg::layoutClicked()
-{
-
-    if( ++currLayout == layoutsList.size() )
-        currLayout = 0;
-    org::kde::KXKB kxkb("org.kde.kxkb", "/kxkb" , QDBusConnection::sessionBus());
-    if( kxkb.isValid() ) {
-        const QString currentLayout = layoutsList.at(currLayout);
-        QDBusReply<bool> setLayoutReply = kxkb.setLayout(currentLayout );
-        setLayoutText( setLayoutReply ? currentLayout : "err" );
-    }
-}
-
-void PasswordDlg::setLayoutText( const QString &txt )
-{
-    mLayoutButton->setText( txt );
-    QSize sz = mLayoutButton->fontMetrics().size( 0, txt );
-    int mrg = mLayoutButton->style()->pixelMetric( QStyle::PM_ButtonMargin ) * 2;
-    mLayoutButton->setFixedSize( sz.width() + mrg, sz.height() + mrg );
-}
-
 void PasswordDlg::updateLabel()
 {
     if (mUnlockingFailed)
@@ -396,14 +363,14 @@ void PasswordDlg::handleVerify()
             if (!GRecvArr( &arr ))
                 break;
             if (!greet->textMessage( arr, false ))
-                static_cast< LockProcess* >(parent())->msgBox( QMessageBox::Information, QString::fromLocal8Bit( arr ) );
+                static_cast< LockProcess* >(parent())->msgBox( this, QMessageBox::Information, QString::fromLocal8Bit( arr ) );
             ::free( arr );
             continue;
         case ConvPutError:
             if (!GRecvArr( &arr ))
                 break;
             if (!greet->textMessage( arr, true ))
-                static_cast< LockProcess* >(parent())->msgBox( QMessageBox::Warning, QString::fromLocal8Bit( arr ) );
+                static_cast< LockProcess* >(parent())->msgBox( this, QMessageBox::Warning, QString::fromLocal8Bit( arr ) );
             ::free( arr );
             continue;
         }
@@ -444,7 +411,7 @@ void PasswordDlg::gplugSetUser( const QString & )
 void PasswordDlg::cantCheck()
 {
     greet->failed();
-    static_cast< LockProcess* >(parent())->msgBox( QMessageBox::Critical,
+    static_cast< LockProcess* >(parent())->msgBox( this, QMessageBox::Critical,
         i18n("Cannot unlock the session because the authentication system failed to work;\n"
              "you must kill krunner_lock (pid %1) manually.", getpid()) );
     greet->revive();
@@ -472,7 +439,8 @@ void PasswordDlg::gplugStart()
     if (!sPid) {
         ::close(sfd[0]);
         sprintf(fdbuf, "%d", sfd[1]);
-        execlp("kcheckpass", "kcheckpass",
+        execlp(QFile::encodeName(KStandardDirs::findExe("kcheckpass")).data(),
+               "kcheckpass",
 #ifdef HAVE_PAM
                "-c", KSCREENSAVER_PAM_SERVICE,
 #endif
@@ -493,29 +461,7 @@ void PasswordDlg::gplugActivity()
 
 void PasswordDlg::gplugMsgBox( QMessageBox::Icon type, const QString &text )
 {
-    QDialog dialog( this, Qt::X11BypassWindowManagerHint );
-    dialog.setModal( true );
-    QFrame *winFrame = new QFrame( &dialog );
-    winFrame->setFrameStyle( QFrame::WinPanel | QFrame::Raised );
-    winFrame->setLineWidth( 2 );
-    QVBoxLayout *vbox = new QVBoxLayout( &dialog );
-    vbox->addWidget( winFrame );
-
-    QLabel *label1 = new QLabel( winFrame );
-    label1->setPixmap( QMessageBox::standardIcon( type ) );
-    QLabel *label2 = new QLabel( text, winFrame );
-    KPushButton *button = new KPushButton( KStandardGuiItem::ok(), winFrame );
-    button->setDefault( true );
-    button->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Preferred ) );
-    connect( button, SIGNAL( clicked() ), SLOT( accept() ) );
-
-    QGridLayout *grid = new QGridLayout( winFrame );
-    grid->setSpacing( 10 );
-    grid->addWidget( label1, 0, 0, Qt::AlignCenter );
-    grid->addWidget( label2, 0, 1, Qt::AlignCenter );
-    grid->addWidget( button, 1, 0, 1, 2, Qt::AlignCenter );
-
-    static_cast< LockProcess* >(parent())->execDialog( &dialog );
+    static_cast< LockProcess* >(parent())->msgBox( this, type, text );
 }
 
 bool PasswordDlg::gplugHasNode( const QString & )
@@ -547,22 +493,22 @@ void PasswordDlg::slotStartNewSession()
     killTimer(mTimeoutTimerId);
     mTimeoutTimerId = 0;
 
-    QDialog *dialog = new QDialog( this, Qt::X11BypassWindowManagerHint );
-    dialog->setObjectName( "warnbox" );
+    KDialog *dialog = new KDialog( this, Qt::X11BypassWindowManagerHint );
     dialog->setModal( true );
-    QFrame *winFrame = new QFrame( dialog );
-    winFrame->setFrameStyle( QFrame::WinPanel | QFrame::Raised );
-    winFrame->setLineWidth( 2 );
-    QVBoxLayout *vbox = new QVBoxLayout( dialog );
-    vbox->addWidget( winFrame );
+    dialog->setButtons( KDialog::Yes | KDialog::No );
+    dialog->showButtonSeparator( true );
+    dialog->setButtonGuiItem( KDialog::Yes, KGuiItem(i18n("&Start New Session"), "fork") );
+    dialog->setButtonGuiItem( KDialog::No, KStandardGuiItem::cancel() );
+    dialog->setDefaultButton( KDialog::Yes );
+    dialog->setEscapeButton( KDialog::No );
 
-    QLabel *label1 = new QLabel( winFrame );
-    label1->setPixmap( QMessageBox::standardIcon( QMessageBox::Warning ) );
-    QString qt_text =
+    bool dontAskAgain = false;
+
+    KMessageBox::createKMessageBox( dialog, QMessageBox::Warning,
           i18n("You have chosen to open another desktop session "
-               "instead of resuming the current one.<br />"
+               "instead of resuming the current one.\n"
                "The current session will be hidden "
-               "and a new login screen will be displayed.<br />"
+               "and a new login screen will be displayed.\n"
                "An F-key is assigned to each session; "
                "F%1 is usually assigned to the first session, "
                "F%2 to the second session and so on. "
@@ -570,79 +516,17 @@ void PasswordDlg::slotStartNewSession()
                "Ctrl, Alt and the appropriate F-key at the same time. "
                "Additionally, the KDE Panel and Desktop menus have "
                "actions for switching between sessions.",
-             7, 8);
-    QLabel *label2 = new QLabel( qt_text, winFrame );
-    KPushButton *okbutton = new KPushButton( KGuiItem(i18n("&Start New Session"), "fork"), winFrame );
-    okbutton->setDefault( true );
-    connect( okbutton, SIGNAL( clicked() ), dialog, SLOT( accept() ) );
-    KPushButton *cbutton = new KPushButton( KStandardGuiItem::cancel(), winFrame );
-    connect( cbutton, SIGNAL( clicked() ), dialog, SLOT( reject() ) );
-
-    QBoxLayout *mbox = new QVBoxLayout( winFrame );
-    mbox->setMargin( KDialog::marginHint() );
-    mbox->setSpacing( KDialog::spacingHint() );
-
-    QGridLayout *grid = new QGridLayout();
-    mbox->addItem( grid );
-    grid->setSpacing( 2 * KDialog::spacingHint() );
-    grid->setMargin( KDialog::marginHint() );
-    grid->addWidget( label1, 0, 0, Qt::AlignCenter );
-    grid->addWidget( label2, 0, 1, Qt::AlignCenter );
-    QCheckBox *cb = new QCheckBox( i18n("&Do not ask again"), winFrame );
-    grid->addWidget( cb, 1, 0, 1, 2 );
-
-    QBoxLayout *hbox = new QHBoxLayout( );
-    mbox->addItem(hbox);
-    hbox->setSpacing( KDialog::spacingHint() );
-    hbox->addStretch( 1 );
-    hbox->addWidget( okbutton );
-    hbox->addStretch( 1 );
-    hbox->addWidget( cbutton );
-    hbox->addStretch( 1 );
-
-    // stolen from kmessagebox
-    int pref_width = 0;
-    int pref_height = 0;
-    // Calculate a proper size for the text.
-    {
-       Q3SimpleRichText rt(qt_text, dialog->font());
-       QRect rect = KGlobalSettings::desktopGeometry(dialog);
-
-       pref_width = rect.width() / 3;
-       rt.setWidth(pref_width);
-       int used_width = rt.widthUsed();
-       pref_height = rt.height();
-       if (used_width <= pref_width)
-       {
-          while(true)
-          {
-             int new_width = (used_width * 9) / 10;
-             rt.setWidth(new_width);
-             int new_height = rt.height();
-             if (new_height > pref_height)
-                break;
-             used_width = rt.widthUsed();
-             if (used_width > new_width)
-                break;
-          }
-          pref_width = used_width;
-       }
-       else
-       {
-          if (used_width > (pref_width *2))
-             pref_width = pref_width *2;
-          else
-             pref_width = used_width;
-       }
-    }
-    label2->setFixedSize(QSize(pref_width+10, pref_height));
+             7, 8),
+        QStringList(),
+        i18n("&Do not ask again"), &dontAskAgain,
+        KMessageBox::NoExec );
 
     int ret = static_cast< LockProcess* >( parent())->execDialog( dialog );
 
     delete dialog;
 
-    if (ret == QDialog::Accepted) {
-        if (cb->isChecked())
+    if (ret == KDialog::Yes) {
+        if (dontAskAgain)
             KMessageBox::saveDontShowAgainContinue( ":confirmNewSession" );
         DM().startReserve();
     }
@@ -670,15 +554,9 @@ void PasswordDlg::slotSwitchUser()
     DM dm;
 
     QDialog dialog( this, Qt::X11BypassWindowManagerHint );
-    dialog.setObjectName( "sessbox" );
     dialog.setModal( true );
-    QFrame *winFrame = new QFrame( &dialog );
-    winFrame->setFrameStyle( QFrame::WinPanel | QFrame::Raised );
-    winFrame->setLineWidth( 2 );
-    QBoxLayout *vbox = new QVBoxLayout( &dialog );
-    vbox->addWidget( winFrame );
 
-    QBoxLayout *hbox = new QHBoxLayout( winFrame );
+    QBoxLayout *hbox = new QHBoxLayout( &dialog );
     hbox->setSpacing( KDialog::spacingHint() );
     hbox->setMargin( KDialog::marginHint() );
 
@@ -694,7 +572,7 @@ void PasswordDlg::slotSwitchUser()
     SessList sess;
     if (dm.localSessions( sess )) {
 
-        lv = new Q3ListView( winFrame );
+        lv = new Q3ListView( &dialog );
         connect( lv, SIGNAL(doubleClicked(Q3ListViewItem *, const QPoint&, int)), SLOT(slotSessionActivated()) );
         connect( lv, SIGNAL(doubleClicked(Q3ListViewItem *, const QPoint&, int)), &dialog, SLOT(reject()) );
         lv->setAllColumnsShowFocus( true );
@@ -725,7 +603,7 @@ void PasswordDlg::slotSwitchUser()
         lv->header()->adjustHeaderSize();
         vbox1->addWidget( lv );
 
-        btn = new KPushButton( KGuiItem(i18nc("session", "&Activate"), "fork"), winFrame );
+        btn = new KPushButton( KGuiItem(i18nc("session", "&Activate"), "fork"), &dialog );
         connect( btn, SIGNAL(clicked()), SLOT(slotSessionActivated()) );
         connect( btn, SIGNAL(clicked()), &dialog, SLOT(reject()) );
         vbox2->addWidget( btn );
@@ -734,7 +612,7 @@ void PasswordDlg::slotSwitchUser()
 
     if (KAuthorized::authorizeKAction("start_new_session") && (p = dm.numReserve()) >= 0)
     {
-        btn = new KPushButton( KGuiItem(i18n("Start &New Session"), "fork"), winFrame );
+        btn = new KPushButton( KGuiItem(i18n("Start &New Session"), "fork"), &dialog );
         connect( btn, SIGNAL(clicked()), SLOT(slotStartNewSession()) );
         connect( btn, SIGNAL(clicked()), &dialog, SLOT(reject()) );
         if (!p)
@@ -743,7 +621,7 @@ void PasswordDlg::slotSwitchUser()
         vbox2->addStretch( 1 );
     }
 
-    btn = new KPushButton( KStandardGuiItem::cancel(), winFrame );
+    btn = new KPushButton( KStandardGuiItem::cancel(), &dialog );
     connect( btn, SIGNAL(clicked()), &dialog, SLOT(reject()) );
     vbox2->addWidget( btn );
 
