@@ -65,7 +65,7 @@ protected:
     virtual void timerEvent(QTimerEvent *);
 
 private Q_SLOTS:
-    void hackExited(K3Process *);
+    void hackExited();
     void signalPipeSignal();
     bool startLock();
     void suspend();
@@ -102,8 +102,6 @@ private:
     int         mPriority;
     bool        mBusy;
     K3Process    mHackProc;
-    int         mRootWidth;
-    int         mRootHeight;
     QString     mSaverExec;
     QString     mSaver;
     bool        mOpenGLVisual;
