@@ -8,22 +8,20 @@
 // KDE screensaver engine
 //
 
-#include "xautolock.h"
-
 #include <config-workspace.h>
-#include <config-xautolock.h>
-#include "xautolock.moc"
 
-#include <X11/Xlib.h>
-#include <X11/Xutil.h>
-#include <ctime>
+#include "xautolock.h"
 #include "xautolock_c.h"
 
 #include <kapplication.h>
+#include <kdebug.h>
 
 #include <QTimerEvent>
 #include <QX11Info>
 
+#include <X11/Xlib.h>
+#include <X11/Xutil.h>
+
 #ifdef HAVE_DPMS
 extern "C" {
 #include <X11/Xmd.h>
@@ -38,16 +36,21 @@ Status DPMSInfo ( Display *, CARD16 *, BOOL * );
 }
 #endif
 
-int xautolock_useXidle = 0;
-int xautolock_useMit = 0;
+#include <ctime>
+
+#ifdef HAVE_XSCREENSAVER
+int xautolock_useMit;
+#endif
 xautolock_corner_t xautolock_corners[ 4 ];
 
 static XAutoLock* self = NULL;
 
+extern "C" {
 static int catchFalseAlarms(Display *, XErrorEvent *)
 {
     return 0;
 }
+}
 
 //===========================================================================
 //
@@ -57,18 +60,11 @@ static int catchFalseAlarms(Display *, XErrorEvent *)
 XAutoLock::XAutoLock()
 {
     self = this;
-    int dummy = 0;
-    dummy = dummy; // shut up
-    xautolock_useXidle = 0;
-    xautolock_useMit = 0;
-#ifdef HAVE_XIDLE
-    useXidle = XidleQueryExtension( QX11Info::display(), &dummy, &dummy );
+#ifdef HAVE_XSCREENSAVER
+    int dummy;
+    xautolock_useMit = XScreenSaverQueryExtension( QX11Info::display(), &dummy, &dummy );
 #endif
-#ifdef HAVE_SCREENSAVER
-    if( !xautolock_useXidle )
-        xautolock_useMit = XScreenSaverQueryExtension( QX11Info::display(), &dummy, &dummy );
-#endif
-    if( !xautolock_useXidle && !xautolock_useMit )
+    if( !xautolock_useMit )
     {
         kapp->installX11EventFilter( this );
         int (*oldHandler)(Display *, XErrorEvent *);
@@ -96,7 +92,8 @@ XAutoLock::XAutoLock()
 //
 XAutoLock::~XAutoLock()
 {
-  self = NULL;
+    stop();
+    self = NULL;
 }
 
 //---------------------------------------------------------------------------
@@ -106,11 +103,17 @@ XAutoLock::~XAutoLock()
 void XAutoLock::setTimeout(int t)
 {
     mTimeout = t;
-    resetTrigger();
 }
 
 void XAutoLock::setDPMS(bool s)
 {
+#ifdef HAVE_DPMS
+    BOOL on;
+    CARD16 state;
+    DPMSInfo( QX11Info::display(), &state, &on );
+    if (!on)
+        s = false;
+#endif
     mDPMS = s;
 }
 
@@ -120,9 +123,11 @@ void XAutoLock::setDPMS(bool s)
 //
 void XAutoLock::start()
 {
-    resetTrigger();
     time(&mLastTimeout);
     mActive = true;
+    resetTrigger();
+    XSetScreenSaver(QX11Info::display(), mTimeout + 10, 100, PreferBlanking, DontAllowExposures); // We'll handle blanking
+    kDebug() << "XSetScreenSaver" << mTimeout + 10;
 }
 
 //---------------------------------------------------------------------------
@@ -132,6 +137,9 @@ void XAutoLock::start()
 void XAutoLock::stop()
 {
     mActive = false;
+    resetTrigger();
+    XSetScreenSaver(QX11Info::display(), 0, 100, PreferBlanking, DontAllowExposures); // No blanking at all
+    kDebug() << "XSetScreenSaver 0";
 }
 
 //---------------------------------------------------------------------------
@@ -142,6 +150,7 @@ void XAutoLock::resetTrigger()
 {
     mLastReset = time( 0 );
     mTrigger = mLastReset + mTimeout;
+    XForceScreenSaver( QX11Info::display(), ScreenSaverReset );
 }
 
 //---------------------------------------------------------------------------
@@ -175,7 +184,7 @@ void XAutoLock::timerEvent(QTimerEvent *ev)
     }
 
     int (*oldHandler)(Display *, XErrorEvent *) = NULL;
-    if( !xautolock_useXidle && !xautolock_useMit )
+    if( !xautolock_useMit )
     { // only the diy way needs special X handler
         XSync( QX11Info::display(), False );
         oldHandler = XSetErrorHandler(catchFalseAlarms);
@@ -198,7 +207,7 @@ void XAutoLock::timerEvent(QTimerEvent *ev)
     xautolock_queryIdleTime( QX11Info::display());
     xautolock_queryPointer( QX11Info::display());
 
-    if( !xautolock_useXidle && !xautolock_useMit )
+    if( !xautolock_useMit )
         XSetErrorHandler(oldHandler);
 
     bool activate = false;
@@ -224,18 +233,17 @@ void XAutoLock::timerEvent(QTimerEvent *ev)
         activate = true;
     if(!on && mDPMS) {
         activate = false;
-        XForceScreenSaver( QX11Info::display(), ScreenSaverReset );
         resetTrigger();
     }
 #endif
 
-#ifdef HAVE_SCREENSAVER
+#ifdef HAVE_XSCREENSAVER
     static XScreenSaverInfo* mitInfo = 0;
     if (!mitInfo) mitInfo = XScreenSaverAllocInfo ();
     if (XScreenSaverQueryInfo (QX11Info::display(), QX11Info::appRootWindow(), mitInfo)) {
         // kDebug() << "XScreenSaverQueryInfo " << mitInfo->state << ScreenSaverDisabled;
         if (mitInfo->state == ScreenSaverDisabled)
-	    activate = false;
+            activate = false;
     }
 #endif
 
@@ -248,7 +256,7 @@ bool XAutoLock::x11Event( XEvent* ev )
     xautolock_processEvent( ev );
 // don't futher process key events that were received only because XAutoLock wants them
     if( ev->type == KeyPress && !ev->xkey.send_event
-        && !xautolock_useXidle && !xautolock_useMit
+        && !xautolock_useMit
         && !QWidget::find( ev->xkey.window ))
         return true;
     return false;
@@ -283,3 +291,5 @@ int xautolock_ignoreWindow( Window w )
 {
    return self->ignoreWindow( w );
 }
+
+#include "xautolock.moc"
