@@ -72,6 +72,15 @@ public:
     }
 
 protected:
+    virtual bool eventFilter( QObject *, QEvent *e )
+    {
+        if (e->type() == QEvent::KeyPress) {
+            keyPressEvent( (QKeyEvent *)e );
+            return true;
+        }
+        return false;
+    }
+
     virtual void keyPressEvent(QKeyEvent *e)
     {
         if (e->text() == QLatin1String("q"))
@@ -163,18 +172,21 @@ int kScreenSaverMain( int argc, char** argv, KScreenSaverInterface& screenSaverI
     if (saveWin == 0)
     {
         demoWidget = new DemoWindow();
-        demoWidget->setAttribute(Qt::WA_OpaquePaintEvent);
-        saveWin = demoWidget->winId();
+        demoWidget->setAttribute(Qt::WA_NoSystemBackground);
+        demoWidget->setAttribute(Qt::WA_PaintOnScreen);
+        demoWidget->show();
         app.processEvents();
+        saveWin = demoWidget->winId();
     }
 
     target = screenSaverInterface.create( saveWin );
+    target->show();
 
-    if ( demoWidget )
+    if (demoWidget)
     {
-        demoWidget->setFixedSize( 600, 420 );
-        demoWidget->show();
+        target->installEventFilter( demoWidget );
     }
+
     args->clear();
     app.exec();
 
