@@ -31,7 +31,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <string.h>
 
 #include <KMessageBox>
-#include <QDir>
 #include <QtDBus/QtDBus>
 
 #include <kapplication.h>
@@ -42,6 +41,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <klocale.h>
 #include <kglobal.h>
 #include <kconfig.h>
+#include <kmanagerselection.h>
 #include "server.h"
 #include <QX11Info>
 
@@ -181,11 +181,10 @@ void sanity_check( int argc, char* argv[] )
         fputs(msg_post, stderr);
 
         QApplication a(argc, argv);
-        Q3CString qmsg(256+path.length());
-        qmsg.sprintf(msg.data(), path.data());
+        QString qmsg = QString::fromLatin1(msg); // no translations possible yet...
+        qmsg.replace("%s", path);
         qmsg = msg_pre+qmsg+msg_post;
-        KMessageBox::error(0, "KDE Installation Problem!",
-            QLatin1String(qmsg.data()));
+        KMessageBox::error(0, "KDE Installation Problem!", qmsg);
         exit(255);
     }
 }
@@ -239,6 +238,10 @@ extern "C" KDE_EXPORT int kdemain( int argc, char* argv[] )
 #endif
 
     KSMServer *server = new KSMServer( wm, only_local);
+    
+    // for the KDE-already-running check in startkde
+    KSelectionOwner kde_running( "_KDE_RUNNING", 0 );
+    kde_running.claim( false );
 
     IceSetIOErrorHandler( IoErrorHandler );
 
