@@ -107,7 +107,7 @@ void KSMServer::startApplication( QStringList& command, const QString& clientMac
             command.prepend( "--" );
             command.prepend( userId );
             command.prepend( "-u" );
-            command.prepend( "kdesu" );
+            command.prepend( KStandardDirs::findExe("kdesu") );
         }
     }
     if ( !clientMachine.isEmpty() && clientMachine != "localhost" ) {
@@ -887,7 +887,7 @@ void KSMServer::storeSession()
     }
     cg.writeEntry( "count", count );
 
-	KConfigGroup cg2( config, "General");
+    KConfigGroup cg2( config, "General");
     cg2.writeEntry( "screenCount", ScreenCount(QX11Info::display()));
 
     storeLegacySession(config.data());
