@@ -44,9 +44,8 @@ class KSMShutdownFeedback : public QWidget
     Q_OBJECT
 
 public:
-    static void start() { s_pSelf = new KSMShutdownFeedback(); s_pSelf->show(); }
-    static void stop() { delete s_pSelf; s_pSelf = 0L; }
-    static KSMShutdownFeedback * self() { return s_pSelf; }
+    static void start();
+    static void stop();
 
 protected:
     ~KSMShutdownFeedback() {}
@@ -68,7 +67,7 @@ class KSMPushButton : public QPushButton
     Q_OBJECT
 
 public:
-    explicit KSMPushButton( const QString &text, QWidget *parent = 0 );
+    explicit KSMPushButton( const QString &text, QWidget *parent = 0, bool smallButton = false );
 
     void setPixmap( const QPixmap & );
     void setPopupMenu( QMenu * );
@@ -93,6 +92,7 @@ private:
     Plasma::Svg* m_glowSvg;
     qreal m_glowOpacity;
     QTimeLine *m_glowTimeLine;
+    bool m_smallButton;
 };
 
 // The confirmation dialog
@@ -107,8 +107,8 @@ public Q_SLOTS:
     void slotLogout();
     void slotHalt();
     void slotReboot();
-    void slotReboot(int);
-    void slotSuspend(int);
+    void slotReboot(QAction*);
+    void slotSuspend(QAction*);
 
 protected:
     ~KSMShutdownDlg() {}
