@@ -1,11 +1,12 @@
 /*
     KSysGuard, the KDE System Guard
 
-  Copyright (c) 2001 Tobias Koenig <tokoe@kde.org>
+    Copyright (c) 2001 Tobias Koenig <tokoe@kde.org>
 
     This program is free software; you can redistribute it and/or
-    modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    modify it under the terms of the GNU General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -26,6 +27,7 @@
 #include <QtGui/QHeaderView>
 #include <QtGui/QMenu>
 #include <QtGui/QTreeView>
+#include <QtGui/QHBoxLayout>
 #include <QtXml/QDomNodeList>
 #include <QtXml/QDomDocument>
 #include <QtXml/QDomElement>
@@ -35,6 +37,7 @@
 #include <klocale.h>
 #include <knotification.h>
 #include <ksgrd/SensorManager.h>
+#include <kdebug.h>
 #include "StyleEngine.h"
 
 #include "SensorLoggerDlg.h"
@@ -402,8 +405,15 @@ SensorLogger::SensorLogger( QWidget *parent, const QString& title, SharedSetting
   mModel->setForegroundColor( KSGRD::Style->firstForegroundColor() );
   mModel->setBackgroundColor( KSGRD::Style->backgroundColor() );
   mModel->setAlarmColor( KSGRD::Style->alarmColor() );
-
+  
+  QLayout *layout = new QHBoxLayout(this);
   mView = new LogSensorView( this );
+  layout->addWidget(mView);
+  setLayout(layout);
+
+  mView->setContextMenuPolicy( Qt::CustomContextMenu );
+  connect(mView, SIGNAL(customContextMenuRequested(const QPoint&)), SLOT(showContextMenu(const QPoint &)));
+
   mView->header()->setStretchLastSection( true );
   mView->setRootIsDecorated( false );
   mView->setItemsExpandable( false );
@@ -576,11 +586,6 @@ void SensorLogger::answerReceived( int, const QList<QByteArray>& ) //virtual
  // we do not use this, since all answers are received by the LogSensors
 }
 
-void SensorLogger::resizeEvent(QResizeEvent*)
-{
-  mView->setGeometry( 10, 20, this->width() - 20, this->height() - 30 );
-}
-
 void SensorLogger::contextMenuRequest( const QModelIndex &index, const QPoint &point )
 {
   LogSensor *sensor = mModel->sensor( index );
@@ -592,20 +597,23 @@ void SensorLogger::contextMenuRequest( const QModelIndex &index, const QPoint &p
     action = pm.addAction(i18n("&Properties"));
     action->setData( 1 );
   }
-  action = pm.addAction(i18n("&Remove Display"));
-  action->setData( 2 );
+  if(!mSharedSettings->locked) {  
 
-  pm.addSeparator();
+    action = pm.addAction(i18n("&Remove Display"));
+    action->setData( 2 );
 
-  action = pm.addAction(i18n("&Remove Sensor"));
-  action->setData( 3 );
-  if ( !sensor )
-    action->setEnabled( false );
+    pm.addSeparator();
 
-  action = pm.addAction(i18n("&Edit Sensor..."));
-  action->setData( 4 );
-  if ( !sensor )
-    action->setEnabled( false );
+    action = pm.addAction(i18n("&Remove Sensor"));
+    action->setData( 3 );
+    if ( !sensor )
+      action->setEnabled( false );
+
+    action = pm.addAction(i18n("&Edit Sensor..."));
+    action->setData( 4 );
+    if ( !sensor )
+      action->setEnabled( false );
+  }
 
   if ( sensor ) {
     if ( sensor->isLogging() ) {
