@@ -5,8 +5,9 @@
     Copyright (c) 2006 John Tapsell <tapsell@kde.org>
 
     This program is free software; you can redistribute it and/or
-    modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    modify it under the terms of the GNU General Public
+    License version 2 or at your option version 3 as published by
+    the Free Software Foundation.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,10 +37,9 @@
 #include "Workspace.h"
 
 Workspace::Workspace( QWidget* parent)
-  : QTabWidget( parent )
+  : KTabWidget( parent )
 {
   KAcceleratorManager::setNoAccel(this);
-
   this->setWhatsThis( i18n( "This is your work space. It holds your worksheets. You need "
                                "to create a new worksheet (Menu File->New) before "
                                "you can drag sensors here." ) );
@@ -61,8 +61,7 @@ void Workspace::saveProperties( KConfigGroup& cfg )
 
 void Workspace::readProperties( const KConfigGroup& cfg )
 {
-  kDebug() << "Reading from " << cfg.name();
-  QStringList selectedSheets = cfg.readPathListEntry( "SelectedSheets" );
+  QStringList selectedSheets = cfg.readPathEntry( "SelectedSheets", QStringList() );
   kDebug() << "Selected Sheets = " << selectedSheets;
 
   if ( selectedSheets.isEmpty() ) {
@@ -138,7 +137,7 @@ void Workspace::updateSheetTitle( QWidget* wdg )
 {
   kDebug() << "update sheet title";
   if ( wdg )
-    setTabText( indexOf(wdg), static_cast<WorkSheet*>( wdg )->title() );
+    setTabText( indexOf(wdg), static_cast<WorkSheet*>( wdg )->translatedTitle() );
 }
 
 bool Workspace::saveOnQuit()
@@ -281,7 +280,7 @@ bool Workspace::restoreWorkSheet( const QString &fileName, bool switchToTab)
   connect( sheet, SIGNAL( titleChanged( QWidget* ) ),
     SLOT( updateSheetTitle( QWidget* )));
 
-  insertTab(-1, sheet, sheet->title() );
+  insertTab(-1, sheet, sheet->translatedTitle() );
   if(switchToTab)
    setCurrentIndex(indexOf(sheet));
 
