@@ -4,7 +4,7 @@
     Copyright (c) 2006 Greg Martyn <greg.martyn@gmail.com>
 
     This program is free software; you can redistribute it and/or
-    modify it under the terms of version 2 of the GNU General Public
+    modify it under the terms of version 2 or later of the GNU General Public
     License as published by the Free Software Foundation.
 
     This program is distributed in the hope that it will be useful,
@@ -80,12 +80,7 @@ static struct timeval currSampling;
 static struct SensorModul* StatSM;
 
 static DiskLoadInfo* DiskLoad = 0;
-static unsigned DiskCount = 0;
 static DiskIOInfo* DiskIO = 0;
-static unsigned long PageIn = 0;
-static unsigned long OldPageIn = 0;
-static unsigned long PageOut = 0;
-static unsigned long OldPageOut = 0;
 
 static char IOStatBuf[ DISKSTATSBUFSIZE ];	/* Buffer for /proc/diskstats */
 static int Dirty = 0;
@@ -101,7 +96,11 @@ void initDiskstats( struct SensorModul* sm ) {
 	StatSM = sm;
 	sprintf( format, "%%%d[^\n]\n", (int)sizeof( buf ) - 1 );
 
-	updateDiskstats(); /* reopens /proc/diskstats as IOStatBuf */
+	/* updateDiskstats() reopens /proc/diskstats as IOStatBuf */
+	if (updateDiskstats()) {
+		/* updateDiskstats() was unable to open file. die. */
+		return;
+	}
 
 	/* Process values from /proc/diskstats (Linux >= 2.6.x) */
 	while (sscanf(iostatBufP, format, buf) == 1) {
@@ -127,17 +126,15 @@ int updateDiskstats( void ) {
 
 	IOStatBuf[ 0 ] = '\0';
 	if ( ( fd = open( "/proc/diskstats", O_RDONLY ) ) < 0 )
-		return 0; /* failure is okay, only exists for Linux >= 2.6.x */
+		return -1; /* unable to open file. disable this module. */
 	
 	n = read( fd, IOStatBuf, DISKSTATSBUFSIZE - 1 );
+	close( fd );
 	if ( n == DISKSTATSBUFSIZE - 1 || n <= 0 ) {
-		log_error( "Internal buffer too small to read \'/proc/diskstats\'" );
-	
-		close( fd );
+		log_error( "Internal buffer too small to read \'/proc/diskstats\'" );		
 		return -1;
 	}
 	
-	close( fd );
 	IOStatBuf[ n ] = '\0';
 
 	return 0;
