@@ -381,28 +381,39 @@ void Client::destroyDecoration()
         }
     }
 
-void Client::checkBorderSizes()
+bool Client::checkBorderSizes( bool also_resize )
     {
     if( decoration == NULL )
-        return;
+        return false;
     int new_left, new_right, new_top, new_bottom;
     decoration->borders( new_left, new_right, new_top, new_bottom );
     if( new_left == border_left && new_right == border_right
         && new_top == border_top && new_bottom == border_bottom )
-        return;
+        return false;
+    if( !also_resize )
+        {
+        border_left = new_left;
+        border_right = new_right;
+        border_top = new_top;
+        border_bottom = new_bottom;
+        return true;
+        }
     GeometryUpdatesBlocker blocker( this );
     move( calculateGravitation( true ));
     border_left = new_left;
     border_right = new_right;
     border_top = new_top;
     border_bottom = new_bottom;
-    if (border_left != new_left ||
-        border_right != new_right ||
-        border_top != new_top ||
-        border_bottom != new_bottom)
     move( calculateGravitation( false ));
     plainResize( sizeForClientSize( clientSize()), ForceGeometrySet );
     checkWorkspacePosition();
+    return true;
+    }
+
+void Client::repaintDecoration()
+    {
+    if( decoration != NULL )
+        decoration->widget()->update();
     }
 
 void Client::detectNoBorder()
@@ -1089,7 +1100,7 @@ void Client::gotPing( Time timestamp )
 void Client::pingTimeout()
     {
     kDebug( 1212 ) << "Ping timeout:" << caption();
-    delete ping_timer;
+    ping_timer->deleteLater();
     ping_timer = NULL;
     killProcess( true, ping_timestamp );
     }
@@ -1249,11 +1260,13 @@ void Client::takeActivity( int flags, bool handled, allowed_t )
 #ifndef NDEBUG
     static Time previous_activity_timestamp;
     static Client* previous_client;
+#if 0
     if( previous_activity_timestamp == xTime() && previous_client != this )
         {
         kDebug( 1212 ) << "Repeated use of the same X timestamp for activity";
         kDebug( 1212 ) << kBacktrace();
         }
+#endif
     previous_activity_timestamp = xTime();
     previous_client = this;
 #endif
@@ -1266,11 +1279,13 @@ void Client::takeFocus( allowed_t )
 #ifndef NDEBUG
     static Time previous_focus_timestamp;
     static Client* previous_client;
+#if 0
     if( previous_focus_timestamp == xTime() && previous_client != this )
         {
         kDebug( 1212 ) << "Repeated use of the same X timestamp for focus";
         kDebug( 1212 ) << kBacktrace();
         }
+#endif
     previous_focus_timestamp = xTime();
     previous_client = this;
 #endif
