@@ -133,6 +133,7 @@ class Client
 
     // !isMinimized() && not hidden, i.e. normally visible on some virtual desktop
         bool isShown( bool shaded_is_shown ) const;
+        bool isHiddenInternal() const; // for compositing
 
         bool isShade() const; // true only for ShadeNormal
         ShadeMode shadeMode() const; // prefer isShade()
@@ -194,7 +195,8 @@ class Client
         QRegion mask() const;
 
         void updateDecoration( bool check_workspace_pos, bool force = false );
-        void checkBorderSizes();
+        bool checkBorderSizes( bool also_resize );
+        void repaintDecoration();
 
         void updateShape();
         
@@ -618,6 +620,12 @@ bool Client::isShown( bool shaded_is_shown ) const
     return !isMinimized() && ( !isShade() || shaded_is_shown ) && !hidden;
     }
 
+inline
+bool Client::isHiddenInternal() const
+    {
+    return hidden;
+    }
+
 inline
 bool Client::isShade() const
     {
