@@ -1,12 +1,25 @@
-/*
- *	This file contains the B2 configuration widget
- *
- *	Copyright (c) 2001
- *		Karol Szwed <gallium@kde.org>
- *		http://gallium.n3.net/
- *	Copyright (c) 2007
- *		Luciano Montanaro <mikelima@cirulla.net>
- */
+/********************************************************************
+ 	This file contains the B2 configuration widget
+ 
+ 	Copyright (c) 2001
+ 		Karol Szwed <gallium@kde.org>
+ 		http://gallium.n3.net/
+ 	Copyright (c) 2007
+ 		Luciano Montanaro <mikelima@cirulla.net>
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #include "config.h"
 #include <kglobal.h>
