@@ -1,17 +1,30 @@
-/*
- *
- *	KDE2 Default KWin client
- *
- *	Copyright (C) 1999, 2001 Daniel Duley <mosfet@kde.org>
- *	Matthias Ettrich <ettrich@kde.org>
- *	Karol Szwed <gallium@kde.org>
- *
- *	Draws mini titlebars for tool windows.
- *	Many features are now customizable.
- *
- *	drawColorBitmaps orignally from kdefx:
- *	  Copyright (C) 1999 Daniel M. Duley <mosfet@kde.org>
- */
+/*********************************************************************
+ 
+ 	KDE2 Default KWin client
+ 
+ 	Copyright (C) 1999, 2001 Daniel Duley <mosfet@kde.org>
+ 	Matthias Ettrich <ettrich@kde.org>
+ 	Karol Szwed <gallium@kde.org>
+ 
+ 	Draws mini titlebars for tool windows.
+ 	Many features are now customizable.
+ 
+ 	drawColorBitmaps orignally from kdefx:
+ 	  Copyright (C) 1999 Daniel M. Duley <mosfet@kde.org>
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #include "kde2.h"
 
@@ -187,7 +200,7 @@ KDE2Handler::~KDE2Handler()
 
 KDecoration* KDE2Handler::createDecoration( KDecorationBridge* b )
 {
-	return new KDE2Client( b, this );
+	return ( new KDE2Client( b, this ))->decoration();
 }
 
 bool KDE2Handler::reset( unsigned long changed )
@@ -218,8 +231,8 @@ unsigned long KDE2Handler::readConfig( bool update )
 	bool new_showGrabBar 		= conf.readEntry("ShowGrabBar", true);
 	bool new_showTitleBarStipple = conf.readEntry("ShowTitleBarStipple", true);
 	bool new_useGradients 		= conf.readEntry("UseGradients", true);
-	int  new_titleHeight 		= QFontMetrics(options()->font(true)).height();
-	int  new_toolTitleHeight 	= QFontMetrics(options()->font(true, true)).height()-2;
+	int  new_titleHeight 		= QFontMetrics(options()->font(true)).height() - 2;
+	int  new_toolTitleHeight 	= QFontMetrics(options()->font(true, true)).height() - 4;
 
 	int new_borderWidth;
 	switch(options()->preferredBorderSize(this)) {
@@ -351,30 +364,34 @@ void KDE2Handler::createPixmaps()
 
 	// Active pins
 	g = options()->palette( ColorButtonBg, true );
-	pinUpPix  = new QPixmap(16, 16);
-	p.begin( pinUpPix );
+	QImage pinUpImg  = QImage(16, 16, QImage::Format_ARGB32_Premultiplied);
+	p.begin( &pinUpImg );
     drawColorBitmaps( &p, g, 0, 0, 16, 16, pinup_white_bits, pinup_gray_bits, pinup_dgray_bits );
 	p.end();
+	pinUpPix = new QPixmap(QPixmap::fromImage(pinUpImg));
 	pinUpPix->setMask( QBitmap::fromData(QSize( 16, 16 ), pinup_mask_bits) );
 
-	pinDownPix = new QPixmap(16, 16);
-	p.begin( pinDownPix );
+	QImage pinDownImg  = QImage(16, 16, QImage::Format_ARGB32_Premultiplied);
+	p.begin( &pinDownImg );
     drawColorBitmaps( &p, g, 0, 0, 16, 16, pindown_white_bits, pindown_gray_bits, pindown_dgray_bits );
 	p.end();
+	pinDownPix = new QPixmap(QPixmap::fromImage(pinDownImg));
 	pinDownPix->setMask( QBitmap::fromData(QSize( 16, 16 ), pindown_mask_bits) );
 
 	// Inactive pins
 	g = options()->palette( ColorButtonBg, false );
-	ipinUpPix = new QPixmap(16, 16);
-	p.begin( ipinUpPix );
+	QImage ipinUpImg  = QImage(16, 16, QImage::Format_ARGB32_Premultiplied);
+	p.begin( &ipinUpImg );
     drawColorBitmaps( &p, g, 0, 0, 16, 16, pinup_white_bits, pinup_gray_bits, pinup_dgray_bits );
 	p.end();
+	ipinUpPix = new QPixmap(QPixmap::fromImage(ipinUpImg));
 	ipinUpPix->setMask( QBitmap::fromData(QSize( 16, 16 ), pinup_mask_bits) );
 
-	ipinDownPix = new QPixmap(16, 16);
-	p.begin( ipinDownPix );
+	QImage ipinDownImg  = QImage(16, 16, QImage::Format_ARGB32_Premultiplied);
+	p.begin( &ipinDownImg );
     drawColorBitmaps( &p, g, 0, 0, 16, 16, pindown_white_bits, pindown_gray_bits, pindown_dgray_bits );
 	p.end();
+	ipinDownPix = new QPixmap(QPixmap::fromImage(ipinDownImg));
 	ipinDownPix->setMask( QBitmap::fromData(QSize( 16, 16 ), pindown_mask_bits) );
 
 	// Create a title buffer for flicker-free painting
@@ -531,11 +548,14 @@ QList< KDE2Handler::BorderSize > KDE2Handler::borderSizes() const
       BorderVeryLarge <<  BorderHuge << BorderVeryHuge << BorderOversized;
 }
 
-bool KDE2Handler::supports( Ability ability )
+bool KDE2Handler::supports( Ability ability ) const
 {
     switch( ability )
         {
+        // announce
         case AbilityAnnounceButtons:
+        case AbilityAnnounceColors:
+        // buttons
         case AbilityButtonMenu:
         case AbilityButtonOnAllDesktops:
         case AbilityButtonSpacer:
@@ -546,6 +566,12 @@ bool KDE2Handler::supports( Ability ability )
         case AbilityButtonAboveOthers:
         case AbilityButtonBelowOthers:
         case AbilityButtonShade:
+        // colors
+        case AbilityColorTitleBack:
+        case AbilityColorTitleBlend:
+        case AbilityColorTitleFore:
+        case AbilityColorFrame:
+        case AbilityColorButtonBack:
             return true;
         default:
             return false;
@@ -750,16 +776,6 @@ QString KDE2Client::visibleName() const
 	return i18n("KDE 2");
 }
 
-QString KDE2Client::defaultButtonsLeft() const
-{
-	return "MS";
-}
-
-QString KDE2Client::defaultButtonsRight() const
-{
-	return "HIAX";
-}
-
 bool KDE2Client::decorationBehaviour(DecorationBehaviour behaviour) const
 {
 	switch (behaviour) {
@@ -809,10 +825,6 @@ int KDE2Client::layoutMetric(LayoutMetric lm, bool respectWindowState, const KCo
 		case LM_ButtonSpacing:
 			return 0;
 
-		case LM_ExplicitButtonSpacer:
-			if ( !isToolWindow() )
-				return borderWidth/2;
-			// fall through
 		default:
 			return KCommonDecoration::layoutMetric(lm, respectWindowState, btn);
 	}
@@ -1030,10 +1042,10 @@ void KDE2Client::paintEvent( QPaintEvent* )
 		(caption().isRightToLeft() ? Qt::AlignRight : Qt::AlignLeft) | Qt::AlignVCenter,
 		caption() );
 
-	bitBlt( widget(), 2, 2, titleBuffer );
-
     p2.end();
 
+    p.drawPixmap( 2, 2, *titleBuffer );
+
 	// Ensure a shaded window has no unpainted areas
 	// Is this still needed?
 #if 1
