@@ -1,10 +1,23 @@
-/*
- * Laptop KWin Decoration
- *
- * Copyright (c) 2005 Sandro Giessl <sandro@giessl.com>
- * Port of this decoration to KDE 3.2, accessibility enhancement are
- * Copyright (c) 2003 Luciano Montanaro <mikelima@cirulla.net>
- */
+/********************************************************************
+  Laptop KWin Decoration
+ 
+  Copyright (c) 2005 Sandro Giessl <sandro@giessl.com>
+  Port of this decoration to KDE 3.2, accessibility enhancement are
+  Copyright (c) 2003 Luciano Montanaro <mikelima@cirulla.net>
+ 
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #include <kconfig.h> // up here to avoid X11 header conflict :P
 #include "laptopclient.h"
@@ -117,7 +130,7 @@ static void create_pixmaps()
         return;
     pixmaps_created = true;
 
-    titleHeight = QFontMetrics(options()->font(true)).height() + 2;
+    titleHeight = QFontMetrics(options()->font(true)).height();
     if (titleHeight < handleSize) titleHeight = handleSize;
     titleHeight &= ~1; // Make title height even
     if (titleHeight < 14) titleHeight = 14;
@@ -419,9 +432,6 @@ int LaptopClient::layoutMetric(LayoutMetric lm, bool respectWindowState, const K
         case LM_ButtonSpacing:
             return 0;
 
-        case LM_ExplicitButtonSpacer:
-            return 0;
-
         default:
             return KCommonDecoration::layoutMetric(lm, respectWindowState, btn);
     }
@@ -562,7 +572,7 @@ void LaptopClient::paintEvent( QPaintEvent* )
         p.drawLine(r.right(), r.y(), r.right(), r.bottom());
         p.drawLine(r.x(), r.bottom(), r.right(), r.bottom());
         p.setPen(options()->color(KDecoration::ColorFont, false));
-        p.drawText(r.x(), r.y(), r.width(), r.height()-1,
+        p.drawText(r.x(), r.y()+1, r.width(), r.height()-1,
                    Qt::AlignCenter, caption() );
         g = options()->palette(KDecoration::ColorFrame, true);
         g.setCurrentColorGroup( QPalette::Active );
@@ -646,7 +656,7 @@ void LaptopClient::updateActiveBuffer( )
     p.drawLine(r.right(), r.y(), r.right(), r.bottom());
     p.drawLine(r.x(), r.bottom(), r.right(), r.bottom());
     p.setPen(options()->color(KDecoration::ColorFont, true));
-    p.drawText(r.x(), r.y(), r.width(), r.height()-1,
+    p.drawText(r.x(), r.y()+1, r.width(), r.height()-1,
                Qt::AlignCenter, caption() );
     g = options()->palette(KDecoration::ColorFrame, true);
     g.setCurrentColorGroup( QPalette::Active );
@@ -683,7 +693,7 @@ LaptopClientFactory::~LaptopClientFactory()
 KDecoration *LaptopClientFactory::createDecoration(KDecorationBridge *b)
 {
     findPreferredHandleSize();
-    return new Laptop::LaptopClient(b, this);
+    return (new Laptop::LaptopClient(b, this))->decoration();
 }
 
 bool LaptopClientFactory::reset(unsigned long changed)
@@ -709,16 +719,24 @@ bool LaptopClientFactory::reset(unsigned long changed)
     }
 }
 
-bool LaptopClientFactory::supports( Ability ability )
+bool LaptopClientFactory::supports( Ability ability ) const
 {
     switch( ability )
     {
+        // announce
         case AbilityAnnounceButtons:
+        case AbilityAnnounceColors:
+        // buttons
         case AbilityButtonOnAllDesktops:
         case AbilityButtonHelp:
         case AbilityButtonMinimize:
         case AbilityButtonMaximize:
         case AbilityButtonClose:
+        case AbilityButtonSpacer:
+        // colors
+        case AbilityColorTitleBack:
+        case AbilityColorTitleFore:
+        case AbilityColorButtonBack:
             return true;
         default:
             return false;
