@@ -329,7 +329,7 @@ void ModernSysFactory::read_config()
           bwidth = 4;
     }
 
-    theight = QFontMetrics(options()->font(true)).height() + 2;
+    theight = QFontMetrics(options()->font(true)).height();
     if (theight < 16)
         theight = 16;
     if (theight < bwidth)
@@ -522,9 +522,6 @@ int ModernSys::layoutMetric(LayoutMetric lm, bool respectWindowState, const KCom
         case LM_ButtonSpacing:
             return 1;
 
-        case LM_ExplicitButtonSpacer:
-            return 3;
-
         default:
             return KCommonDecoration::layoutMetric(lm, respectWindowState, btn);
     }
@@ -758,7 +755,7 @@ ModernSysFactory::~ModernSysFactory()
 
 KDecoration* ModernSysFactory::createDecoration( KDecorationBridge* b )
 {
-    return(new ModernSys(b, this));
+    return(new ModernSys(b, this))->decoration();
 }
 
 bool ModernSysFactory::reset( unsigned long changed )
@@ -783,11 +780,14 @@ bool ModernSysFactory::reset( unsigned long changed )
     }
 }
 
-bool ModernSysFactory::supports( Ability ability )
+bool ModernSysFactory::supports( Ability ability ) const
 {
     switch( ability )
     {
+        // announce
         case AbilityAnnounceButtons:
+        case AbilityAnnounceColors:
+        // buttons
         case AbilityButtonOnAllDesktops:
         case AbilityButtonSpacer:
         case AbilityButtonHelp:
@@ -798,6 +798,10 @@ bool ModernSysFactory::supports( Ability ability )
         case AbilityButtonBelowOthers:
         case AbilityButtonShade:
         case AbilityButtonMenu:
+        // colors
+        case AbilityColorTitleBack:
+        case AbilityColorTitleBlend:
+        case AbilityColorTitleFore:
             return true;
         default:
             return false;
