@@ -33,7 +33,11 @@ namespace Oxygen
 {
 // OxygenFactory /////////////////////////////////////////////////////////////
 
-static const int OXYGEN_BUTTONSIZE      = 21;
+static const int OXYGEN_BUTTONSIZE      = 22;
+#define TFRAMESIZE 3
+#define BFRAMESIZE 5
+#define LFRAMESIZE 5
+#define RFRAMESIZE 5
 
 enum ButtonType {
     ButtonHelp=0,
@@ -53,6 +57,7 @@ public:
     virtual ~OxygenFactory();
     virtual KDecoration *createDecoration(KDecorationBridge *b);
     virtual bool reset(unsigned long changed);
+    virtual bool supports( Ability ability ) const;
 
     static bool initialized();
     static Qt::Alignment titleAlign();
