@@ -23,17 +23,18 @@
 #include <QBitmap>
 #include <QPainter>
 #include <QImage>
-
-#include <kconfiggroup.h>
 #include <QPixmap>
 
-#include "misc.h"
 #include "plastik.h"
 #include "plastik.moc"
 #include "plastikclient.h"
 #include "plastikbutton.h"
 #include <QApplication>
-#include <kconfig.h>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KColorUtils>
+#include <KColorScheme>
+#include <KGlobalSettings>
 
 namespace KWinPlastik
 {
@@ -133,14 +134,17 @@ bool PlastikHandler::reset(unsigned long changed)
 
 KDecoration* PlastikHandler::createDecoration( KDecorationBridge* bridge )
 {
-        return new PlastikClient( bridge, this );
+        return ( new PlastikClient( bridge, this ))->decoration();
 }
 
-bool PlastikHandler::supports( Ability ability )
+bool PlastikHandler::supports( Ability ability ) const
 {
     switch( ability )
     {
+        // announce
         case AbilityAnnounceButtons:
+        case AbilityAnnounceColors:
+        // buttons
         case AbilityButtonMenu:
         case AbilityButtonOnAllDesktops:
         case AbilityButtonSpacer:
@@ -151,6 +155,10 @@ bool PlastikHandler::supports( Ability ability )
         case AbilityButtonAboveOthers:
         case AbilityButtonBelowOthers:
         case AbilityButtonShade:
+        // colors
+        case AbilityColorTitleBack:
+        case AbilityColorTitleFore:
+        case AbilityColorFrame:
             return true;
         default:
             return false;
@@ -194,25 +202,24 @@ void PlastikHandler::readConfig()
 
 QColor PlastikHandler::getColor(KWinPlastik::ColorType type, const bool active)
 {
+    double c = KGlobalSettings::contrastF();
     switch (type) {
         case WindowContour:
-            return KDecoration::options()->color(ColorTitleBar, active).dark(200);
+            return KColorScheme::shade(KDecoration::options()->color(ColorTitleBar, active), KColorScheme::DarkShade, c);
         case TitleGradient1:
-            return hsvRelative(KDecoration::options()->color(ColorTitleBar, active), 0,-10,+10);
+            return KColorScheme::shade(KDecoration::options()->color(ColorTitleBar, active), KColorScheme::MidlightShade, c-0.4);
             break;
         case TitleGradient2:
-            return hsvRelative(KDecoration::options()->color(ColorTitleBar, active), 0,0,-25);
+            return KColorScheme::shade(KDecoration::options()->color(ColorTitleBar, active), KColorScheme::MidShade, c-0.4);
             break;
         case TitleGradient3:
             return KDecoration::options()->color(ColorTitleBar, active);
             break;
         case ShadeTitleLight:
-            return alphaBlendColors(KDecoration::options()->color(ColorTitleBar, active),
-                                    Qt::white, active?205:215);
+            return KColorScheme::shade(KDecoration::options()->color(ColorTitleBar, active), KColorScheme::LightShade, active?c-0.4:c-0.8);
             break;
         case ShadeTitleDark:
-            return alphaBlendColors(KDecoration::options()->color(ColorTitleBar, active),
-                                    Qt::black, active?205:215);
+            return KColorScheme::shade(KDecoration::options()->color(ColorTitleBar, active), KColorScheme::DarkShade, active?c-0.4:c-0.8);
             break;
         case Border:
             return KDecoration::options()->color(ColorFrame, active);
@@ -234,7 +241,7 @@ const QPixmap &PlastikHandler::pixmap(Pixmaps type, bool active, bool toolWindow
         case TitleBarTileTop:
         case TitleBarTile:
         {
-            const int titleBarTileHeight = (toolWindow ? m_titleHeightTool : m_titleHeight) + 2;
+            const int titleBarTileHeight = (toolWindow ? m_titleHeightTool : m_titleHeight)+2;
             // gradient used as well in TitleBarTileTop as TitleBarTile
             const int gradientHeight = 2 + titleBarTileHeight-1;
             QPixmap gradient(1, gradientHeight);
@@ -243,7 +250,6 @@ const QPixmap &PlastikHandler::pixmap(Pixmaps type, bool active, bool toolWindow
             QLinearGradient grad(0, 0, 0, gradientHeight);
             grad.setColorAt(0.0,                                  getColor(TitleGradient1, active));
             grad.setColorAt(4.0 / (double)gradientHeight,         getColor(TitleGradient2, active));
-            grad.setColorAt(1.0 - (4.0 / (double)gradientHeight), getColor(TitleGradient2, active));
             grad.setColorAt(1.0,                                  getColor(TitleGradient3, active));
             painter.setBrush(grad);
             painter.drawRect(0, 0, 1, gradientHeight);
@@ -267,7 +273,7 @@ const QPixmap &PlastikHandler::pixmap(Pixmaps type, bool active, bool toolWindow
                 painter.begin(pm);
                 painter.drawPixmap(0, 0, gradient, 0,2 ,-1,-1);
                 if (m_coloredBorder) {
-                    painter.setPen(getColor(TitleGradient3, active).dark(110) );
+                    painter.setPen(KColorScheme::shade(getColor(TitleGradient3, active), KColorScheme::MidShade) );
                 } else {
                     painter.setPen(getColor(TitleGradient3, active) );
                 }
@@ -357,14 +363,12 @@ const QPixmap &PlastikHandler::pixmap(Pixmaps type, bool active, bool toolWindow
                     painter.setPen(getColor(TitleGradient3, active) );
                     painter.drawLine(2,0, w-2,0);
                 }
-                painter.setPen(getColor(TitleGradient3, active).dark(110) );
+                painter.setPen(KColorScheme::shade(getColor(TitleGradient3, active), KColorScheme::MidShade) );
                 painter.drawPoint(w-1,0);
             } else {
                 painter.setPen(getColor(WindowContour, active) );
                 painter.drawPoint(0, 0);
-                painter.setPen(
-                        alphaBlendColors(getColor(Border, active),
-                                         getColor(ShadeTitleLight, active), 130) );
+                painter.setPen(KColorUtils::mix(getColor(Border, active), getColor(ShadeTitleLight, active) ) );
                 painter.drawPoint(1, 0);
                 painter.setPen(getColor(Border, active) );
                 painter.drawLine(2,0, w-1,0);
@@ -382,7 +386,7 @@ const QPixmap &PlastikHandler::pixmap(Pixmaps type, bool active, bool toolWindow
             pm = new QPixmap(w, 1);
             QPainter painter(pm);
             if (m_coloredBorder) {
-                painter.setPen(getColor(TitleGradient3, active).dark(110) );
+                painter.setPen(KColorScheme::shade(getColor(TitleGradient3, active), KColorScheme::MidShade) );
                 painter.drawPoint(0,0);
                 if (w > 3) {
                     painter.setPen(getColor(TitleGradient3, active) );
@@ -395,9 +399,7 @@ const QPixmap &PlastikHandler::pixmap(Pixmaps type, bool active, bool toolWindow
             } else {
                 painter.setPen(getColor(Border, active) );
                 painter.drawLine(0,0, w-3,0);
-                painter.setPen(
-                        alphaBlendColors(getColor(Border, active),
-                                         getColor(ShadeTitleDark, active), 130) );
+                painter.setPen(KColorUtils::mix(getColor(Border, active), getColor(ShadeTitleDark, active) ) );
                 painter.drawPoint(w-2, 0);
                 painter.setPen(getColor(WindowContour, active) );
                 painter.drawPoint(w-1, 0);
@@ -426,9 +428,7 @@ const QPixmap &PlastikHandler::pixmap(Pixmaps type, bool active, bool toolWindow
                 painter.setPen(getColor(TitleGradient3, active) );
                 painter.drawLine(2,0, w-1,0);
             } else {
-                painter.setPen(
-                        alphaBlendColors(getColor(Border, active),
-                                        getColor(ShadeTitleLight, active), 130) );
+                painter.setPen(KColorUtils::mix(getColor(Border, active), getColor(ShadeTitleLight, active) ) );
                 painter.drawLine(1,0, 1,h-2);
             }
 
@@ -454,9 +454,7 @@ const QPixmap &PlastikHandler::pixmap(Pixmaps type, bool active, bool toolWindow
                 painter.setPen(getColor(TitleGradient3, active) );
                 painter.drawLine(0,0, w-3,0);
             } else {
-                painter.setPen(
-                        alphaBlendColors(getColor(Border, active),
-                                         getColor(ShadeTitleDark, active), 130) );
+                painter.setPen(KColorUtils::mix(getColor(Border, active), getColor(ShadeTitleDark, active) ) );
                 painter.drawLine(w-2,0, w-2,h-2);
             }
 
@@ -474,7 +472,7 @@ const QPixmap &PlastikHandler::pixmap(Pixmaps type, bool active, bool toolWindow
             QPainter painter(pm);
 
             if (m_coloredBorder) {
-                painter.setPen(getColor(TitleGradient3, active).dark(110) );
+                painter.setPen(KColorScheme::shade(getColor(TitleGradient3, active), KColorScheme::MidShade) );
                 painter.drawPoint(0,0);
                 painter.setPen(getColor(TitleGradient3, active) );
                 painter.drawLine(0,1, 0,h-3);
@@ -483,9 +481,7 @@ const QPixmap &PlastikHandler::pixmap(Pixmaps type, bool active, bool toolWindow
             } else {
                 painter.setPen(getColor(Border, active) );
                 painter.drawLine(0,0, 0,h-3);
-                painter.setPen(
-                        alphaBlendColors(getColor(Border, active),
-                                        getColor(ShadeTitleDark, active), 130) );
+                painter.setPen(KColorUtils::mix(getColor(Border, active), getColor(ShadeTitleDark, active) ) );
                 painter.drawPoint(0, h-2);
             }
             painter.setPen(getColor(WindowContour, active) );
