@@ -62,7 +62,7 @@ QString WebClient::defaultButtonsLeft() const
 
 QString WebClient::defaultButtonsRight() const
 {
-    return "HIAX";
+    return "HIA__X";
 }
 
 bool WebClient::decorationBehaviour(DecorationBehaviour behaviour) const
@@ -110,9 +110,6 @@ int WebClient::layoutMetric(LayoutMetric lm, bool respectWindowState, const KCom
     case LM_ButtonSpacing:
       return 0;
 
-    case LM_ExplicitButtonSpacer:
-      return 0;
-
     default:
       return KCommonDecoration::layoutMetric(lm, respectWindowState, btn);
   }
@@ -224,8 +221,8 @@ WebClient::paintEvent(QPaintEvent * pe)
   const int titleEdgeBottom = layoutMetric(LM_TitleEdgeBottom);
   const int ttlHeight = layoutMetric(LM_TitleHeight);
   const int titleEdgeBottomBottom = r_y+titleEdgeTop+ttlHeight+titleEdgeBottom-1;
-  QRect titleRect = QRect(r_x+titleEdgeLeft+buttonsLeftWidth(), r_y+titleEdgeTop,
-            r_x2-titleEdgeRight-buttonsRightWidth()-(r_x+titleEdgeLeft+buttonsLeftWidth()),
+  QRect titleRect = QRect(r_x+titleEdgeLeft+buttonsLeftWidth()+1, r_y+titleEdgeTop,
+            r_x2-titleEdgeRight-buttonsRightWidth()-(r_x+titleEdgeLeft+buttonsLeftWidth()+1),
             titleEdgeBottomBottom-(r_y+titleEdgeTop) );
   titleRect.setTop(1);
 
@@ -334,7 +331,7 @@ void WebClient::updateWindowShape()
 
 KDecoration* WebFactory::createDecoration( KDecorationBridge* b )
 {
-  return(new WebClient(b, this));
+  return(new WebClient(b, this))->decoration();
 }
 
 bool WebFactory::reset(unsigned long changed)
@@ -354,11 +351,14 @@ bool WebFactory::reset(unsigned long changed)
   }
 }
 
-bool WebFactory::supports( Ability ability )
+bool WebFactory::supports( Ability ability ) const
 {
     switch( ability )
     {
+        // announce
         case AbilityAnnounceButtons:
+        case AbilityAnnounceColors:
+        // buttons
         case AbilityButtonOnAllDesktops:
         case AbilityButtonHelp:
         case AbilityButtonMinimize:
@@ -368,6 +368,10 @@ bool WebFactory::supports( Ability ability )
         case AbilityButtonAboveOthers:
         case AbilityButtonBelowOthers:
         case AbilityButtonShade:
+        case AbilityButtonSpacer:
+        // colors:
+        case AbilityColorTitleBack:
+        case AbilityColorTitleFore:
             return true;
         default:
             return false;
