@@ -83,10 +83,10 @@ void Workspace::setupCompositing()
         return;
         }
     else if( !CompositingPrefs::compositingPossible() )
-    {
-        kDebug( 1212 ) << "Compositing isn't possible";
+        {
+        kError( 1212 ) << "Compositing is not possible";
         return;
-    }
+        }
     if( scene != NULL )
         return;
     char selection_name[ 100 ];
@@ -147,7 +147,8 @@ void Workspace::setupCompositing()
         }
     if( scene == NULL || scene->initFailed())
         {
-        kError( 1212 ) << "Failed to create Scene object. Compositing disabled" << endl;
+        kError( 1212 ) << "Failed to initialize compositing, compositing disabled";
+        kError( 1212 ) << "Consult http://techbase.kde.org/Projects/KWin/4.0-release-notes#Setting_up";
         delete scene;
         scene = NULL;
         delete cm_selection;
@@ -301,10 +302,11 @@ void Workspace::performCompositing()
         windows.append( c );
     foreach( Deleted* c, deleted ) // TODO remember stacking order somehow
         windows.append( c );
-    foreach( Toplevel* c, static_cast< EffectsHandlerImpl* >( effects )->elevatedWindows())
+    foreach( EffectWindow* c, static_cast< EffectsHandlerImpl* >( effects )->elevatedWindows())
         {
-        windows.removeAll( c );
-        windows.append( c );
+        Toplevel* t = static_cast< EffectWindowImpl* >( c )->window();
+        windows.removeAll( t );
+        windows.append( t );
         }
     foreach( Toplevel* c, windows )
         { // This could be possibly optimized WRT obscuring, but that'd need being already
