@@ -202,8 +202,7 @@ void EffectsHandlerImpl::windowDeleted( EffectWindow* c )
     {
     foreach( EffectPair ep, loaded_effects )
         ep.second->windowDeleted( c );
-    Toplevel* c2 = static_cast< EffectWindowImpl* >( c )->window();
-    elevated_windows.removeAll( c2 );
+    elevated_windows.removeAll( c );
     }
 
 void EffectsHandlerImpl::windowClosed( EffectWindow* c )
@@ -450,10 +449,9 @@ EffectWindowList EffectsHandlerImpl::stackingOrder() const
 
 void EffectsHandlerImpl::setElevatedWindow( EffectWindow* w, bool set )
     {
-    Toplevel* c = static_cast< EffectWindowImpl* >( w )->window();
-    elevated_windows.removeAll( c );
+    elevated_windows.removeAll( w );
     if( set )
-        elevated_windows.append( c );
+        elevated_windows.append( w );
     }
 
 void EffectsHandlerImpl::setTabBoxWindow(EffectWindow* w)
@@ -811,7 +809,7 @@ bool EffectsHandlerImpl::loadEffect( const QString& name )
 
     Effect* e = create();
 
-    effect_order.insert( service->property( "X-Ordering" ).toInt(), EffectPair( name, e ));
+    effect_order.insert( service->property( "X-KDE-Ordering" ).toInt(), EffectPair( name, e ));
     effectsChanged();
     effect_libraries[ name ] = library;
 
@@ -867,10 +865,10 @@ bool EffectsHandlerImpl::isEffectLoaded( const QString& name )
 void EffectsHandlerImpl::effectsChanged()
     {
     loaded_effects.clear();
-    kDebug(1212) << "Recreating effects' list:";
+//    kDebug(1212) << "Recreating effects' list:";
     foreach( EffectPair effect, effect_order )
         {
-        kDebug(1212) << effect.first;
+//        kDebug(1212) << effect.first;
         loaded_effects.append( effect );
         }
     }
@@ -1080,7 +1078,8 @@ QByteArray EffectWindowImpl::readProperty( long atom, long type, int format ) co
                 }
             if( long( rtype ) == type && rformat == format )
                 {
-                QByteArray ret( reinterpret_cast< const char* >( data ), nitems * ( format / 8 ));
+                int bytelen = format == 8 ? nitems : format == 16 ? nitems * sizeof( short ) : nitems * sizeof( long );
+                QByteArray ret( reinterpret_cast< const char* >( data ), bytelen );
                 XFree( data );
                 return ret;
                 }
