@@ -1,12 +1,22 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 2007 Lubos Lunak <l.lunak@kde.org>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #ifndef KWIN_DESKTOPGRID_H
 #define KWIN_DESKTOPGRID_H
@@ -45,10 +55,11 @@ class DesktopGridEffect
         void paintSlide( int mask, QRegion region, const ScreenPaintData& data );
         void paintScreenDesktop( int desktop, int mask, QRegion region, ScreenPaintData data );
         void slideDesktopChanged( int old );
+        void setHighlightedDesktop( int desktop );
         double progress;
         bool activated;
         int painting_desktop;
-        int hover_desktop;
+        int highlighted_desktop;
         Window input;
         bool keyboard_grab;
         bool was_window_move;
