@@ -1,18 +1,29 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 2007 Lubos Lunak <l.lunak@kde.org>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #include "shadow.h"
 
 #include <kwinglutils.h>
 
 #include <kconfiggroup.h>
+#include <kdebug.h>
 #include <KStandardDirs>
 
 namespace KWin
@@ -23,11 +34,11 @@ KWIN_EFFECT( shadow, ShadowEffect )
 ShadowEffect::ShadowEffect()
     {
     KConfigGroup conf = effects->effectConfig("Shadow");
-    shadowXOffset = conf.readEntry( "XOffset", 5 );
-    shadowYOffset = conf.readEntry( "YOffset", 5 );
-    shadowOpacity = conf.readEntry( "Opacity", 0.2 );
+    shadowXOffset = conf.readEntry( "XOffset", 0 );
+    shadowYOffset = conf.readEntry( "YOffset", 3 );
+    shadowOpacity = conf.readEntry( "Opacity", 0.25 );
     shadowFuzzyness = conf.readEntry( "Fuzzyness", 10 );
-    shadowSize = conf.readEntry( "Size", 4 );
+    shadowSize = conf.readEntry( "Size", 5 );
     intensifyActiveShadow = conf.readEntry( "IntensifyActiveShadow", true );
 
     QString shadowtexture =  KGlobal::dirs()->findResource("data", "kwin/shadow-texture.png");
@@ -36,47 +47,116 @@ ShadowEffect::ShadowEffect()
 
 QRect ShadowEffect::shadowRectangle(const QRect& windowRectangle) const
     {
-    int shadowGrow = shadowFuzzyness + shadowSize + 20;
+    int shadowGrow = shadowFuzzyness + shadowSize;
     return windowRectangle.adjusted( shadowXOffset - shadowGrow, shadowYOffset - shadowGrow,
             shadowXOffset + shadowGrow, shadowYOffset + shadowGrow);
     }
+
+void ShadowEffect::paintScreen( int mask, QRegion region, ScreenPaintData& data )
+    {
+    shadowDatas.clear();
+
+    // Draw windows
+    effects->paintScreen( mask, region, data );
+
+    // Draw shadows
+    drawQueuedShadows( 0 );
+    }
+
 void ShadowEffect::prePaintWindow( EffectWindow* w, WindowPrePaintData& data, int time )
     {
-    data.mask |= PAINT_WINDOW_TRANSLUCENT;
-    data.paint |= QRegion( shadowRectangle( ( QRegion( w->geometry()) & data.paint ).boundingRect() ));
+    if( useShadow( w ))
+        {
+        data.paint |= shadowRectangle( data.paint.boundingRect() );
+        }
     effects->prePaintWindow( w, data, time );
     }
 
-void ShadowEffect::paintWindow( EffectWindow* w, int mask, QRegion region, WindowPaintData& data )
+void ShadowEffect::drawWindow( EffectWindow* w, int mask, QRegion region, WindowPaintData& data )
     {
-    if( !w->isDeleted() && !w->isDesktop() && !w->isDock() )
-        drawShadow( w, mask, region, data );
-    effects->paintWindow( w, mask, region, data );
-    }
+    // Whether the shadow drawing can be delayed or not.
+    bool optimize = !( mask & ( PAINT_WINDOW_TRANSFORMED | PAINT_SCREEN_TRANSFORMED |
+            PAINT_SCREEN_WITH_TRANSFORMED_WINDOWS | PAINT_WINDOW_TRANSLUCENT ));
+    if( !optimize )
+        {
+        // Transformed or translucent windows are drawn bottom-to-top, so
+        //  first we need to draw all queued shadows.
+        drawQueuedShadows( w );
+        }
+    if( useShadow( w ))
+        {
+        if( !optimize )
+            {
+            // For translucent windows, shadow needs to be drawn before the
+            //  window itself.
+            drawShadow( w, mask, region, data, false );
+            }
+        else
+            {
+            // For opaque windows, just schedule the shadow to be drawn later
+            ShadowData d(w, data);
+            d.clip = w->shape().translated( w->x(), w->y());
+            if( !shadowDatas.isEmpty())
+                d.clip |= shadowDatas.last().clip;
+            d.mask = mask;
+            foreach(QRect r, region.rects())
+                d.region |= shadowRectangle(r);
+            d.region &= region;
+            shadowDatas.append(d);
+            }
+        }
 
-void ShadowEffect::postPaintWindow( EffectWindow* w )
-    {
-    effects->postPaintWindow( w );
+    effects->drawWindow( w, mask, region, data );
     }
 
 QRect ShadowEffect::transformWindowDamage( EffectWindow* w, const QRect& r )
     {
+    if( !useShadow( w ))
+        return effects->transformWindowDamage( w, r );
     QRect r2 = r | shadowRectangle( r );
     return effects->transformWindowDamage( w, r2 );
     }
 
+void ShadowEffect::windowClosed( EffectWindow* c )
+    {
+    effects->addRepaint( shadowRectangle( c->geometry() ));
+    }
+
+bool ShadowEffect::useShadow( EffectWindow* w ) const
+    {
+    return !w->isDeleted() && !w->isDesktop() && !w->isDock() && !w->hasOwnShape();
+    }
+
 void ShadowEffect::addQuadVertices(QVector<float>& verts, float x1, float y1, float x2, float y2) const
-{
+    {
     verts << x1 << y1;
     verts << x1 << y2;
     verts << x2 << y2;
     verts << x2 << y1;
-}
+    }
 
-void ShadowEffect::drawShadow( EffectWindow* window, int mask, QRegion region, WindowPaintData& data )
+void ShadowEffect::drawQueuedShadows( EffectWindow* behindWindow )
+    {
+    QList<ShadowData> newShadowDatas;
+    EffectWindowList stack = effects->stackingOrder();
+    foreach( ShadowData d, shadowDatas )
+        {
+        // If behindWindow is given then only render shadows of the windows
+        //  that are behind that window.
+        if( !behindWindow || stack.indexOf(d.w) < stack.indexOf(behindWindow))
+            {
+            drawShadow( d.w, d.mask, d.region.subtracted( d.clip ), d.data, true );
+            }
+        else
+            {
+            newShadowDatas.append(d);
+            }
+        }
+    shadowDatas = newShadowDatas;
+    }
+
+void ShadowEffect::drawShadow( EffectWindow* window, int mask, QRegion region, WindowPaintData& data, bool clip )
     {
-    if(( mask & PAINT_WINDOW_TRANSLUCENT ) == 0 )
-        return;
     glPushAttrib( GL_CURRENT_BIT | GL_ENABLE_BIT | GL_TEXTURE_BIT );
     glEnable( GL_BLEND );
     glBlendFunc( GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA );
@@ -95,6 +175,8 @@ void ShadowEffect::drawShadow( EffectWindow* window, int mask, QRegion region, W
         glScalef( data.xScale, data.yScale, 1 );
 
     QVector<float> verts, texcoords;
+    verts.reserve(80);
+    texcoords.reserve(80);
     // center
     addQuadVertices(verts, 0 + fuzzy, 0 + fuzzy, w - fuzzy, h - fuzzy);
     addQuadVertices(texcoords, 0.5, 0.5, 0.5, 0.5);
@@ -137,7 +219,10 @@ void ShadowEffect::drawShadow( EffectWindow* window, int mask, QRegion region, W
     glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
     // We have two elements per vertex in the verts array
     int verticesCount = verts.count() / 2;
-    renderGLGeometry( mask, region, verticesCount, verts.data(), texcoords.data() );
+    if( clip )
+        renderGLGeometry( true, region, verticesCount, verts.data(), texcoords.data() );
+    else
+        renderGLGeometry( mask, region, verticesCount, verts.data(), texcoords.data() );
     mShadowTexture->unbind();
 
     glPopMatrix();
