@@ -1,12 +1,22 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 2006 Lubos Lunak <l.lunak@kde.org>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 /*
 
@@ -31,8 +41,6 @@ License. See the file "COPYING" for the exact licensing terms.
 
 */
 
-#include <config-workspace.h>
-
 #include "videorecord.h"
 
 #include <kaction.h>
@@ -53,7 +61,7 @@ VideoRecordEffect::VideoRecordEffect()
     KActionCollection* actionCollection = new KActionCollection( this );
     KAction* a = static_cast< KAction* >( actionCollection->addAction( "VideoRecord" ));
     a->setText( i18n("Toggle Video Recording" ));
-    a->setGlobalShortcut( KShortcut( Qt::CTRL + Qt::Key_F11 ));
+    a->setGlobalShortcut( KShortcut( Qt::CTRL + Qt::META + Qt::Key_V ));
     connect( a, SIGNAL( triggered( bool )), this, SLOT( toggleRecording()));
     area = QRect( 0, 0, displayWidth(), displayHeight());
     }
