@@ -476,7 +476,15 @@ bool Workspace::workspaceEvent( XEvent * e )
             break;
         case VisibilityNotify:
             if( compositing() && overlay != None && e->xvisibility.window == overlay )
+                {
+                bool was_visible = overlay_visible;
                 overlay_visible = ( e->xvisibility.state != VisibilityFullyObscured );
+                if( !was_visible && overlay_visible )
+                    { // hack for #154825
+                    addRepaintFull();
+                    QTimer::singleShot( 2000, this, SLOT( addRepaintFull()));
+                    }
+                }
             break;
         default:
             if( e->type == Extensions::randrNotifyEvent() && Extensions::randrAvailable() )
@@ -1698,7 +1706,8 @@ void Unmanaged::configureNotifyEvent( XConfigureEvent* e )
         addWorkspaceRepaint( geometry()); // damage old area
         QRect old = geom;
         geom = newgeom;
-        discardWindowPixmap();
+        if( old.size() != geom.size())
+            discardWindowPixmap();
         if( scene != NULL )
             scene->windowGeometryShapeChanged( this );
         if( effects != NULL )
