@@ -681,8 +681,8 @@ void Client::cleanGrouping()
         {
         if( (*it)->transientFor() == this )
             {
-            ClientList::ConstIterator it2 = it++;
-            removeTransient( *it2 );
+            removeTransient( *it );
+            it = transients_list.begin(); // restart, just in case something more has changed with the list
             }
         else
             ++it;
@@ -765,9 +765,9 @@ void Client::checkGroupTransients()
                 if( (*it2)->hasTransient( *it1, false ) && (*it3)->hasTransient( *it1, false ))
                     {
                     if( (*it2)->hasTransient( *it3, true ))
-                        (*it3)->transients_list.removeAll( *it1 );
-                    if( (*it3)->hasTransient( *it2, true ))
                         (*it2)->transients_list.removeAll( *it1 );
+                    if( (*it3)->hasTransient( *it2, true ))
+                        (*it3)->transients_list.removeAll( *it1 );
                     }
                 }
             }
