@@ -1,12 +1,22 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 2007 Rivo Laks <rivolaks@hot.ee>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #include "main.h"
 
@@ -55,9 +65,12 @@ ConfirmDialog::ConfirmDialog() :
 
 KWinCompositingConfig::KWinCompositingConfig(QWidget *parent, const QVariantList &)
     : KCModule( KWinCompositingConfigFactory::componentData(), parent),
-        mKWinConfig(KSharedConfig::openConfig("kwinrc"))
+        mKWinConfig(KSharedConfig::openConfig("kwinrc")),
+        m_showConfirmDialog (false)
 {
+    KGlobal::locale()->insertCatalog( "kwin_effects" );
     ui.setupUi(this);
+    layout()->setMargin(0);
     ui.tabWidget->setCurrentIndex(0);
     ui.statusLabel->hide();
 
@@ -97,7 +110,10 @@ KWinCompositingConfig::KWinCompositingConfig(QWidget *parent, const QVariantList
         ui.useCompositing->setChecked(false);
         compositingEnabled(false);
 
-        ui.statusLabel->setText(i18n("Compositing is not supported on your system."));
+        QString text = i18n("Compositing is not supported on your system.");
+        text += "<br><br>";
+        text += CompositingPrefs::compositingNotPossibleReason();
+        ui.statusLabel->setText(text);
         ui.statusLabel->show();
     }
 
@@ -138,10 +154,11 @@ void KWinCompositingConfig::showConfirmDialog()
         // Revert settings
         KConfigGroup config(mKWinConfig, "Compositing");
         config.deleteGroup();
-        QMap<QString, QString>::const_iterator i = mPreviousConfig.constBegin();
-        while (i != mPreviousConfig.constEnd()) {
-            config.writeEntry(i.key(), i.value());
-            ++i;
+        QMap<QString, QString>::const_iterator it = mPreviousConfig.constBegin();
+        for(; it != mPreviousConfig.constEnd(); ++it) {
+            if (it.value().isEmpty())
+                continue;
+            config.writeEntry(it.key(), it.value());
         }
         // Sync with KWin and reload
         configChanged();
@@ -188,11 +205,16 @@ void KWinCompositingConfig::loadGeneralTab()
     // Load effect settings
     KConfigGroup effectconfig(mTmpConfig, "Plugins");
 #define LOAD_EFFECT_CONFIG(effectname)  effectconfig.readEntry("kwin4_effect_" effectname "Enabled", true)
-    bool winManagementEnabled = LOAD_EFFECT_CONFIG("presentwindows");
-    winManagementEnabled &= LOAD_EFFECT_CONFIG("boxswitch");
-    winManagementEnabled &= LOAD_EFFECT_CONFIG("desktopgrid");
-    winManagementEnabled &= LOAD_EFFECT_CONFIG("dialogparent");
-    ui.effectWinManagement->setChecked(winManagementEnabled);
+    int winManagementEnabled = LOAD_EFFECT_CONFIG("presentwindows")
+        + LOAD_EFFECT_CONFIG("boxswitch")
+        + LOAD_EFFECT_CONFIG("desktopgrid")
+        + LOAD_EFFECT_CONFIG("dialogparent");
+    if (winManagementEnabled > 0 && winManagementEnabled < 4) {
+        ui.effectWinManagement->setTristate(true);
+        ui.effectWinManagement->setCheckState(Qt::PartiallyChecked);
+    }
+    else
+        ui.effectWinManagement->setChecked(winManagementEnabled);
     ui.effectShadows->setChecked(LOAD_EFFECT_CONFIG("shadow"));
     ui.effectAnimations->setChecked(LOAD_EFFECT_CONFIG("minimizeanimation"));
 #undef LOAD_EFFECT_CONFIG
@@ -205,7 +227,6 @@ void KWinCompositingConfig::loadEffectsTab()
 
 void KWinCompositingConfig::load()
 {
-    kDebug() ;
     mKWinConfig->reparseConfiguration();
 
     // Copy Plugins group to temp config file
@@ -224,18 +245,17 @@ void KWinCompositingConfig::load()
     emit changed( false );
 }
 
-bool KWinCompositingConfig::saveGeneralTab()
+void KWinCompositingConfig::saveGeneralTab()
 {
     KConfigGroup config(mKWinConfig, "Compositing");
     // Save current config. We'll use this for restoring in case something
     //  goes wrong.
     mPreviousConfig = config.entryMap();
     // Check if any critical settings that need confirmation have changed
-    bool confirm = false;
     if(ui.useCompositing->isChecked()
         && ui.useCompositing->isChecked() != config.readEntry("Enabled", mDefaultPrefs.enableCompositing()))
         {
-        confirm = true;
+        m_showConfirmDialog = true;
         }
 
     config.writeEntry("Enabled", ui.useCompositing->isChecked());
@@ -243,17 +263,17 @@ bool KWinCompositingConfig::saveGeneralTab()
     // Save effects
     KConfigGroup effectconfig(mTmpConfig, "Plugins");
 #define WRITE_EFFECT_CONFIG(effectname, widget)  effectconfig.writeEntry("kwin4_effect_" effectname "Enabled", widget->isChecked())
-    WRITE_EFFECT_CONFIG("presentwindows", ui.effectWinManagement);
-    WRITE_EFFECT_CONFIG("boxswitch", ui.effectWinManagement);
-    WRITE_EFFECT_CONFIG("desktopgrid", ui.effectWinManagement);
-    WRITE_EFFECT_CONFIG("dialogparent", ui.effectWinManagement);
+    if (ui.effectWinManagement->checkState() != Qt::PartiallyChecked) {
+        WRITE_EFFECT_CONFIG("presentwindows", ui.effectWinManagement);
+        WRITE_EFFECT_CONFIG("boxswitch", ui.effectWinManagement);
+        WRITE_EFFECT_CONFIG("desktopgrid", ui.effectWinManagement);
+        WRITE_EFFECT_CONFIG("dialogparent", ui.effectWinManagement);
+    }
     WRITE_EFFECT_CONFIG("shadow", ui.effectShadows);
     // TODO: maybe also do some effect-specific configuration here, e.g.
     //  enable/disable desktopgrid's animation according to this setting
     WRITE_EFFECT_CONFIG("minimizeanimation", ui.effectAnimations);
 #undef WRITE_EFFECT_CONFIG
-
-    return confirm;
 }
 
 void KWinCompositingConfig::saveEffectsTab()
@@ -263,10 +283,19 @@ void KWinCompositingConfig::saveEffectsTab()
 
 void KWinCompositingConfig::save()
 {
-    kDebug() ;
-
-    bool confirm = saveGeneralTab();
-    saveEffectsTab();
+    // bah; tab content being dependent on the other is really bad; and
+    // deprecated in the HIG for a reason.  Its confusing!
+    // Make sure we only call save on each tab once; as they are stateful due to the revert concept
+    if (ui.tabWidget->currentIndex() == 0) { // general was active
+        saveGeneralTab();
+        loadEffectsTab();
+        saveEffectsTab();
+    }
+    else { // effects tab was active
+        saveEffectsTab();
+        loadGeneralTab();
+        saveGeneralTab();
+    }
 
     // Copy Plugins group from temp config to real config
     QMap<QString, QString> entries = mTmpConfig->entryMap("Plugins");
@@ -282,8 +311,9 @@ void KWinCompositingConfig::save()
 
     configChanged();
 
-    if(confirm)
+    if(m_showConfirmDialog)
     {
+        m_showConfirmDialog = false;
         showConfirmDialog();
     }
 }
@@ -300,7 +330,6 @@ void KWinCompositingConfig::configChanged()
 
 void KWinCompositingConfig::defaults()
 {
-    kDebug() ;
     ui.useCompositing->setChecked(mDefaultPrefs.enableCompositing());
     ui.effectWinManagement->setChecked(true);
     ui.effectShadows->setChecked(true);
@@ -311,7 +340,6 @@ void KWinCompositingConfig::defaults()
 
 QString KWinCompositingConfig::quickHelp() const
 {
-    kDebug() ;
     return i18n("<h1>Desktop Effects</h1>");
 }
 
