@@ -32,13 +32,20 @@ DEALINGS IN THE SOFTWARE.
 #include <netwm_def.h>
 #include <QtGui/QMouseEvent>
 
+#define KWIN_EXPORT KDE_EXPORT
+
+class KConfig;
+
+/** @defgroup kdecoration KWin decorations library */
+
+/** @addtogroup kdecoration */
+/** @{ */
+
 class KDecorationOptionsPrivate;
 class KDecorationBridge;
 class KDecorationPrivate;
 class KDecorationFactory;
 
-#define KWIN_EXPORT KDE_EXPORT
-
 /**
  * This class provides a namespace for all decoration related classes.
  * All shared types are defined here.
@@ -200,6 +207,12 @@ class KWIN_EXPORT KDecorationOptions : public KDecorationDefines
 public:
     KDecorationOptions();
     virtual ~KDecorationOptions();
+    /**
+     * Call to update settings when the config changes. Return value is
+     * a combination of Setting* (SettingColors, etc.) that have changed.
+     * @since 4.0.1
+     */
+    unsigned long updateSettings( KConfig* config );
     /**
      * Returns the color that should be used for the given part of the decoration.
      * The changed flags for this setting is SettingColors.
@@ -311,6 +324,21 @@ public:
     virtual unsigned long updateSettings() = 0; // returns SettingXYZ mask
 
 protected:
+    /** @internal */
+    void setOpMaxButtonLeftClick( WindowOperation op );
+    /** @internal */
+    void setOpMaxButtonRightClick( WindowOperation op );
+    /** @internal */
+    void setOpMaxButtonMiddleClick( WindowOperation op );
+    /** @internal */
+    void setBorderSize( BorderSize bs );
+    /** @internal */
+    void setCustomButtonPositions( bool b );
+    /** @internal */
+    void setTitleButtonsLeft( const QString& b );
+    /** @internal */
+    void setTitleButtonsRight( const QString& b );
+private:
     /**
      * @internal
      */
@@ -867,4 +895,6 @@ inline int KDecoration::height() const
     return geometry().height();
     }
 
+/** @} */
+
 #endif
