@@ -1,12 +1,22 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 2006 Lubos Lunak <l.lunak@kde.org>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #include "kwineffects.h"
 
@@ -25,7 +35,7 @@ License. See the file "COPYING" for the exact licensing terms.
 
 #include <assert.h>
 
-#ifdef HAVE_XRENDER
+#ifdef KWIN_HAVE_XRENDER_COMPOSITING
 #include <X11/extensions/Xrender.h>
 #endif
 
@@ -121,6 +131,10 @@ void Effect::grabbedKeyboardEvent( QKeyEvent* )
     {
     }
 
+void Effect::propertyNotify( EffectWindow* , long )
+    {
+    }
+
 void Effect::desktopChanged( int )
     {
     }
@@ -149,7 +163,8 @@ bool Effect::borderActivated( ElectricBorder )
     return false;
     }
 
-void Effect::mouseChanged( const QPoint&, const QPoint&, Qt::MouseButtons, Qt::KeyboardModifiers )
+void Effect::mouseChanged( const QPoint&, const QPoint&, Qt::MouseButtons,
+    Qt::MouseButtons, Qt::KeyboardModifiers, Qt::KeyboardModifiers )
     {
     }
 
@@ -282,7 +297,7 @@ void EffectsHandler::sendReloadMessage( const QString& effectname )
 
 KConfigGroup EffectsHandler::effectConfig( const QString& effectname )
     {
-    KSharedConfig::Ptr kwinconfig = KSharedConfig::openConfig( "kwinrc", KConfig::CascadeConfig );
+    KSharedConfig::Ptr kwinconfig = KSharedConfig::openConfig( "kwinrc", KConfig::NoGlobals );
     return kwinconfig->group( "Effect-" + effectname );
     }
 
@@ -311,7 +326,7 @@ bool EffectsHandler::paintText( const QString& text, const QPoint& center, int m
     QRect area( center.x() - textrect.width() / 2, center.y() - textrect.height() / 2,
                  textrect.width(), textrect.height() );
 
-#ifdef HAVE_OPENGL
+#ifdef KWIN_HAVE_OPENGL_COMPOSITING
     if( effects->compositingType() == OpenGLCompositing )
         {
         GLTexture textTexture( textPixmap, GL_TEXTURE_RECTANGLE_ARB );
@@ -339,7 +354,7 @@ bool EffectsHandler::paintText( const QString& text, const QPoint& center, int m
         return true;
         }
 #endif
-#ifdef HAVE_XRENDER
+#ifdef KWIN_HAVE_XRENDER_COMPOSITING
     if( effects->compositingType() == XRenderCompositing )
         {
         static XRenderPictFormat* alphaFormat = 0;
@@ -369,7 +384,7 @@ bool EffectsHandler::paintTextWithBackground( const QString& text, const QPoint&
     QRect area( center.x() - textrect.width() / 2, center.y() - textrect.height() / 2,
                 textrect.width(), textrect.height() );
 
-#ifdef HAVE_OPENGL
+#ifdef KWIN_HAVE_OPENGL_COMPOSITING
     if( effects->compositingType() == OpenGLCompositing )
     {
         glColor4f( bgcolor.redF(), bgcolor.greenF(), bgcolor.blueF(), bgcolor.alphaF() );
@@ -422,6 +437,15 @@ EffectWindowGroup::~EffectWindowGroup()
     {
     }
 
+//****************************************
+// GlobalShortcutsEditor
+//****************************************
+
+GlobalShortcutsEditor::GlobalShortcutsEditor( QWidget *parent ) :
+        KShortcutsEditor( parent, GlobalAction )
+    {
+    }
+
 /***************************************************************
  WindowQuad
 ***************************************************************/
