@@ -1,12 +1,22 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 2007 Rivo Laks <rivolaks@hot.ee>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #ifndef KWIN_GLUTILS_FUNCS_H
 #define KWIN_GLUTILS_FUNCS_H
@@ -15,18 +25,44 @@ License. See the file "COPYING" for the exact licensing terms.
 
 #define KWIN_EXPORT KDE_EXPORT
 
-#include <config-X11.h> // HAVE_OPENGL
+#include <kwinconfig.h> // KWIN_HAVE_OPENGL
 
-#ifdef HAVE_OPENGL
+#ifdef KWIN_HAVE_OPENGL
 
 // gcc-3.3.3 apparently cannot resolve KWin's namespaced versions properly,
 // so hide possible global functions
 #define glXQueryDrawable kwinhide_glXQueryDrawable
+#define glXGetFBConfigAttrib kwinhide_glXGetFBConfigAttrib
+#define glXGetVisualFromFBConfig kwinhide_glXGetVisualFromFBConfig
+#define glXDestroyWindow kwinhide_glXDestroyWindow
+#define glXDestroyPixmap kwinhide_glXDestroyPixmap
+#define glXCreateWindow kwinhide_glXCreateWindow
+#define glXCreatePixmap kwinhide_glXCreatePixmap
+#define glXGetFBConfigs kwinhide_glXGetFBConfigs
+#define glXGetProcAddress kwinhide_glXGetProcAddress
+#define glXReleaseTexImageEXT kwinhide_glXReleaseTexImageEXT
+#define glXBindTexImageEXT kwinhide_glXBindTexImageEXT
+#define glXCopySubBuffer kwinhide_glXCopySubBuffer
+#define glXGetVideoSync kwinhide_glXGetVideoSync
+#define glXWaitVideoSync kwinhide_glXWaitVideoSync
 
 #include <GL/gl.h>
 #include <GL/glx.h>
 
 #undef glXQueryDrawable
+#undef glXGetFBConfigAttrib
+#undef glXGetVisualFromFBConfig
+#undef glXDestroyWindow
+#undef glXDestroyPixmap
+#undef glXCreateWindow
+#undef glXCreatePixmap
+#undef glXGetFBConfigs
+#undef glXGetProcAddress
+#undef glXReleaseTexImageEXT
+#undef glXBindTexImageEXT
+#undef glXCopySubBuffer
+#undef glXGetVideoSync
+#undef glXWaitVideoSync
 
 #include <fixx11h.h>
 
