@@ -1,12 +1,22 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 2006-2007 Rivo Laks <rivolaks@hot.ee>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #include "kwinshadereffect.h"
 
@@ -42,7 +52,7 @@ ShaderEffect::~ShaderEffect()
 
 bool ShaderEffect::loadData(const QString& shadername)
 {
-#ifndef HAVE_OPENGL
+#ifndef KWIN_HAVE_OPENGL_COMPOSITING
     return false;
 #else
     // If NPOT textures are not supported, use nearest power-of-two sized
@@ -90,7 +100,7 @@ bool ShaderEffect::loadData(const QString& shadername)
 
 bool ShaderEffect::supported()
 {
-#ifndef HAVE_OPENGL
+#ifndef KWIN_HAVE_OPENGL_COMPOSITING
     return false;
 #else
     return GLRenderTarget::supported() &&
@@ -119,7 +129,7 @@ GLShader* ShaderEffect::shader() const
 void ShaderEffect::prePaintScreen( ScreenPrePaintData& data, int time )
 {
     mTime += time / 1000.0f;
-#ifdef HAVE_OPENGL
+#ifdef KWIN_HAVE_OPENGL_COMPOSITING
     if( mValid && mEnabled )
     {
         data.mask |= PAINT_SCREEN_WITH_TRANSFORMED_WINDOWS;
@@ -136,7 +146,7 @@ void ShaderEffect::postPaintScreen()
     // Call the next effect.
     effects->postPaintScreen();
 
-#ifdef HAVE_OPENGL
+#ifdef KWIN_HAVE_OPENGL_COMPOSITING
     if( mValid && mEnabled )
     {
         // Disable render texture
