@@ -125,7 +125,7 @@ SceneOpenGL::SceneOpenGL( Workspace* ws )
             !glXGetVisualFromFBConfig || !glXCreatePixmap || !glXDestroyPixmap ||
             !glXCreateWindow || !glXDestroyWindow )
         {
-        kDebug( 1212 ) << "GLX_SGIX_fbconfig or required GLX functions missing";
+        kError( 1212 ) << "GLX_SGIX_fbconfig or required GLX functions missing";
         return; // error
         }
     if( !selectMode())
@@ -134,27 +134,19 @@ SceneOpenGL::SceneOpenGL( Workspace* ws )
         return; // error
     if( !initRenderingContext())
         return; // error
-
     // Initialize OpenGL
     initGL();
+    if( !hasGLExtension( "GL_ARB_texture_non_power_of_two" )
+        && !hasGLExtension( "GL_ARB_texture_rectangle" ))
+        {
+        kError( 1212 ) << "GL_ARB_texture_non_power_of_two and GL_ARB_texture_rectangle missing";
+        return; // error
+        }
     if( db )
         glDrawBuffer( GL_BACK );
     // Check whether certain features are supported
     has_waitSync = glXGetVideoSync ? true : false;
 
-    int vis_buffer, vis_drawable;
-    glXGetFBConfigAttrib( display(), fbcbuffer, GLX_VISUAL_ID, &vis_buffer );
-    XVisualInfo* visinfo_buffer = glXGetVisualFromFBConfig( display(), fbcbuffer );
-    kDebug( 1212 ) << "Buffer visual (depth " << visinfo_buffer->depth << "): 0x" << QString::number( vis_buffer, 16 );
-    XFree( visinfo_buffer );
-    for( int i = 0; i <= 32; i++ )
-        {
-        if( fbcdrawableinfo[ i ].fbconfig == NULL )
-            continue;
-        glXGetFBConfigAttrib( display(), fbcdrawableinfo[ i ].fbconfig, GLX_VISUAL_ID, &vis_drawable );
-        kDebug( 1212 ) << "Drawable visual (depth " << i << "): 0x" << QString::number( vis_drawable, 16 );
-        }
-
     // OpenGL scene setup
     glMatrixMode( GL_PROJECTION );
     glLoadIdentity();
@@ -162,7 +154,11 @@ SceneOpenGL::SceneOpenGL( Workspace* ws )
     glOrtho( 0, displayWidth(), displayHeight(), 0, 0, 65535 );
     glMatrixMode( GL_MODELVIEW );
     glLoadIdentity();
-    checkGLError( "Init" );
+    if( checkGLError( "Init" ))
+        {
+        kError( 1212 ) << "OpenGL compositing setup failed";
+        return; // error
+        }
     kDebug( 1212 ) << "DB:" << db << ", TFP:" << tfp_mode << ", SHM:" << shm_mode
         << ", Direct:" << bool( glXIsDirect( display(), ctxbuffer )) << endl;
     init_ok = true;
@@ -293,29 +289,47 @@ void SceneOpenGL::cleanupShm()
 #endif
     }
 
+// TODO replace with just KXErrorHandler::errorCode() for 4.1
+static int xerror = 0;
+static bool xerrorhandler( int, int error, unsigned long )
+    {
+    if( xerror == 0 )
+        xerror = error;
+    return true;
+    }
+
 bool SceneOpenGL::initRenderingContext()
     {
     bool direct_rendering = options->glDirect;
     if( !tfp_mode && !shm_mode )
         direct_rendering = false; // fallback doesn't seem to work with direct rendering
-    KXErrorHandler errs;
+    xerror = 0;
+    KXErrorHandler errs1( xerrorhandler );
     ctxbuffer = glXCreateNewContext( display(), fbcbuffer, GLX_RGBA_TYPE, NULL,
         direct_rendering ? GL_TRUE : GL_FALSE );
-    if( ctxbuffer == NULL || !glXMakeCurrent( display(), glxbuffer, ctxbuffer )
-        || errs.error( true ))
-        { // failed
+    bool failed = ( ctxbuffer == NULL || !glXMakeCurrent( display(), glxbuffer, ctxbuffer ));
+    if( errs1.error( true )) // always check for error( having it all in one if() could skip
+        failed = true;       // it due to evaluation short-circuiting
+    if( failed )
+        {
         if( !direct_rendering )
             {
-            kDebug( 1212 ) << "Couldn't initialize rendering context";
+            kDebug( 1212 ).nospace() << "Couldn't initialize rendering context (0x" << hex << xerror << ")";
             return false;
             }
 	glXMakeCurrent( display(), None, NULL );
-        glXDestroyContext( display(), ctxbuffer );
+        if( ctxbuffer != NULL )
+            glXDestroyContext( display(), ctxbuffer );
         direct_rendering = false; // try again
+        xerror = 0;
+        KXErrorHandler errs2( xerrorhandler );
         ctxbuffer = glXCreateNewContext( display(), fbcbuffer, GLX_RGBA_TYPE, NULL, GL_FALSE );
-        if( ctxbuffer == NULL || !glXMakeCurrent( display(), glxbuffer, ctxbuffer ) || errs.error( true ))
+        bool failed = ( ctxbuffer == NULL || !glXMakeCurrent( display(), glxbuffer, ctxbuffer ));
+        if( errs2.error( true ))
+            failed = true;
+        if( failed )
             {
-            kDebug( 1212 ) << "Couldn't initialize rendering context";
+            kDebug( 1212 ).nospace() << "Couldn't initialize rendering context (0x" << hex << xerror << ")";
             return false;
             }
         }
@@ -363,9 +377,14 @@ bool SceneOpenGL::initBuffer()
         }
     else
         {
-        kDebug( 1212 ) << "Couldn't create output buffer (failed to create overlay window?) !";
+        kError( 1212 ) << "Couldn't create output buffer (failed to create overlay window?) !";
         return false; // error
         }
+    int vis_buffer;
+    glXGetFBConfigAttrib( display(), fbcbuffer, GLX_VISUAL_ID, &vis_buffer );
+    XVisualInfo* visinfo_buffer = glXGetVisualFromFBConfig( display(), fbcbuffer );
+    kDebug( 1212 ) << "Buffer visual (depth " << visinfo_buffer->depth << "): 0x" << QString::number( vis_buffer, 16 );
+    XFree( visinfo_buffer );
     return true;
     }
 
@@ -403,6 +422,10 @@ bool SceneOpenGL::initBufferConfigs()
                                   GLX_BUFFER_SIZE, &value );
             if( value != visual_depth && ( value - alpha ) != visual_depth )
                 continue;
+            glXGetFBConfigAttrib( display(), fbconfigs[ j ],
+                                  GLX_RENDER_TYPE, &value );
+            if( !( value & GLX_RGBA_BIT ))
+                continue;
             int back_value;
             glXGetFBConfigAttrib( display(), fbconfigs[ j ],
                                   GLX_DOUBLEBUFFER, &back_value );
@@ -445,9 +468,17 @@ bool SceneOpenGL::initBufferConfigs()
         XFree( fbconfigs );
     if( fbcbuffer_db == NULL && fbcbuffer_nondb == NULL )
         {
-        kDebug( 1212 ) << "Couldn't find framebuffer configuration for buffer!";
+        kError( 1212 ) << "Couldn't find framebuffer configuration for buffer!";
         return false;
         }
+    for( int i = 0; i <= 32; i++ )
+        {
+        if( fbcdrawableinfo[ i ].fbconfig == NULL )
+            continue;
+        int vis_drawable = 0;
+        glXGetFBConfigAttrib( display(), fbcdrawableinfo[ i ].fbconfig, GLX_VISUAL_ID, &vis_drawable );
+        kDebug( 1212 ) << "Drawable visual (depth " << i << "): 0x" << QString::number( vis_drawable, 16 );
+        }
     return true;
     }
 
@@ -488,6 +519,10 @@ bool SceneOpenGL::initDrawableConfigs()
                                   GLX_BUFFER_SIZE, &value );
             if( value != i && ( value - alpha ) != i )
                 continue;
+            glXGetFBConfigAttrib( display(), fbconfigs[ j ],
+                                  GLX_RENDER_TYPE, &value );
+            if( !( value & GLX_RGBA_BIT ))
+                continue;
             if( tfp_mode )
                 {
                 value = 0;
@@ -558,12 +593,12 @@ bool SceneOpenGL::initDrawableConfigs()
         XFree( fbconfigs );
     if( fbcdrawableinfo[ DefaultDepth( display(), DefaultScreen( display())) ].fbconfig == NULL )
         {
-        kDebug( 1212 ) << "Couldn't find framebuffer configuration for default depth!";
+        kError( 1212 ) << "Couldn't find framebuffer configuration for default depth!";
         return false;
         }
     if( fbcdrawableinfo[ 32 ].fbconfig == NULL )
         {
-        kDebug( 1212 ) << "Couldn't find framebuffer configuration for depth 32!";
+        kError( 1212 ) << "Couldn't find framebuffer configuration for depth 32 (no ARGB GLX visual)!";
         return false;
         }
     return true;
@@ -744,7 +779,7 @@ void SceneOpenGL::windowGeometryShapeChanged( Toplevel* c )
         return;                 // by default
     Window* w = windows[ c ];
     w->discardShape();
-    w->discardTexture();
+    w->checkTextureSize();
     }
 
 void SceneOpenGL::windowOpacityChanged( Toplevel* )
@@ -1122,6 +1157,18 @@ void SceneOpenGL::Window::discardTexture()
     texture.discard();
     }
 
+// This call is used in SceneOpenGL::windowGeometryShapeChanged(),
+// which originally called discardTexture(), however this was causing performance
+// problems with the launch feedback icon - large number of texture rebinds.
+// Since the launch feedback icon does not resize, only changes shape, it
+// is not necessary to rebind the texture (with no strict binding), therefore
+// discard the texture only if size changes.
+void SceneOpenGL::Window::checkTextureSize()
+    {
+    if( texture.size() != size())
+        discardTexture();
+    }
+
 // when the window's composite pixmap is discarded, undo binding it to the texture
 void SceneOpenGL::Window::pixmapDiscarded()
     {
