@@ -1,13 +1,23 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
 Copyright (C) 2003 Lubos Lunak <l.lunak@kde.org>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 //#define QT_CLEAN_NAMESPACE
 #include "tabbox.h"
@@ -455,7 +465,7 @@ void TabBox::paintEvent( QPaintEvent* e )
                   {
                   // draw highlight background
                   if ( (*it) == currentClient() )
-                    p.fillRect(x, y, r.width(), lineHeight, palette().brush( QPalette::Highlight ));
+                    p.fillRect(x, y, r.width(), lineHeight, palette().brush( QPalette::Active, QPalette::Highlight ));
 
                   // draw icon
                   QPixmap icon;
@@ -492,11 +502,11 @@ void TabBox::paintEvent( QPaintEvent* e )
 
                   // draw text
                   if ( (*it) == currentClient() )
-                    p.setPen(palette().color( QPalette::HighlightedText ));
+                    p.setPen(palette().color( QPalette::Active, QPalette::HighlightedText ));
                   else if( (*it)->isMinimized())
                     {
-                    QColor c1 = palette().color( QPalette::Text );
-                    QColor c2 = palette().color( QPalette::Background );
+                    QColor c1 = palette().color( QPalette::Active, QPalette::Text );
+                    QColor c2 = palette().color( QPalette::Active, QPalette::Background );
                     // from kicker's TaskContainer::blendColors()
                     int r1, g1, b1;
                     int r2, g2, b2;
@@ -511,7 +521,7 @@ void TabBox::paintEvent( QPaintEvent* e )
                     p.setPen(QColor( r1, g1, b1 ));
                     }
                   else
-                    p.setPen(palette().color( QPalette::Text ));
+                    p.setPen(palette().color( QPalette::Active, QPalette::Text ));
 
                   p.drawText(x+5 + iconWidth + 8, y, r.width() - 5 - iconWidth - 8, lineHeight,
                               Qt::AlignLeft | Qt::AlignVCenter | Qt::TextSingleLine, s);
@@ -546,13 +556,13 @@ void TabBox::paintEvent( QPaintEvent* e )
             {
             // draw highlight background
             if ( it == desk )  // current desktop
-              p.fillRect(x, y, r.width(), lineHeight, palette().brush( QPalette::Highlight ));
+              p.fillRect(x, y, r.width(), lineHeight, palette().brush( QPalette::Active, QPalette::Highlight ));
 
             p.save();
 
             // draw "icon" (here: number of desktop)
-            p.fillRect(x+5, y+2, iconWidth, iconHeight, palette().brush( QPalette::Base ));
-            p.setPen(palette().color( QPalette::Text ));
+            p.fillRect(x+5, y+2, iconWidth, iconHeight, palette().brush( QPalette::Active, QPalette::Base ));
+            p.setPen(palette().color( QPalette::Active, QPalette::Text ));
             p.drawRect(x+5, y+2, iconWidth, iconHeight);
 
             // draw desktop-number
@@ -564,9 +574,9 @@ void TabBox::paintEvent( QPaintEvent* e )
 
             // draw desktop name text
             if ( it == desk )
-              p.setPen(palette().color( QPalette::HighlightedText ));
+              p.setPen(palette().color( QPalette::Active, QPalette::HighlightedText ));
             else
-              p.setPen(palette().color( QPalette::Text ));
+              p.setPen(palette().color( QPalette::Active, QPalette::Text ));
 
             p.drawText(x+5 + iconWidth + 8, y, r.width() - 5 - iconWidth - 8, lineHeight,
                        Qt::AlignLeft | Qt::AlignVCenter | Qt::TextSingleLine,
@@ -686,10 +696,10 @@ void TabBox::delayedShow()
 
 void TabBox::handleMouseEvent( XEvent* e )
     {
-    XAllowEvents( display(), AsyncPointer, xTime() );
+    XAllowEvents( display(), AsyncPointer, xTime());
     if( !isVisible() && isDisplayed())
         { // tabbox has been replaced, check effects
-            if( effects && static_cast<EffectsHandlerImpl*>(effects)->checkInputWindowEvent( e ))
+        if( effects && static_cast<EffectsHandlerImpl*>(effects)->checkInputWindowEvent( e ))
             return;
         }
     if( e->type != ButtonPress )
