@@ -1,12 +1,22 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 2006 Lubos Lunak <l.lunak@kde.org>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #include "toplevel.h"
 
@@ -45,7 +55,6 @@ Toplevel::~Toplevel()
     delete info;
     }
 
-#ifndef NDEBUG
 kdbgstream& operator<<( kdbgstream& stream, const Toplevel* cl )
     {
     if( cl == NULL )
@@ -87,7 +96,6 @@ kdbgstream& operator<<( kdbgstream& stream, const ConstToplevelList& list )
     stream << ")";
     return stream;
     }
-#endif
 
 void Toplevel::detectShape( Window id )
     {
@@ -134,6 +142,9 @@ void Toplevel::disownDataPassedToDeleted()
 
 NET::WindowType Toplevel::windowType( bool direct, int supported_types ) const
     {
+    if( supported_types == 0 )
+        supported_types = dynamic_cast< const Client* >( this ) != NULL
+            ? SUPPORTED_MANAGED_WINDOW_TYPES_MASK : SUPPORTED_UNMANAGED_WINDOW_TYPES_MASK;
     NET::WindowType wt = info->windowType( supported_types );
     if( direct )
         return wt;
@@ -281,8 +292,8 @@ void Toplevel::getResourceClass()
     XClassHint classHint;
     if( XGetClassHint( display(), window(), &classHint ) ) 
         {
-        // Qt3.2 and older had this all lowercase, Qt3.3 capitalized resource class
-        // force lowercase, so that workarounds listing resource classes still work
+        // Qt3.2 and older had this all lowercase, Qt3.3 capitalized resource class.
+        // Force lowercase, so that workarounds listing resource classes still work.
         resource_name = QByteArray( classHint.res_name ).toLower();
         resource_class = QByteArray( classHint.res_class ).toLower();
         XFree( classHint.res_name );
