@@ -1,12 +1,22 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 2006 Lubos Lunak <l.lunak@kde.org>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #ifndef KWIN_TOPLEVEL_H
 #define KWIN_TOPLEVEL_H
@@ -53,8 +63,9 @@ class Toplevel
         virtual QPoint clientPos() const = 0; // inside of geometry()
         virtual QSize clientSize() const = 0;
 
-    // prefer isXXX() instead
-        NET::WindowType windowType( bool direct = false, int supported_types = SUPPORTED_WINDOW_TYPES_MASK ) const;
+        // prefer isXXX() instead
+        // 0 for supported types means default for managed/unmanaged types
+        NET::WindowType windowType( bool direct = false, int supported_types = 0 ) const;
         bool hasNETSupport() const;
         bool isDesktop() const;
         bool isDock() const;
@@ -382,18 +393,9 @@ inline pid_t Toplevel::pid() const
     return info->pid();
     }
 
-#ifdef NDEBUG
-inline
-kndbgstream& operator<<( kndbgstream& stream, const Toplevel* ) { return stream; }
-inline
-kndbgstream& operator<<( kndbgstream& stream, const ToplevelList& ) { return stream; }
-inline
-kndbgstream& operator<<( kndbgstream& stream, const ConstToplevelList& ) { return stream; }
-#else
 kdbgstream& operator<<( kdbgstream& stream, const Toplevel* );
 kdbgstream& operator<<( kdbgstream& stream, const ToplevelList& );
 kdbgstream& operator<<( kdbgstream& stream, const ConstToplevelList& );
-#endif
 
 KWIN_COMPARE_PREDICATE( WindowMatchPredicate, Toplevel, Window, cl->window() == value );
 KWIN_COMPARE_PREDICATE( FrameIdMatchPredicate, Toplevel, Window, cl->frameId() == value );
