@@ -56,6 +56,7 @@
 #include "plasma/scriptengine.h"
 #include "plasma/shadowitem_p.h"
 #include "plasma/svg.h"
+#include "plasma/svgpanel.h"
 #include "plasma/theme.h"
 #include "plasma/view.h"
 
@@ -184,112 +185,6 @@ public:
         }
     }
 
-    void paintBackground(QPainter* p2, Applet* q, QRectF paintRect)
-    {
-        if (q->formFactor() != Plasma::Planar) {
-            // we don't paint special backgrounds for other form factors
-            // if that changes in the future, this method is where such
-            // background painting code should be added
-            return;
-        }
-
-        // TODO: caching these values might be an idea
-        const int topHeight = background->elementSize("top").height();
-        const int leftWidth = background->elementSize("left").width();
-        const int topOffset = 0 - topHeight;
-        const int leftOffset = 0 - leftWidth;
-
-        if (!cachedBackground || cachedBackground->size() != q->boundingRect().toRect().size()) {
-            QSize contents = contentSize(q).toSize();
-
-            const int contentWidth = contents.width();
-            const int contentHeight = contents.height();
-
-            background->resize();
-
-            const int topWidth = background->elementSize("top").width();
-            const int leftHeight = background->elementSize("left").height();
-            const int rightWidth = background->elementSize("right").width();
-            const int bottomHeight = background->elementSize("bottom").height();
-
-            // contents top-left corner is (0,0).  We need to draw up and left of that
-            const int rightOffset = contentWidth;
-            const int bottomOffset = contentHeight;
-            const int contentTop = 0;
-            const int contentLeft = 0;
-
-            delete cachedBackground;
-            cachedBackground = new QPixmap(leftWidth + contentWidth + rightWidth, topHeight + contentHeight + bottomHeight);
-            cachedBackground->fill(Qt::transparent);
-            QPainter p(cachedBackground);
-            p.translate(leftWidth, topHeight);
-            p.setCompositionMode(QPainter::CompositionMode_Source);
-            p.setRenderHint(QPainter::SmoothPixmapTransform);
-
-            //FIXME: This is a hack to fix a drawing problems with svg files where a thin transparent border is drawn around the svg image.
-            //       the transparent border around the svg seems to vary in size depending on the size of the svg and as a result increasing the
-            //       svn image by 2 all around didn't resolve the issue. For now it resizes based on the border size.
-
-            background->resize(contentWidth, contentHeight);
-            background->paint(&p, QRect(contentLeft-leftWidth, contentTop-topHeight, contentWidth+leftWidth*2, contentHeight+topHeight*2), "center");
-            background->resize();
-
-            background->paint(&p, QRect(leftOffset, topOffset, leftWidth, topHeight), "topleft");
-            background->paint(&p, QRect(rightOffset, topOffset,rightWidth, topHeight), "topright");
-            background->paint(&p, QRect(leftOffset, bottomOffset, leftWidth, bottomHeight), "bottomleft");
-            background->paint(&p, QRect(rightOffset, bottomOffset, rightWidth, bottomHeight), "bottomright");
-
-            if (background->elementExists("hint-stretch-borders")) {
-                background->paint(&p, QRect(leftOffset, contentTop, leftWidth, contentHeight), "left");
-                background->paint(&p, QRect(rightOffset, contentTop, rightWidth, contentHeight), "right");
-                background->paint(&p, QRect(contentLeft, topOffset, contentWidth, topHeight), "top");
-                background->paint(&p, QRect(contentLeft, bottomOffset, contentWidth, bottomHeight), "bottom");
-            } else {
-                QPixmap left(leftWidth, leftHeight);
-                left.fill(Qt::transparent);
-                {
-                    QPainter sidePainter(&left);
-                    sidePainter.setCompositionMode(QPainter::CompositionMode_Source);
-                    background->paint(&sidePainter, QPoint(0, 0), "left");
-                }
-                p.drawTiledPixmap(QRect(leftOffset, contentTop, leftWidth, contentHeight), left);
-
-                QPixmap right(rightWidth, leftHeight);
-                right.fill(Qt::transparent);
-                {
-                    QPainter sidePainter(&right);
-                    sidePainter.setCompositionMode(QPainter::CompositionMode_Source);
-                    background->paint(&sidePainter, QPoint(0, 0), "right");
-                }
-                p.drawTiledPixmap(QRect(rightOffset, contentTop, rightWidth, contentHeight), right);
-
-                QPixmap top(topWidth, topHeight);
-                top.fill(Qt::transparent);
-                {
-                    QPainter sidePainter(&top);
-                    sidePainter.setCompositionMode(QPainter::CompositionMode_Source);
-                    background->paint(&sidePainter, QPoint(0, 0), "top");
-                }
-                p.drawTiledPixmap(QRect(contentLeft, topOffset, contentWidth, topHeight), top);
-
-                QPixmap bottom(topWidth, bottomHeight);
-                bottom.fill(Qt::transparent);
-                {
-                    QPainter sidePainter(&bottom);
-                    sidePainter.setCompositionMode(QPainter::CompositionMode_Source);
-                    background->paint(&sidePainter, QPoint(0, 0), "bottom");
-                }
-                p.drawTiledPixmap(QRect(contentLeft, bottomOffset, contentWidth, bottomHeight), bottom);
-            }
-
-            // re-enable this once Qt's svg rendering is un-buggered
-            //background->resize(contentWidth, contentHeight);
-            //background->paint(&p, QRect(contentLeft, contentTop, contentWidth, contentHeight), "center");
-        }
-
-        p2->drawPixmap(paintRect, *cachedBackground, paintRect.translated(-leftOffset,-topOffset));
-    }
-
     QSizeF contentSize(const Applet* q)
     {
         if (failureText) {
@@ -317,10 +212,10 @@ public:
     void getBorderSize(int& left , int& top, int &right, int& bottom)
     {
         if (background) {
-            top = background->elementSize("top").height();
-            left = background->elementSize("left").width();
-            right = background->elementSize("right").width();
-            bottom = background->elementSize("bottom").height();
+            top = background->marginSize(Plasma::TopMargin);
+            left = background->marginSize(Plasma::LeftMargin);
+            right = background->marginSize(Plasma::RightMargin);
+            bottom = background->marginSize(Plasma::BottomMargin);
         } else {
             top = left = right = bottom = 0;
         }
@@ -393,7 +288,7 @@ public:
     QList<QObject*> watchedForFocus;
     QStringList loadedEngines;
     static uint s_maxAppletId;
-    Plasma::Svg *background;
+    Plasma::SvgPanel *background;
     Plasma::LineEdit *failureText;
     ScriptEngine* scriptEngine;
     ConfigXml* configXml;
@@ -505,11 +400,14 @@ KConfigGroup Applet::config() const
 KConfigGroup Applet::globalConfig() const
 {
     KConfigGroup globalAppletConfig;
-    if (containment() && containment()->corona()) {
-        KSharedConfig::Ptr coronaConfig = containment()->corona()->config();
-        globalAppletConfig = KConfigGroup(coronaConfig, "AppletGlobals");
+    const Containment *c = isContainment() ? dynamic_cast<const Containment*>(this) : containment();
+    QString group = isContainment() ? "ContainmentGlobals" : "AppletGlobals";
+
+    if (c && c->corona()) {
+        KSharedConfig::Ptr coronaConfig = c->corona()->config();
+        globalAppletConfig = KConfigGroup(coronaConfig, group);
     } else {
-        globalAppletConfig = KConfigGroup(KGlobal::config(), "AppletGlobals");
+        globalAppletConfig = KConfigGroup(KGlobal::config(), group);
     }
 
     return KConfigGroup(&globalAppletConfig, globalName());
@@ -645,7 +543,8 @@ bool Applet::isKioskImmutable() const
 
 void Applet::setImmutable(bool immutable)
 {
-    if (d->immutable == immutable) {
+    if (d->immutable == immutable ||
+        (immutable && d->kioskImmutable)) {
         return;
     }
 
@@ -663,7 +562,7 @@ void Applet::setDrawStandardBackground(bool drawBackground)
 {
     if (drawBackground) {
         if (!d->background) {
-            d->background = new Plasma::Svg("widgets/background");
+            d->background = new Plasma::SvgPanel("widgets/background");
             updateGeometry();
         }
     } else if (d->background) {
@@ -706,13 +605,14 @@ void Applet::setFailedToLaunch(bool failed, const QString& reason)
 
     d->failureText = 0;
     qDeleteAll(QGraphicsItem::children());
-    delete layout();
+    setLayout(0);
 
     if (failed) {
         setDrawStandardBackground(true);
         Layout* failureLayout = new BoxLayout(BoxLayout::TopToBottom, this);
         failureLayout->setMargin(0);
         d->failureText = new LineEdit(this);
+        d->failureText->setTextInteractionFlags( Qt::TextSelectableByMouse );
         d->failureText->setStyled(false);
         d->failureText->document()->setTextWidth(200);
         d->failureText->setHtml(visibleFailureText(reason));
@@ -742,7 +642,7 @@ void Applet::setNeedsConfiguring(bool needsConfig)
     d->needsConfig = needsConfig;
     prepareGeometryChange();
     qDeleteAll(QGraphicsItem::children());
-    delete layout();
+    setLayout(0);
 
     if (needsConfig) {
         setDrawStandardBackground(true);
@@ -757,7 +657,7 @@ void Applet::setNeedsConfiguring(bool needsConfig)
 void Applet::performSetupConfig()
 {
     qDeleteAll(QGraphicsItem::children());
-    delete layout();
+    setLayout(0);
     showConfigurationInterface();
 }
 
@@ -765,8 +665,11 @@ void Applet::checkImmutability()
 {
     d->kioskImmutable = globalConfig().isImmutable() || config().isImmutable() ||
                         (containment() && containment()->isKioskImmutable()) ||
-                        (dynamic_cast<Corona*>( scene() ) && static_cast<Corona*>(scene())->isKioskImmutable());
-    setImmutable(d->kioskImmutable);
+                        (dynamic_cast<Corona*>(scene()) && static_cast<Corona*>(scene())->isKioskImmutable());
+
+    if (d->kioskImmutable) {
+        updateConstraints(ImmutableConstraint);
+    }
 }
 
 void Applet::flushUpdatedConstraints()
@@ -886,9 +789,11 @@ void Applet::paintWidget(QPainter *painter, const QStyleOptionGraphicsItem *opti
         painter->setRenderHint(QPainter::Antialiasing);
     }
 
-    if (d->background) {
+    if (d->background &&
+        formFactor() != Plasma::Vertical &&
+        formFactor() != Plasma::Horizontal) {
         //kDebug() << "option rect is" << option->rect;
-        d->paintBackground(painter, this, option->rect);
+        d->background->paint(painter, option->rect);
     }
 
     if (!d->failed && !d->needsConfig) {
@@ -928,14 +833,26 @@ FormFactor Applet::formFactor() const
 
 Containment* Applet::containment() const
 {
+/*
+ * while this is probably "more correct", much of the code in applet assumes containment
+ * returns zero in the case that this is a containment itself.
+ * if (isContainment()) {
+        return dynamic_cast<Containment*>(const_cast<Applet*>(this));
+    }
+*/
+
     QGraphicsItem *parent = parentItem();
     Containment *c = 0;
+
     while (parent) {
-        if ((c = dynamic_cast<Containment*>(parent))) {
+        Containment *possibleC =  dynamic_cast<Containment*>(parent);
+        if (possibleC && possibleC->isContainment()) {
+            c = possibleC;
             break;
         }
         parent = parent->parentItem();
     }
+
     return c;
 }
 
@@ -1341,6 +1258,9 @@ void Applet::setGeometry(const QRectF& geometry)
             managingLayout()->invalidate();
         }
 
+        if (d->background) {
+            d->background->resize(size());
+        }
         updatedConstraints |= Plasma::SizeConstraint;
     }
 
