@@ -47,7 +47,7 @@ class Package;
  * First, it is the base class for the plugin system and therefore is the
  * interface to applets for host applications. It also handles the life time
  * management of data engines (e.g. all data engines accessed via
- * Applet::datEngine(const QString&) are properly deref'd on Applet
+ * Applet::dataEngine(const QString&) are properly deref'd on Applet
  * destruction), background painting (allowing for consistent and complex
  * look and feel in just one line of code for applets), loading and starting
  * of scripting support for each applet, providing access to the associated
@@ -68,6 +68,7 @@ class PLASMA_EXPORT Applet : public Widget
     Q_PROPERTY( bool needsConfiguring READ needsConfiguring WRITE setNeedsConfiguring )
     Q_PROPERTY( QRectF boundingRect READ boundingRect )
     Q_PROPERTY( QRectF geometry READ geometry WRITE setGeometry )
+    Q_PROPERTY( bool shouldConserveResources READ shouldConserveResources )
 
     public:
         typedef QList<Applet*> List;
@@ -102,7 +103,7 @@ class PLASMA_EXPORT Applet : public Widget
          * This method is called once the applet is loaded and added to a Corona.
          * If the applet requires a QGraphicsScene or has an particularly intensive
          * set of initialization routines to go through, consider implementing it
-         * in this method instead of the contsructor.
+         * in this method instead of the constructor.
          **/
         virtual void init();
 
@@ -127,7 +128,7 @@ class PLASMA_EXPORT Applet : public Widget
          *
          * @param group the name of the group to access
          **/
-        KConfigGroup config(const QString& group) const;
+        KConfigGroup config(const QString &group) const;
 
         /**
          * Saves state information about this applet.
@@ -216,11 +217,38 @@ class PLASMA_EXPORT Applet : public Widget
         virtual Location location() const;
 
         /**
-         * Returns the area within which contents can be painted. If there is no
-         * background, then this is equivalent to boundingRect().size()
+         * Returns the rect that the contents are positioned within in local coordinates
+         */
+        QRectF contentRect() const;
+
+        /**
+         * Returns the area within which contents can be painted.
          **/
         QSizeF contentSize() const;
 
+        /**
+         * Sets the content size.
+         *
+         * @note Normally an applet should never
+         * call this directly except in the constructor to provide a default
+         * size
+         *
+         * @arg size the new size of the contents area
+         */
+        void setContentSize(const QSizeF &size);
+
+        /**
+         * Sets the content size.
+         *
+         * @note Normally an applet should never
+         * call this directly except in the constructor to provide a default
+         * size
+         *
+         * @arg width the new width of the contents area
+         * @arg height the new height of the contents area
+         */
+        void setContentSize(int width, int height);
+
         /**
          * Returns an ideal size for the applet's content.
          * Applets can re-implement this to provide a suitable size based
@@ -234,6 +262,42 @@ class PLASMA_EXPORT Applet : public Widget
          */
         virtual QSizeF contentSizeHint() const;
 
+        /**
+         * Sets the minimum size for the content of this applet
+         */
+        void setMinimumContentSize(const QSizeF &minSize);
+
+        /**
+         * Sets the minimum size for the content of this applet
+         *
+         * @arg minWidth the new minimum width of the contents area
+         * @arg minHeight the new minimum height of the contents area
+         */
+        void setMinimumContentSize(int minWidth, int minHeight);
+
+        /**
+         * Get the minimum size for the content of this applet
+         */
+        QSizeF minimumContentSize() const;
+
+        /**
+         * Sets the maximum size for the content of this applet.
+         */
+        void setMaximumContentSize(const QSizeF &maxSize);
+
+        /**
+         * Sets the maximum size for the content of this applet
+         *
+         * @arg maxWidth the new maximum width of the contents area
+         * @arg maxHeight the new maximum height of the contents area
+         */
+        void setMaximumContentSize(int maxWidth, int maxHeight);
+
+        /**
+         * Get the minimum size for the content of this applet
+         */
+        QSizeF maximumContentSize() const;
+
         /**
          * Returns a list of all known applets.
          *
@@ -270,23 +334,15 @@ class PLASMA_EXPORT Applet : public Widget
          *                  list containing only applets not specifically
          *                  registered to an application.
          * @return list of categories
+         * @param visibleOnly true if it should only return applets that are marked as visible
          */
-        static QStringList knownCategories(const QString &parentApp = QString());
+        static QStringList knownCategories(const QString &parentApp = QString(), bool visibleOnly = true);
 
         /**
          * @return true if this plasmoid provides a GUI configuration
          **/
         bool hasConfigurationInterface();
 
-        /**
-         * Reimplement this slot to show a configuration dialog.
-         *
-         * Let the user play with the plasmoid options.
-         * Called when the user selects the configure entry
-         * from the context menu.
-         */
-        virtual void showConfigurationInterface();
-
         /**
          * Attempts to load an applet
          *
@@ -343,6 +399,14 @@ class PLASMA_EXPORT Applet : public Widget
          */
         QString pluginName() const;
 
+        /**
+         * Whether the applet should conserve resources. If true, try to avoid doing stuff which
+         * is computationally heavy. Try to conserve power and resources.
+         *
+         * @return true if it should conserve resources, false if it does not.
+         */
+        bool shouldConserveResources() const;
+
         /**
          * Returns the icon related to this applet
          **/
@@ -379,11 +443,9 @@ class PLASMA_EXPORT Applet : public Widget
         bool isImmutable() const;
 
         /**
-         * Sets whether or not this applet is immutable or not.
-         *
-         * @arg immutable true if this applet should not be changeable
-         **/
-        void setImmutable(bool immutable);
+         * @return true if this applet is immutable due to Kiosk settings
+         */
+        bool isKioskImmutable() const;
 
         /**
          * @return returns whether or not the applet is using the standard
@@ -395,7 +457,7 @@ class PLASMA_EXPORT Applet : public Widget
          * Sets whether the applet should automatically draw the standard
          * background.
          *
-         * Defaults to false
+         * Defaults to true
          **/
         void setDrawStandardBackground(bool drawBackground);
 
@@ -477,14 +539,26 @@ class PLASMA_EXPORT Applet : public Widget
         virtual QSizeF sizeHint() const;
 
         /**
-        * Sets the geometry of this Applet.
-        */
-        /**
-        * Sets the geometry of this Plasma::Applet
-        * @param geometry the geometry to apply to this Plasma::Applet.
-        */
+         * Sets the geometry of this Plasma::Applet
+         * @param geometry the geometry to apply to this Plasma::Applet.
+         */
         void setGeometry(const QRectF &geometry);
 
+        /**
+         * Sets whether or not this Applet is acting as a Containment
+         */
+        void setIsContainment(bool isContainment);
+
+        /**
+         * @return true if this Applet is currently being used as a Containment, false otherwise
+         */
+        bool isContainment() const;
+
+        /**
+         * @internal
+         */
+        void resetConfigurationObject();
+
     Q_SIGNALS:
         /**
          * Emitted when the applet needs to take (or lose) keyboard focus.
@@ -501,12 +575,55 @@ class PLASMA_EXPORT Applet : public Widget
          **/
         void requestFocus( bool focus );
 
+        /**
+         * Emitted whenever the applet makes a geometry change, so that views
+         * can coordinate themselves with these changes if they desire.
+         */
+        void geometryChanged();
+
+        /**
+         * Emitted when an applet has changed values in its configuration
+         * and wishes for them to be saved at the next save point. As this implies
+         * disk activity, this signal should be used with care.
+         *
+         * @note This does not need to be emitted from saveState by individual
+         * applets.
+         */
+        void configNeedsSaving();
+
     public Q_SLOTS:
+        /**
+         * Sets whether or not this applet is immutable or not.
+         *
+         * @arg immutable true if this applet should not be changeable
+         **/
+        void setImmutable(bool immutable);
+
         /**
          * Destroys the applet; it will be deleted and configurations reset.
          */
         void destroy();
 
+        /**
+         * Reimplement this slot to show a configuration dialog.
+         *
+         * Let the user play with the plasmoid options.
+         * Called when the user selects the configure entry
+         * from the context menu.
+         */
+        virtual void showConfigurationInterface();
+
+        /**
+         * Sends all pending contraints updates to the applet. Will usually
+         * be called automatically, but can also be called manually if needed.
+         */
+        void flushUpdatedConstraints();
+
+        /**
+         * @return the Containment, if any, this applet belongs to
+         **/
+        Containment* containment() const;
+
     protected:
         /**
          * Called when a request to save the state of the applet is made
@@ -569,24 +686,19 @@ class PLASMA_EXPORT Applet : public Widget
         /**
          * Reimplemented from QGraphicsItem
          */
-        void contextMenuEvent(QGraphicsSceneContextMenuEvent *contextMenuEvent);
-
-        /**
-         * @internal for adjusting the shadow
-         */
         QVariant itemChange(GraphicsItemChange change, const QVariant &value);
 
-        /**
-         * @return the Containment, if any, this applet belongs to
-         **/
-        Containment* containment() const;
-
     protected Q_SLOTS:
         /**
          * @internal used to show the configuration of an applet on first show
          */
         void performSetupConfig();
 
+        /**
+         * @internal used to check the immutability of the item in the config file
+         */
+        void checkImmutability();
+
     private:
         Q_DISABLE_COPY(Applet)
 
