@@ -59,7 +59,6 @@ public:
           formFactor(Planar),
           location(Floating),
           screen(-1),
-          immutable(false),
           toolbox(0),
           type(Containment::NoContainmentType)
     {
@@ -87,7 +86,6 @@ public:
     Applet::List applets;
     QMap<Applet*, AppletHandle*> handles;
     int screen;
-    bool immutable;
     DesktopToolbox *toolbox;
     Containment::Type type;
 };
@@ -184,14 +182,11 @@ void Containment::setContainmentType(Containment::Type type)
             Plasma::Widget *addWidgetTool = addToolBoxTool("addwidgets", "list-add", i18n("Add Widgets"));
             connect(addWidgetTool, SIGNAL(clicked()), this, SIGNAL(showAddWidgets()));
 
-//zooming provides no functionality for 4.0 (not implemented yet) and will confuse user
-#if 0
             Plasma::Widget *zoomInTool = addToolBoxTool("zoomIn", "zoom-in", i18n("Zoom In"));
             connect(zoomInTool, SIGNAL(clicked()), this, SIGNAL(zoomIn()));
 
             Plasma::Widget *zoomOutTool = addToolBoxTool("zoomOut", "zoom-out", i18n("Zoom Out"));
             connect(zoomOutTool, SIGNAL(clicked()), this, SIGNAL(zoomOut()));
-#endif
         }
     } else {
         delete d->toolbox;
@@ -207,7 +202,7 @@ Corona* Containment::corona() const
 void Containment::contextMenuEvent(QGraphicsSceneContextMenuEvent* event)
 {
     //kDebug() << "let's see if we manage to get a context menu here, huh";
-    if (!scene() || !KAuthorized::authorizeKAction("desktop_contextmenu")) {
+    if (!isContainment() || !scene() || !KAuthorized::authorizeKAction("desktop_contextmenu")) {
         Applet::contextMenuEvent(event);
         return;
     }
@@ -222,39 +217,30 @@ void Containment::contextMenuEvent(QGraphicsSceneContextMenuEvent* event)
 
     while (item) {
         applet = qgraphicsitem_cast<Applet*>(item);
-        if (applet) {
+        if (applet && !applet->isContainment()) {
             break;
         }
 
+        // applet may have a value due to finding a containment!
+        applet = 0;
         item = item->parentItem();
     }
 
     KMenu desktopMenu;
     //kDebug() << "context menu event " << (QObject*)applet;
-    if (!applet) {
-        if (!scene() || (static_cast<Corona*>(scene())->isImmutable() && !KAuthorized::authorizeKAction("unlock_desktop"))) {
-            //kDebug() << "immutability";
-            Applet::contextMenuEvent(event);
-            return;
-        }
-
-        //FIXME: change this to show this only in debug mode (or not at all?)
-        //       before final release
-        QList<QAction*> actions = contextActions();
-
-        if (actions.count() < 1) {
-            //kDebug() << "no applet, but no actions";
-            Applet::contextMenuEvent(event);
-            return;
-        }
-
-        foreach(QAction* action, actions) {
-            desktopMenu.addAction(action);
-        }
-    } else {
+    if (applet) {
         bool hasEntries = false;
+
+        QList<QAction*> actions = applet->contextActions();
+        if (!actions.isEmpty()) {
+            foreach(QAction* action, actions) {
+                desktopMenu.addAction(action);
+            }
+            hasEntries = true;
+        }
+
         if (applet->hasConfigurationInterface()) {
-            QAction* configureApplet = new QAction(i18n("%1 Settings...", applet->name()), &desktopMenu);
+            QAction* configureApplet = new QAction(i18n("%1 Settings", applet->name()), &desktopMenu);
             configureApplet->setIcon(KIcon("configure"));
             connect(configureApplet, SIGNAL(triggered(bool)),
                     applet, SLOT(showConfigurationInterface()));
@@ -262,7 +248,29 @@ void Containment::contextMenuEvent(QGraphicsSceneContextMenuEvent* event)
             hasEntries = true;
         }
 
+        QList<QAction*> containmentActions = contextActions();
+        if (containmentActions.count() > 0) {
+            if (hasEntries) {
+                desktopMenu.addSeparator();
+            }
+            hasEntries = true;
+            QMenu *containmentActionMenu = &desktopMenu;
+
+            if (actions.count() > 0 && containmentActions.count() > 2) {
+                containmentActionMenu = new KMenu(i18n("%1 Options", name()), &desktopMenu);
+                desktopMenu.addMenu(containmentActionMenu);
+            }
+
+            foreach(QAction* action, containmentActions) {
+                containmentActionMenu->addAction(action);
+            }
+        }
+
         if (scene() && !static_cast<Corona*>(scene())->isImmutable()) {
+            if (hasEntries) {
+                desktopMenu.addSeparator();
+            }
+
             QAction* closeApplet = new QAction(i18n("Remove this %1", applet->name()), &desktopMenu);
             QVariant appletV;
             appletV.setValue((QObject*)applet);
@@ -274,20 +282,29 @@ void Containment::contextMenuEvent(QGraphicsSceneContextMenuEvent* event)
             hasEntries = true;
         }
 
-        QList<QAction*> actions = applet->contextActions();
-        if (!actions.isEmpty()) {
-            desktopMenu.addSeparator();
-            foreach(QAction* action, actions) {
-                desktopMenu.addAction(action);
-            }
-            hasEntries = true;
-        }
-
         if (!hasEntries) {
             Applet::contextMenuEvent(event);
             kDebug() << "no entries";
             return;
         }
+    } else {
+        if (!scene() || (static_cast<Corona*>(scene())->isImmutable() && !KAuthorized::authorizeKAction("unlock_desktop"))) {
+            //kDebug() << "immutability";
+            Applet::contextMenuEvent(event);
+            return;
+        }
+
+        QList<QAction*> actions = contextActions();
+
+        if (actions.count() < 1) {
+            //kDebug() << "no applet, but no actions";
+            Applet::contextMenuEvent(event);
+            return;
+        }
+
+        foreach(QAction* action, actions) {
+            desktopMenu.addAction(action);
+        }
     }
 
     event->accept();
@@ -315,10 +332,9 @@ void Containment::setFormFactor(FormFactor formFactor)
 
     //kDebug() << "switching FF to " << formFactor;
     d->formFactor = formFactor;
-    Layout *lay = layout();
-    setLayout(0);
-    delete lay;
-    lay = 0;
+    Layout *lay = 0;
+    //note: setting a new layout autodeletes the old one
+    //and creating a layout calls setLayout on the parent
 
     switch (d->formFactor) {
         case Planar:
@@ -336,9 +352,11 @@ void Containment::setFormFactor(FormFactor formFactor)
             break;
         case MediaCenter:
             //FIXME: need a layout type here!
+            setLayout(0); //auto-delete
             break;
         default:
             kDebug() << "This can't be happening! Or... can it? ;)" << d->formFactor;
+            setLayout(0); //auto-delete
             break;
     }
 
@@ -367,6 +385,19 @@ void Containment::setLocation(Location location)
         return;
     }
 
+
+    bool emitGeomChange = false;
+
+    if ((location == TopEdge || location == BottomEdge) &&
+        (d->location == TopEdge || d->location == BottomEdge)) {
+        emitGeomChange = true;
+    }
+
+    if ((location == RightEdge || location == LeftEdge) &&
+        (d->location == RightEdge || d->location == LeftEdge)) {
+        emitGeomChange = true;
+    }
+
     d->location = location;
 
     foreach (Applet* applet, d->applets) {
@@ -374,6 +405,13 @@ void Containment::setLocation(Location location)
     }
 
     setScreen(screen());
+
+    if (emitGeomChange) {
+        // our geometry on the scene will not actually change,
+        // but for the purposes of views it has
+        emit geometryChanged();
+    }
+
     updateConstraints(Plasma::LocationConstraint);
 }
 
@@ -405,63 +443,9 @@ Applet* Containment::addApplet(const QString& name, const QVariantList& args, ui
         applet = new Applet;
     }
 
-    switch (containmentType()) {
-    case PanelContainment:
-    {
-        //panels don't want backgrounds, which is important when setting geometry
-        applet->setDrawStandardBackground(false);
-
-        // Calculate where the user wants the applet to go before adding it
-        int index = -1;
-        QPointF position = appletGeometry.topLeft();
-        BoxLayout *l = dynamic_cast<BoxLayout *>(layout());
-        if (!delayInit && l && position != QPointF(-1, -1)) {
-            foreach (Applet *existingApplet, d->applets) {
-                if (formFactor() == Horizontal) {
-                    qreal middle = (existingApplet->geometry().left() +
-                            existingApplet->geometry().right()) / 2.0;
-                    // Applets are checked in order so there is no need to check
-                    // if the position is equal to or greater than the applet's
-                    // leftmost point. This also allows for dropping in the gap
-                    // between applets.
-                    if (position.x() < middle) {
-                        index = l->indexOf(existingApplet);
-                        break;
-                    } else if (position.x() <= existingApplet->geometry().right()) {
-                        index = l->indexOf(existingApplet) + 1;
-                        break;
-                    }
-                } else {
-                    qreal middle = (existingApplet->geometry().top() +
-                            existingApplet->geometry().bottom()) / 2.0;
-                    if (position.y() < middle) {
-                        index = l->indexOf(existingApplet);
-                        break;
-                    } else if (position.y() <= existingApplet->geometry().bottom()) {
-                        index = l->indexOf(existingApplet) + 1;
-                        break;
-                    }
-                }
-            }
-        }
-
-        addApplet(applet);
-        prepareApplet(applet, delayInit);
-
-        // Reposition the applet after adding has been done
-        if (index != -1) {
-            l->insertItem(index, l->takeAt(l->indexOf(applet)));
-            d->applets.removeAll(applet);
-            d->applets.insert(index, applet);
-        }
-
-        break;
-    }
-
-    default:
-        addApplet(applet);
-        prepareApplet(applet, delayInit);
+    addApplet(applet, appletGeometry.topLeft(), delayInit);
 
+    if (containmentType() != PanelContainment) {
         //kDebug() << "adding applet" << applet->name() << "with a default geometry of" << appletGeometry << appletGeometry.isValid();
         if (appletGeometry.isValid()) {
             applet->setGeometry(appletGeometry);
@@ -485,6 +469,108 @@ Applet* Containment::addApplet(const QString& name, const QVariantList& args, ui
     return applet;
 }
 
+//pos must be relative to the containment already. use mapfromscene.
+//what we're trying to do here for panels is make the applet go to the requested position,
+//or somewhere close to it, and get integrated properly into the containment as if it were created
+//there.
+void Containment::addApplet(Applet *applet, const QPointF &pos, bool dontInit)
+{
+    if (!applet) {
+        kDebug() << "adding null applet!?!";
+        return;
+    }
+
+    Containment *currentContainment = applet->containment();
+    int index = -1;
+
+    if (containmentType() == PanelContainment) {
+        //panels don't want backgrounds, which is important when setting geometry
+        applet->setDrawStandardBackground(false);
+
+        // Calculate where the user wants the applet to go before adding it
+        //so long as this isn't a new applet with a delayed init
+        if (! dontInit || (currentContainment && currentContainment != this)) {
+            index = indexAt(pos);
+        }
+    }
+
+    if (currentContainment && currentContainment != this) {
+        applet->removeSceneEventFilter(currentContainment);
+        KConfigGroup oldConfig = applet->config();
+        applet->resetConfigurationObject();
+        currentContainment->d->applets.removeAll(applet);
+        addChild(applet);
+
+        //FIXME: we will lose parts of the existing configuration that aren't
+        //       resaved. but KConfigGroup::reparent does not exist in 4.0.x
+        // now move the old config to the new location
+        // KConfigGroup c = config().group("Applets").group(QString::number(applet->id()));
+        // oldConfig.reparent(&c);
+    } else {
+        addChild(applet);
+    }
+
+    d->applets << applet;
+
+    connect(applet, SIGNAL(destroyed(QObject*)),
+            this, SLOT(appletDestroyed(QObject*)));
+
+    if (containmentType() == PanelContainment) {
+        // Reposition the applet after adding has been done
+        if (index != -1) {
+            BoxLayout *l = dynamic_cast<BoxLayout *>(layout());
+            l->insertItem(index, l->takeAt(l->indexOf(applet)));
+            d->applets.removeAll(applet);
+            d->applets.insert(index, applet);
+        }
+    } else {
+        //FIXME if it came from a panel its bg was disabled
+        //maybe we should expect the applet to handle that on a constraint update?
+
+        //should we really do this? hell, do we have any business playing with the geometry of
+        //non-panel applets at all?
+        if (pos != QPointF(-1, -1)) {
+            applet->setPos(pos);
+        }
+    }
+    prepareApplet(applet, dontInit); //must at least flush constraints
+}
+
+//containment-relative pos... right?
+int Containment::indexAt(const QPointF &pos) const
+{
+    if (pos == QPointF(-1, -1)) {
+        return -1;
+    }
+    BoxLayout *l = dynamic_cast<BoxLayout *>(layout());
+    if (l) {
+        foreach (Applet *existingApplet, d->applets) {
+            if (formFactor() == Horizontal) {
+                qreal middle = (existingApplet->geometry().left() +
+                        existingApplet->geometry().right()) / 2.0;
+                // Applets are checked in order so there is no need to check
+                // if the position is equal to or greater than the applet's
+                // leftmost point. This also allows for dropping in the gap
+                // between applets.
+                if (pos.x() < middle) {
+                    return l->indexOf(existingApplet);
+                } else if (pos.x() <= existingApplet->geometry().right()) {
+                    return l->indexOf(existingApplet) + 1;
+                }
+            } else {
+                qreal middle = (existingApplet->geometry().top() +
+                        existingApplet->geometry().bottom()) / 2.0;
+                if (pos.y() < middle) {
+                    return l->indexOf(existingApplet);
+                } else if (pos.y() <= existingApplet->geometry().bottom()) {
+                    return l->indexOf(existingApplet) + 1;
+                }
+            }
+        }
+    }
+    return -1;
+}
+
 void Containment::prepareApplet(Applet *applet, bool delayInit)
 {
     if (delayInit) {
@@ -550,37 +636,6 @@ bool Containment::regionIsEmpty(const QRectF &region, Applet *ignoredApplet) con
     return true;
 }
 
-void Containment::addApplet(Applet *applet)
-{
-    Containment *currentContainment = applet->containment();
-    if (currentContainment && currentContainment != this) {
-        applet->removeSceneEventFilter(currentContainment);
-        KConfigGroup oldConfig = applet->config();
-        applet->resetConfigurationObject();
-        currentContainment->d->applets.removeAll(applet);
-        addChild(applet);
-
-        // now move the old config to the new location
-        KConfigGroup c = config();
-        c = KConfigGroup(&c, "Applets");
-        c = KConfigGroup(&c, QString::number(applet->id()));
-        //FIXME: without the next line, we don't save the applet configuration in the new location!
-        //       this is pending a patch to KConfigGroup, however, so can't go in right now
-        //oldConfig.reparent(&c);
-    } else {
-        addChild(applet);
-    }
-
-    d->applets << applet;
-
-    if (currentContainment) {
-        applet->installSceneEventFilter(this);
-    }
-
-    connect(applet, SIGNAL(destroyed(QObject*)),
-            this, SLOT(appletDestroyed(QObject*)));
-}
-
 void Containment::appletDestroyed(QObject* object)
 {
     // we do a static_cast here since it really isn't an Applet by this
@@ -674,14 +729,20 @@ void Containment::setScreen(int screen)
             //kDebug() << "setting geometry to" << desktop->screenGeometry(screen) << r << geometry();
         } else if (containmentType() == PanelContainment) {
             QRect r = desktop->screenGeometry(screen);
-            //kDebug() << "we are a panel on" << r << ", let's move ourselves to a negative coordinate system" << -r.height() - INTER_CONTAINMENT_MARGIN;
-            int vertOffset = r.height() + INTER_CONTAINMENT_MARGIN;
+            //kDebug() << "we are a panel on" << r << ", let's move ourselves to a negative coordinate system" << -(r.x() * 2) - r.height() - INTER_CONTAINMENT_MARGIN;
+            // panels are moved into negative coords; we double the x() so that each screen get's
+            // it's own area for panels
+            int vertOffset = (r.y() * 2) + r.height() + INTER_CONTAINMENT_MARGIN;
             translate(0, -vertOffset);
         }
     }
 
+    int oldScreen = d->screen;
     d->screen = screen;
     updateConstraints(Plasma::ScreenConstraint);
+    if (oldScreen != screen) {
+        emit screenChanged(oldScreen, screen, this);
+    }
 }
 
 int Containment::screen() const
@@ -783,7 +844,6 @@ void Containment::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
 bool Containment::sceneEventFilter(QGraphicsItem *watched, QEvent *event)
 {
     Applet *applet = qgraphicsitem_cast<Applet*>(watched);
-    //QEvent::GraphicsSceneHoverEnter
 
     // Otherwise we're watching something we shouldn't be...
     //kDebug() << "got sceneEvent";
@@ -794,19 +854,31 @@ bool Containment::sceneEventFilter(QGraphicsItem *watched, QEvent *event)
 
     switch (event->type()) {
     case QEvent::GraphicsSceneHoverEnter:
-        //kDebug() << "got hoverenterEvent" << d->immutable << " " << applet->isImmutable();
-        if (!d->immutable && !applet->isImmutable() && !corona()->isImmutable() && !d->handles.contains(applet)) {
-            //kDebug() << "generated applet handle";
-            //TODO: there should be a small delay on showing these. they pop up too quickly/easily
-            //      right now
-            AppletHandle *handle = new AppletHandle(this, applet);
-            d->handles[applet] = handle;
-            connect(handle, SIGNAL(disappearDone(AppletHandle*)),
-                    this, SLOT(handleDisappeared(AppletHandle*)));
-            connect(applet, SIGNAL(geometryChanged()),
-                    handle, SLOT(appletResized()));
+        //kDebug() << "got hoverenterEvent" << isImmutable() << " " << applet->isImmutable();
+        if (!isImmutable() && !applet->isImmutable()) {
+            if (d->handles.contains(applet)) {
+                d->handles[applet]->startFading(AppletHandle::FadeIn);
+            } else {
+                //kDebug() << "generated applet handle";
+                //TODO: there should be a small delay on showing these. they pop up too quickly/easily
+                //      right now
+                AppletHandle *handle = new AppletHandle(this, applet);
+                d->handles[applet] = handle;
+                connect(handle, SIGNAL(disappearDone(AppletHandle*)),
+                        this, SLOT(handleDisappeared(AppletHandle*)));
+                connect(applet, SIGNAL(geometryChanged()),
+                        handle, SLOT(appletResized()));
+            }
         }
         break;
+    case QEvent::GraphicsSceneHoverLeave:
+        //kDebug() << "got hoverLeaveEvent";
+        if (d->handles.contains(applet)) {
+            QGraphicsSceneHoverEvent *he = static_cast<QGraphicsSceneHoverEvent *>(event);
+            if (!d->handles[applet]->boundingRect().contains(d->handles[applet]->mapFromScene(he->scenePos()))) {
+                d->handles[applet]->startFading(AppletHandle::FadeOut);
+            }
+        }
     default:
         break;
     }
@@ -854,6 +926,16 @@ bool Containment::isToolboxToolEnabled(const QString &toolname) const
     return d->createToolbox()->isToolEnabled(toolname);
 }
 
+void Containment::showToolbox()
+{
+    d->createToolbox()->showToolbox();
+}
+
+void Containment::hideToolbox()
+{
+    d->createToolbox()->hideToolbox();
+}
+
 } // Plasma namespace
 
 #include "containment.moc"
