@@ -182,9 +182,17 @@ class PLASMA_EXPORT Containment : public Applet
         void clearApplets();
 
         /**
-         * add existing applet to this containment
+         * add existing applet to this containment at pos
+         * @param pos the containment-relative position
+         * @param dontInit if true, init() will not be called on the applet
          */
-        void addApplet(Applet * applet);
+        void addApplet(Applet *applet, const QPointF &pos = QPointF(-1, -1), bool dontInit = true);
+
+        /**
+         * @return the index to insert an applet at if you want it near the point pos.
+         * @param pos the containment-relative position
+         */
+        virtual int indexAt(const QPointF &pos) const;
 
         /**
          * Sets the physical screen this Containment is associated with.
@@ -247,6 +255,16 @@ class PLASMA_EXPORT Containment : public Applet
          */
         void containmentConstraintsUpdated(Plasma::Constraints constraints);
 
+        /**
+         * Open the Plasma toolbox
+         */
+        void showToolbox();
+
+        /**
+         * Close the Plasma toolbox
+         */
+        void hideToolbox();
+
     Q_SIGNALS:
         /**
          * This signal is emitted when a new applet is created by the containment
@@ -281,6 +299,11 @@ class PLASMA_EXPORT Containment : public Applet
          */
         void showAddWidgets();
 
+        /**
+         * Emitted when there is a change in screens
+         */
+        void screenChanged(int oldScreen, int newScreen, Plasma::Containment *containment);
+
     public Q_SLOTS:
         /**
          * Informs the Corona as to what position it is in. This is informational
