@@ -45,8 +45,9 @@ public:
         format.setAlphaBufferSize(8);
         //dummy size construction
         pbuf = new QGLPixelBuffer(300, 300, format, dummy);
-        if (pbuf->isValid())
+        if (pbuf->isValid()) {
             pbuf->makeCurrent();
+        }
     }
     void updateGlSize(const QSize &size)
     {
@@ -70,6 +71,7 @@ GLApplet::GLApplet(QGraphicsItem *parent,
       d(new Private)
 {
     if (!d->dummy->isValid() ||
+        !QGLPixelBuffer::hasOpenGLPbuffers() ||
         !d->pbuf->isValid()) {
         setFailedToLaunch(true, i18n("This system does not support OpenGL applets."));
     }
@@ -79,6 +81,11 @@ GLApplet::GLApplet(QObject *parent, const QVariantList &args)
     : Applet(parent, args),
       d(new Private)
 {
+    if (!d->dummy->isValid() ||
+        !QGLPixelBuffer::hasOpenGLPbuffers() ||
+        !d->pbuf->isValid()) {
+        setFailedToLaunch(true, i18n("This system does not support OpenGL applets."));
+    }
 }
 
 GLApplet::~GLApplet()
@@ -162,6 +169,7 @@ void GLApplet::paintInterface(QPainter *painter,
                               const QStyleOptionGraphicsItem *option,
                               const QRect &contentsRect)
 {
+    Q_UNUSED(contentsRect)
     Q_ASSERT(d->pbuf);
     if ((!d->dummy->isValid() ||
          !d->pbuf->isValid())) {
@@ -178,7 +186,7 @@ void GLApplet::paintInterface(QPainter *painter,
     glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 
     QMatrix m = painter->worldMatrix();
-    QRect deviceRect = m.mapRect(boundingRect()).toRect();
+    QRect deviceRect = m.mapRect(QRect(QPoint(23, 25), contentSize().toSize()));
     d->updateGlSize(deviceRect.size());
 
     // redirect this widget's painting into the pbuffer
