@@ -30,6 +30,7 @@
 #include <KIO/Job>
 #include <KPluginInfo>
 #include <KStandardDirs>
+#include <KTempDir>
 #include <KTemporaryFile>
 #include <KZip>
 #include <KDebug>
@@ -46,16 +47,24 @@ public:
     Private(const PackageStructure& st, const QString& p)
         : structure(st),
           basePath(p),
-          valid(QFile::exists(basePath))
+          valid(QFile::exists(basePath)),
+          metadata(0)
     {
         if (valid && basePath[basePath.length() - 1] != '/') {
             basePath.append('/');
         }
     }
+    
+    ~Private()
+    {
+        delete metadata;
+    }
 
     PackageStructure structure;
     QString basePath;
     bool valid;
+    PackageMetadata *metadata;
+    
 };
 
 Package::Package(const QString& packageRoot, const QString& package,
@@ -64,8 +73,14 @@ Package::Package(const QString& packageRoot, const QString& package,
 {
 }
 
+Package::Package(const QString &packagePath, const PackageStructure &structure)
+    : d(new Private(structure, packagePath))
+{
+}
+
 Package::~Package()
 {
+    delete d;
 }
 
 bool Package::isValid() const
@@ -74,15 +89,17 @@ bool Package::isValid() const
         return false;
     }
 
-    foreach (const QString& dir, d->structure.requiredDirectories()) {
-        if (QFile::exists(d->basePath + '/' + dir)) {
+    foreach (const char *dir, d->structure.requiredDirectories()) {
+        if (!QFile::exists(d->basePath + "contents/" + d->structure.path(dir))) {
+            kWarning(505) << "Could not find required directory" << dir;
             d->valid = false;
             return false;
         }
     }
 
-    foreach (const QString& file, d->structure.requiredFiles()) {
-        if (QFile::exists(d->basePath + '/' + file)) {
+    foreach (const char *file, d->structure.requiredFiles()) {
+        if (!QFile::exists(d->basePath + "contents/" + d->structure.path(file))) {
+            kWarning(505) << "Could not find required file" << file;
             d->valid = false;
             return false;
         }
@@ -103,8 +120,9 @@ QString Package::filePath(const char* fileType, const QString& filename) const
         return QString();
     }
 
+    path.prepend(d->basePath + "contents/");
+
     if (!filename.isEmpty()) {
-        path.prepend(d->basePath);
         path.append("/").append(filename);
     }
 
@@ -131,7 +149,7 @@ QStringList Package::entryList(const char* fileType) const
         return QStringList();
     }
 
-    QDir dir(d->basePath + path);
+    QDir dir(d->basePath + "contents/" + path);
 
     if (!dir.exists()) {
         return QStringList();
@@ -140,7 +158,16 @@ QStringList Package::entryList(const char* fileType) const
     return dir.entryList(QDir::Files | QDir::Readable);
 }
 
+const PackageMetadata *Package::metadata() const
+{
+    if (!d->metadata) {
+        d->metadata = new PackageMetadata(d->basePath + "metadata.desktop");
+    }
+    return d->metadata;
+}
+
 //TODO: provide a version of this that allows one to ask for certain types of packages, etc?
+//      should we be using KService here instead/as well?
 QStringList Package::knownPackages(const QString& packageRoot) // static
 {
     QDir dir(packageRoot);
@@ -151,8 +178,8 @@ QStringList Package::knownPackages(const QString& packageRoot) // static
 
     QStringList packages;
 
-    foreach (const QString& dir, dir.entryList(QDir::AllDirs | QDir::Readable)) {
-        QString metadata = packageRoot + '/' + dir + "/metadata.desktop";
+    foreach (const QString& sdir, dir.entryList(QDir::AllDirs | QDir::Readable)) {
+        QString metadata = packageRoot + '/' + sdir + "/metadata.desktop";
         if (QFile::exists(metadata)) {
             PackageMetadata m(metadata);
             packages << m.name();
@@ -171,16 +198,19 @@ bool Package::installPackage(const QString& package,
     if (!root.exists()) {
         KStandardDirs::makeDir(packageRoot);
         if (!root.exists()) {
+            kWarning(505) << "Could not create package root directory:" << packageRoot;
             return false;
         }
     }
 
     if (!QFile::exists(package)) {
+        kWarning(505) << "No such file:" << package;
         return false;
     }
 
     KZip archive(package);
     if (!archive.open(QIODevice::ReadOnly)) {
+        kWarning(505) << "Could not open package file:" << package;
         return false;
     }
 
@@ -188,46 +218,43 @@ bool Package::installPackage(const QString& package,
     const KArchiveEntry* metadata = source->entry("metadata.desktop");
 
     if (!metadata) {
+        kWarning(505) << "No metadata file in package" << package;
         return false;
     }
 
     QFile f(package);
-    QString tempdir = packageRoot + '/' + f.fileName();
-    if (QFile::exists(tempdir)) {
-        return false;
-    }
+    KTempDir tempdir;
+    source->copyTo(tempdir.name());
 
-    source->copyTo(tempdir);
-
-    QString metadataPath = tempdir + "/metadata.desktop";
+    QString metadataPath = tempdir.name() + "metadata.desktop";
     if (!QFile::exists(metadataPath)) {
-        KIO::SimpleJob* job = KIO::file_delete(tempdir);
-        job->exec();
+        kWarning(505) << "No metadata file in package" << package;
         return false;
     }
     PackageMetadata meta(metadataPath);
     QString targetName = meta.name();
 
     if (targetName.isEmpty()) {
-        KIO::SimpleJob* job = KIO::file_delete(tempdir);
-        job->exec();
+        kWarning(505) << "Package name not specified";
         return false;
     }
 
     targetName = packageRoot + '/' + targetName;
     if (QFile::exists(targetName)) {
-        KIO::SimpleJob* job = KIO::file_delete(tempdir);
-        job->exec();
+        kWarning(505) << targetName << "already exists";
         return false;
     }
 
-    KIO::FileCopyJob* job = KIO::file_move(tempdir, targetName);
+    KIO::FileCopyJob* job = KIO::file_move(tempdir.name(), targetName, -1,
+        KIO::HideProgressInfo);
 
     if (!job->exec()) {
-        KIO::SimpleJob* job = KIO::file_delete(tempdir);
-        job->exec();
+        kWarning(505) << "Could not move package to destination:" << targetName;
         return false;
     }
+    
+    // no need to remove the temp dir (which has been moved)
+    tempdir.setAutoRemove(false);
 
     // and now we register it as a service =)
     targetName.append("/metadata.desktop");
@@ -244,58 +271,36 @@ bool Package::installPackage(const QString& package,
     }
 
     service.append(pluginInfo.pluginName()).append(".desktop");
-    job = KIO::file_copy(targetName, service);
+    job = KIO::file_copy(targetName, service, -1, KIO::HideProgressInfo);
     return job->exec();
 }
 
-bool Package::createPackage(const PackageMetadata & metadata,
-                            const QString& source,
-                            const QString& destination)
+bool Package::createPackage(const PackageMetadata &metadata,
+                            const QString &source,
+                            const QString &destination,
+                            const QString &icon) // static
 {
     if (!metadata.isComplete()) {
-        kWarning(550) << "Metadata file is not complete" ;
+        kWarning(550) << "Metadata file is not complete";
         return false;
     }
 
+    // write metadata in a temporary file
     KTemporaryFile metadataFile;
-    metadataFile.open();
-    metadata.write(metadataFile.fileName());
-
-    KTemporaryFile releaseNotes;
-    //We just write the content of the QString containing the metadata in an
-    //empty temporary file that we will package with the name metadata.desktop
-    if (releaseNotes.open()) {
-        QTextStream out(&releaseNotes);
-        if (metadata.releaseNotes().isEmpty()) {
-            out << metadata.releaseNotes();
-        } else {
-            out << "NO_RELEASE_NOTES";
-        }
+    if (!metadataFile.open()) {
+        return false;
     }
+    metadata.write(metadataFile.fileName(), icon);
 
-    //OK, we've got the temporary file with the metadata in it.
-    //Now we just need to put everything into a zip archive.
+    // put everything into a zip archive
     KZip creation(destination);
     creation.setCompression(KZip::NoCompression);
-
     if (!creation.open(QIODevice::WriteOnly)) {
         return false;
     }
-
+    
     creation.addLocalFile(metadataFile.fileName(), "metadata.desktop");
-    creation.addLocalFile(releaseNotes.fileName(), "notes.txt");
-
-    if (!metadata.icon().isEmpty()) {
-        //TODO: just one icon?
-        creation.addLocalFile(metadata.icon(), "icon.png");
-    }
-
-    if (!metadata.preview().isEmpty()) {
-        //TODO: just one icon?
-        creation.addLocalFile(metadata.preview(), "preview.png");
-    }
-
-    creation.addLocalDirectory(source, "contents/");
+    creation.addLocalDirectory(source, "contents");
     creation.close();
     return true;
 }
