@@ -21,6 +21,7 @@
 #define PLASMA_DEFS_H
 
 #include <QtGui/QGraphicsItem>
+#include <QtGui/QPainterPath>
 
 #include <plasma/plasma_export.h>
 
@@ -35,10 +36,14 @@ namespace Plasma
  * objects have managed for them and which they may wish to react to,
  * for instance in Applet::constraintsUpdated
  */
-enum Constraint { FormFactorConstraint = 1 /** The FormFactor for an object */,
+enum Constraint { NoConstraint = 0,
+                  FormFactorConstraint = 1 /** The FormFactor for an object */,
                   LocationConstraint = 2 /** The Location of an object */,
                   ScreenConstraint = 4 /** Which screen an object is on */,
-                  AllConstraints = FormFactorConstraint | LocationConstraint | ScreenConstraint
+                  SizeConstraint = 8 /** the size of the applet was changed */,
+                  ImmutableConstraint = 16 /** the immutability (locked) nature of the applet changed  */,
+                  StartupCompletedConstraint = 32 /** application startup has completed */,
+                  AllConstraints = FormFactorConstraint | LocationConstraint | ScreenConstraint | SizeConstraint | ImmutableConstraint
 };
 Q_DECLARE_FLAGS(Constraints, Constraint)
 
@@ -101,6 +106,15 @@ enum Position { LeftPositioned    /**< Positioned left */,
                 CenterPositioned  /**< Positioned in the center */
               };
 
+/**
+ * Flip enumeration
+ */
+enum FlipDirection { NoFlip = 0          /**< Do not flip */,
+                     HorizontalFlip = 1   /**< Flip horizontally */,
+                     VerticalFlip = 2    /**< Flip vertically */
+                   };
+Q_DECLARE_FLAGS(Flip, FlipDirection)
+
 /**
  * Zoom levels that Plasma is aware of...
  **/
@@ -121,6 +135,24 @@ enum ItemTypes { AppletType = QGraphicsItem::UserType + 1,
                  LineEditType = QGraphicsItem::UserType + 2
                };
 
+/**
+ * The ComonentType enumeration refers to the various types of components,
+ * or plugins, supported by plasma.
+ */
+enum ComponentType { AppletComponent = 1 /**< Plasma::Applet based plugins **/,
+                     DataEngineComponent = 2 /**< Plasma::DataEngine based plugins **/,
+                     RunnerComponent = 4 /**< Plasma::AbstractRunner based plugsin **/,
+                     AnimatorComponent = 8 /**< Plasma::Animator based plugins **/,
+                     ContainmentComponent = 16 /**< Plasma::Containment based plugins **/
+                   };
+Q_DECLARE_FLAGS(ComponentTypes, ComponentType)
+
+enum MarginEdge { TopMargin = 0,
+                  BottomMargin,
+                  LeftMargin,
+                  RightMargin
+                };
+
 /**
  * @return the scaling factor (0..1) for a ZoomLevel
  **/
@@ -135,8 +167,14 @@ PLASMA_EXPORT qreal scalingFactor(ZoomLevel level);
  **/
 PLASMA_EXPORT Direction locationToDirection(Location location);
 
+/**
+ * Returns a nicely rounded rectanglular path for painting.
+ */
+PLASMA_EXPORT QPainterPath roundedRectangle(const QRectF& rect, qreal radius);
+
 } // Plasma namespace
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Plasma::Constraints)
+Q_DECLARE_OPERATORS_FOR_FLAGS(Plasma::Flip)
 
 #endif // multiple inclusion guard
