@@ -64,27 +64,28 @@ class Svg::Private
             : renderer(0),
               contentType(Svg::SingleImage)
         {
-            if (QDir::isAbsolutePath(imagePath)) {
-                path = imagePath;
-                themed = false;
-
-                if (!QFile::exists(path)) {
-                    kDebug() << "Plasma::Svg: file '" << path << "' does not exist!";
-                }
-            } else {
-                themePath = imagePath;
-                themed = true;
-            }
+            setImagePath(imagePath);
         }
 
         ~Private()
         {
-            if (renderer.count() == 2) {
-                // this and the cache reference it; and boy is this not thread safe ;)
-                renderers.erase(renderers.find(themePath));
-            }
+            eraseRenderer();
+        }
 
-            renderer = 0;
+        void setImagePath(const QString &imagePath)
+        {
+            themed = !QDir::isAbsolutePath(imagePath);
+            path = themePath = QString();
+
+            if (themed) {
+                themePath = imagePath;
+            } else {
+                path = imagePath;
+
+                if (!QFile::exists(path)) {
+                    kDebug() << "Plasma::Svg: file '" << path << "' does not exist!";
+                }
+            }
         }
 
         void removeFromCache()
@@ -134,10 +135,12 @@ class Svg::Private
             } else {
                 renderer->render(&renderPainter, elementId);
             }
+
             renderPainter.end();
-            bool inserted = QPixmapCache::insert( id, p );
-            if (!inserted)
+
+            if (!QPixmapCache::insert( id, p )) {
                 kDebug() << "pixmap cache is too small for inserting" << id << "of size" << s;
+            }
         }
 
         void createRenderer()
@@ -146,7 +149,7 @@ class Svg::Private
                 return;
             }
 
-            if (themed && path.isNull()) {
+            if (themed && path.isEmpty()) {
                 path = Plasma::Theme::self()->image(themePath);
             }
 
@@ -163,6 +166,16 @@ class Svg::Private
             size = renderer->defaultSize();
         }
 
+        void eraseRenderer()
+        {
+            if (renderer.count() == 2) {
+                // this and the cache reference it; and boy is this not thread safe ;)
+                renderers.erase(renderers.find(themePath));
+            }
+
+            renderer = 0;
+        }
+
         QSize elementSize(const QString& elementId)
         {
             createRenderer();
@@ -182,7 +195,7 @@ class Svg::Private
             QSizeF naturalSize = renderer->defaultSize();
             qreal dx = size.width() / naturalSize.width();
             qreal dy = size.height() / naturalSize.height();
-            
+
             return QRect(elementRect.x() * dx, elementRect.y() * dy,
                          elementRect.width() * dx, elementRect.height() * dy);
         }
@@ -273,6 +286,17 @@ bool Svg::elementExists(const QString& elementId) const
     return d->renderer->elementExists(elementId);
 }
 
+QString Svg::elementAtPoint(const QPoint &point) const
+{
+    d->createRenderer();
+    QSizeF naturalSize = d->renderer->defaultSize();
+    qreal dx = d->size.width() / naturalSize.width();
+    qreal dy = d->size.height() / naturalSize.height();
+    //kDebug() << point << "is really" << QPoint(point.x() *dx, naturalSize.height() - point.y() * dy);
+
+    return QString(); // d->renderer->elementAtPoint(QPoint(point.x() *dx, naturalSize.height() - point.y() * dy));
+}
+
 QMatrix Svg::matrixForElement(const QString& elementId) const
 {
     d->createRenderer();
@@ -300,6 +324,17 @@ Svg::ContentType Svg::contentType()
     return d->contentType;
 }
 
+void Svg::setFile(const QString &svgFilePath)
+{
+   d->setImagePath(svgFilePath);
+   d->eraseRenderer();
+}
+
+QString Svg::file() const
+{
+   return d->themePath;
+}
+
 void Svg::themeChanged()
 {
     d->removeFromCache();
