@@ -1,5 +1,5 @@
 /*
- *   Copyright 2007 by André Duffeck <andre@duffeck.de>
+ *   Copyright 2007 by André Duffeck <duffeck@kde.org>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -42,8 +42,6 @@ class Flash::Private
 
         Private() { }
         ~Private() { }
-        int height;
-        int width;
 
         QString text;
         QColor color;
@@ -70,10 +68,11 @@ Flash::Flash(QGraphicsItem *parent)
     d->defaultDuration = 3000;
     d->type = Private::Text;
     d->color = Qt::black;
-    d->height = 40;
-    d->width = 100 ;
     d->animId = 0;
     d->state = Private::Invisible;
+    setSize(QSizeF(40, 100));
+
+    setCachePaintMode( NoCacheMode );
 }
 
 Flash::~Flash()
@@ -83,31 +82,7 @@ Flash::~Flash()
 
 QRectF Flash::boundingRect() const
 {
-    return QRectF(0,0,d->width,d->height);
-}
-
-int Flash::height() const
-{
-    return d->height;
-}
-
-int Flash::width() const
-{
-    return d->width;
-}
-
-void Flash::setHeight(int h)
-{
-    prepareGeometryChange ();
-    d->height = h;
-    update();
-}
-
-void Flash::setWidth(int w)
-{
-    prepareGeometryChange ();
-    d->width = w;
-    update();
+    return QRectF(0, 0, size().width(), size().height());
 }
 
 void Flash::setDuration( int duration )
@@ -115,19 +90,6 @@ void Flash::setDuration( int duration )
     d->defaultDuration = duration;
 }
 
-QSize Flash::size() const
-{
-    return QSize(d->width,d->height);
-}
-
-void Flash::setSize(const QSize &s)
-{
-    prepareGeometryChange ();
-    d->width = s.width();
-    d->height = s.height();
-    update();
-}
-
 void Flash::setColor( const QColor &color )
 {
     d->color = color;
@@ -140,8 +102,9 @@ void Flash::setFont( const QFont &font )
 
 void Flash::flash( const QString &text, int duration, const QTextOption &option)
 {
+    kDebug() << duration;
     d->type = Private::Text;
-    d->duration = (duration == 0) ? duration : d->defaultDuration;
+    d->duration = (duration == 0) ? d->defaultDuration : duration;
     d->text = text;
     d->textOption = option;
     QTimer::singleShot( 0, this, SLOT(fadeIn()) );
@@ -150,7 +113,7 @@ void Flash::flash( const QString &text, int duration, const QTextOption &option)
 void Flash::flash( const QPixmap &pixmap, int duration, Qt::Alignment align )
 {
     d->type = Private::Pixmap;
-    d->duration = (duration == 0) ? duration : d->defaultDuration;
+    d->duration = (duration == 0) ? d->defaultDuration : duration;
     d->pixmap = pixmap;
     d->alignment = align;
     QTimer::singleShot( 0, this, SLOT(fadeIn()) );
@@ -184,14 +147,14 @@ void Flash::fadeOut()
 
 QPixmap Flash::renderPixmap()
 {
-    QPixmap pm( width(), height() );
+    QPixmap pm( size().toSize() );
     pm.fill(Qt::transparent);
 
     QPainter painter( &pm );
     if( d->type == Private::Text ) {
         painter.setPen( d->color );
         painter.setFont( d->font );
-        painter.drawText( QRect( 0, 0, width(), height() ), d->text, d->textOption);
+        painter.drawText( QRect( QPoint(0, 0), size().toSize() ), d->text, d->textOption);
     } else if( d->type == Private::Pixmap ) {
         QPoint p;
         if( d->alignment & Qt::AlignLeft )
@@ -212,14 +175,15 @@ QPixmap Flash::renderPixmap()
     }
     return pm;
 }
-
 void Flash::paintWidget(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
     Q_UNUSED(option)
     Q_UNUSED(widget)
 
-    if( d->animId ) {
-        painter->drawPixmap(0, 0, Plasma::Phase::self()->animationResult(d->animId));
+    if( d->animId && !Plasma::Phase::self()->animationResult(d->animId).isNull() ) {
+        painter->drawPixmap( 0, 0, Plasma::Phase::self()->animationResult(d->animId) );
+    } else if( d->state == Private::Visible ) {
+        painter->drawPixmap( 0, 0, d->renderedPixmap );
     }
 }
 
