@@ -47,6 +47,7 @@
 #include <KMimeType>
 #include <KDebug>
 #include <KColorScheme>
+#include <KGlobalSettings>
 
 #include <plasma/theme.h>
 
@@ -280,7 +281,7 @@ void Icon::init()
     d->setVerticalMargin(Private::ItemMargin, 0, 0);
 
     d->setActiveMargins();
-    d->currentSize = QSizeF(-1,-1);
+    d->currentSize = QSizeF(-1, -1);
 }
 
 void Icon::addAction(QAction *action)
@@ -341,11 +342,6 @@ void Icon::setNumDisplayLines(int numLines)
     }
 }
 
-QSizeF Icon::sizeHint() const
-{
-    return d->currentSize;
-}
-
 void Icon::setDrawBackground(bool draw)
 {
     if (d->drawBg != draw) {
@@ -412,7 +408,7 @@ void Icon::layoutIcons(const QStyleOptionGraphicsItem *option)
                           d->verticalMargin[Private::TextMargin].bottom;
             //never make a label higher than half the total height
             heightAvail = qMax(heightAvail, d->currentSize.height()/2);
-        }else{
+        } else {
             heightAvail = d->currentSize.height();
         }
 
@@ -421,13 +417,13 @@ void Icon::layoutIcons(const QStyleOptionGraphicsItem *option)
             iconWidth = d->currentSize.width() -
                         d->horizontalMargin[Private::IconMargin].left -
                         d->horizontalMargin[Private::IconMargin].right;
-        }else{
+        } else {
             iconWidth = heightAvail -
                         d->verticalMargin[Private::IconMargin].top -
                         d->verticalMargin[Private::IconMargin].bottom;
         }
     //Horizontal layout
-    }else{
+    } else {
         qreal widthAvail;
         QFontMetricsF fm(font());
 
@@ -445,7 +441,7 @@ void Icon::layoutIcons(const QStyleOptionGraphicsItem *option)
                          textWidth -
                          d->horizontalMargin[Private::TextMargin].left -
                          d->horizontalMargin[Private::TextMargin].right;
-        }else{
+        } else {
             widthAvail = d->currentSize.width();
         }
 
@@ -454,7 +450,7 @@ void Icon::layoutIcons(const QStyleOptionGraphicsItem *option)
             iconWidth = d->currentSize.height() -
                         d->verticalMargin[Private::IconMargin].top -
                         d->verticalMargin[Private::IconMargin].bottom;
-        }else{
+        } else {
             iconWidth = widthAvail -
                         d->horizontalMargin[Private::IconMargin].left -
                         d->horizontalMargin[Private::IconMargin].right;
@@ -899,6 +895,8 @@ void Icon::drawActionButtonBase(QPainter* painter, const QSize &size, int elemen
 void Icon::setText(const QString& text)
 {
     d->text = text;
+    // cause a relayout
+    d->currentSize = QSizeF(-1, -1);
 }
 
 QString Icon::text() const
@@ -909,6 +907,8 @@ QString Icon::text() const
 void Icon::setInfoText(const QString& text)
 {
     d->infoText = text;
+    // cause a relayout
+    d->currentSize = QSizeF(-1, -1);
 }
 
 QString Icon::infoText() const
@@ -1024,6 +1024,14 @@ void Icon::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
     update();
 }
 
+void Icon::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
+{
+    Q_UNUSED(event)
+    if (!KGlobalSettings::singleClick()) {
+        emit doubleClicked();
+    }
+}
+
 void Icon::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
 {
     foreach (IconAction *action, d->cornerActions) {
