@@ -92,20 +92,29 @@ class Icon::Private
 public:
     enum MarginType { ItemMargin = 0, TextMargin, IconMargin, NMargins };
 
+    enum IconState
+    {
+        NoState = 0,
+        HoverState = 1,
+        PressedState = 2,
+        ManualPressedState = 4,
+        MovedState = 8
+    };
+    Q_DECLARE_FLAGS(IconStates, IconState)
+
 public:
     Private();
     ~Private();
 
-    void drawBackground(QPainter *painter);
-    void drawForeground(QPainter *painter);
+    void drawBackground(QPainter *painter, IconState state);
     void drawText(QPainter *painter);
     void drawTextItems(QPainter *painter, const QStyleOptionGraphicsItem *option,
                         const QTextLayout &labelLayout, const QTextLayout &infoLayout) const;
 
-    QPixmap decoration(const QStyleOptionGraphicsItem *option) const;
+    QPixmap decoration(const QStyleOptionGraphicsItem *option, bool useHoverEffect);
     QPointF iconPosition(const QStyleOptionGraphicsItem *option, const QPixmap &pixmap) const;
 
-    QSizeF displaySizeHint(const QStyleOptionGraphicsItem *option) const;
+    QSizeF displaySizeHint(const QStyleOptionGraphicsItem *option, const qreal width) const;
 
     QBrush foregroundBrush(const QStyleOptionGraphicsItem *option) const;
     QBrush backgroundBrush(const QStyleOptionGraphicsItem *option) const;
@@ -122,6 +131,8 @@ public:
 
     inline void setLayoutOptions(QTextLayout &layout, const QStyleOptionGraphicsItem *options) const;
 
+    inline Qt::LayoutDirection iconDirection(const QStyleOptionGraphicsItem *option) const;
+
 
     // Margin functions
     inline void setActiveMargins();
@@ -135,19 +146,10 @@ public:
     inline QSizeF subtractMargin(const QSizeF &size, MarginType type) const;
 
 
-    void checkSvgElements();
-
     enum {
-        NoSvg = 0,
-        SvgBackground = 1,
-        SvgBackgroundHover = 2,
-        SvgBackgroundPressed = 4,
-        SvgForeground = 8,
-        SvgForegroundHover = 16,
-        SvgForegroundPressed = 32,
-        SvgMinibutton = 64,
-        SvgMinibuttonHover = 128,
-        SvgMinibuttonPressed = 256
+        Minibutton = 64,
+        MinibuttonHover = 128,
+        MinibuttonPressed = 256
     };
 
     enum ActionPosition {
@@ -158,31 +160,33 @@ public:
         LastIconPosition
     };
 
-    enum ButtonState
-    {
-        NoState,
-        HoverState,
-        PressedState
-    };
-
     QString text;
     QString infoText;
-    Svg svg;
-    int svgElements;
-    QSizeF size;
+    Svg *iconSvg;
+    QString iconSvgElement;
+    QPixmap iconSvgPixmap;
+    QColor textColor;
+    QColor shadowColor;
     QSizeF iconSize;
     QIcon icon;
-    ButtonState state;
+    IconStates states;
     Qt::Orientation orientation;
-    bool calculateSizeRequested;
+    int numDisplayLines;
+    bool invertLayout;
+    bool drawBg;
+    QSizeF currentSize;
 
     QList<IconAction*> cornerActions;
 
     Margin verticalMargin[NMargins];
     Margin horizontalMargin[NMargins];
     Margin *activeMargins;
+
+    static const int maxDisplayLines = 5;
 };
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(Icon::Private::IconStates)
+
 // Inline methods
 void Icon::Private::setLayoutOptions(QTextLayout &layout, const QStyleOptionGraphicsItem *option) const
 {
@@ -195,6 +199,23 @@ void Icon::Private::setLayoutOptions(QTextLayout &layout, const QStyleOptionGrap
     layout.setTextOption(textoption);
 }
 
+Qt::LayoutDirection Icon::Private::iconDirection(const QStyleOptionGraphicsItem *option) const
+{
+    Qt::LayoutDirection direction;
+
+    if (invertLayout && orientation == Qt::Horizontal) {
+        if (option->direction == Qt::LeftToRight) {
+            direction = Qt::RightToLeft;
+        }else{
+            direction = Qt::LeftToRight;
+        }
+    }else{
+        direction = option->direction;
+    }
+
+    return direction;
+}
+
 void Icon::Private::setActiveMargins()
 {
     activeMargins = (orientation == Qt::Horizontal ?
