@@ -54,7 +54,6 @@ Clock::Clock(QObject *parent, const QVariantList &args)
       m_showYear(false),
       m_showDay(false),
       m_showTimezone(false),
-      m_twentyFour(false),
       m_dialog(0),
       m_calendar(0),
       m_layout(0)
@@ -78,7 +77,6 @@ void Clock::init()
     m_showYear = cg.readEntry("showYear", false);
 
     m_showDay = cg.readEntry("showDay", true);
-    m_twentyFour = cg.readEntry("twentyFour", true);
 
     m_plainClockFont = cg.readEntry("plainClockFont", m_plainClockFont);
     m_plainClockColor = cg.readEntry("plainClockColor", m_plainClockColor);
@@ -98,15 +96,6 @@ Qt::Orientations Clock::expandingDirections() const
     return Qt::Vertical;
 }
 
-
-void Clock::constraintsUpdated(Plasma::Constraints)
-{
-    // I'm not sure why this is needed, since we don't actually change
-    // any geometry in this method, but it screws up the system tray
-    // without it.
-    updateGeometry();
-}
-
 void Clock::dataUpdated(const QString& source, const Plasma::DataEngine::Data &data)
 {
     Q_UNUSED(source);
@@ -173,7 +162,6 @@ void Clock::showConfigurationInterface()
     ui.showDate->setChecked(m_showDate);
     ui.showYear->setChecked(m_showYear);
     ui.showDay->setChecked(m_showDay);
-    ui.twentyFour->setChecked(m_twentyFour);
     ui.showTimezone->setChecked(m_showTimezone);
     ui.plainClockFontBold->setChecked(m_plainClockFontBold);
     ui.plainClockFontItalic->setChecked(m_plainClockFontItalic);
@@ -224,8 +212,6 @@ void Clock::configAccepted()
     cg.writeEntry("showYear", m_showYear);
     m_showDay = ui.showDay->checkState() == Qt::Checked;
     cg.writeEntry("showDay", m_showDay);
-    m_twentyFour = ui.twentyFour->checkState() == Qt::Checked;
-    cg.writeEntry("twentyFour", m_twentyFour);
 
     if (m_showTimezone != (ui.showTimezone->checkState() == Qt::Checked)) {
         m_showTimezone = ui.showTimezone->checkState() == Qt::Checked;
@@ -335,19 +321,7 @@ void Clock::paintInterface(QPainter *p, const QStyleOptionGraphicsItem *option,
                                 (contentsRect.width()),
                                 (contentsRect.height()));
         }
-        QString timeString;
-        // FIXME: 12/24-hr distinction makes no sense in many languages.
-        // Instead, possibly do this: use KLocale's formatTime() by default,
-        // with a checkbox "Custom time format" which would allow editing
-        // the KLocale time format string.
-        if (m_twentyFour) {
-            // i18n: See http://doc.trolltech.com/4.3/qtime.html#toString
-            // for possible format expressions.
-            timeString = m_time.toString(i18nc("@item 24-hr clock format", "hh:mm"));
-        } else {
-            timeString = m_time.toString(i18nc("@item 12-hr clock format", "h:mm AP"));
-        }
-
+        QString timeString = KGlobal::locale()->formatTime(m_time);
         m_plainClockFont.setBold(m_plainClockFontBold);
         m_plainClockFont.setItalic(m_plainClockFontItalic);
  
