@@ -42,6 +42,8 @@
 #include <plasma/svg.h>
 #include <plasma/theme.h>
 
+const int WINDOW_UPDATE_DELAY = 50;
+
 Pager::Pager(QObject *parent, const QVariantList &args)
     : Plasma::Applet(parent, args),
       m_dialog(0),
@@ -86,7 +88,7 @@ void Pager::init()
     connect(KWindowSystem::self(), SIGNAL(activeWindowChanged(WId)), this, SLOT(activeWindowChanged(WId)));
     connect(KWindowSystem::self(), SIGNAL(numberOfDesktopsChanged(int)), this, SLOT(numberOfDesktopsChanged(int)));
     connect(KWindowSystem::self(), SIGNAL(stackingOrderChanged()), this, SLOT(stackingOrderChanged()));
-    connect(KWindowSystem::self(), SIGNAL(windowChanged(WId)), this, SLOT(windowChanged(WId)));
+    connect(KWindowSystem::self(), SIGNAL(windowChanged(WId,unsigned int)), this, SLOT(windowChanged(WId,unsigned int)));
     connect(KWindowSystem::self(), SIGNAL(showingDesktopChanged(bool)), this, SLOT(showingDesktopChanged(bool)));
 
     m_desktopLayoutOwner = new KSelectionOwner( QString( "_NET_DESKTOP_LAYOUT_S%1" )
@@ -223,6 +225,8 @@ void Pager::recalculateWindowRects()
                 continue;
             }
             QRect windowRect = info.frameGeometry();
+            if( KWindowSystem::mapViewport())
+                windowRect = fixViewportPosition( windowRect );
             windowRect = QRectF(windowRect.x() * m_scaleFactor,
                                 windowRect.y() * m_scaleFactor,
                                 windowRect.width() * m_scaleFactor, 
@@ -253,6 +257,7 @@ void Pager::configAccepted()
             m_rows = m_desktopCount;
         }
         globalcg.writeEntry("rows", m_rows);
+        emit configNeedsSaving();
         // force an update of the column count in recalculateGeometry
         m_columns = 0;
         m_size = QSizeF(-1, -1);
@@ -265,25 +270,37 @@ void Pager::configAccepted()
 void Pager::currentDesktopChanged(int desktop)
 {
     m_currentDesktop = desktop;
-    m_timer->start();
+
+    if (!m_timer->isActive()) {
+        m_timer->start(WINDOW_UPDATE_DELAY);
+    }
 }
 
 void Pager::windowAdded(WId id)
 {
     Q_UNUSED(id)
-    m_timer->start();
+
+    if (!m_timer->isActive()) {
+        m_timer->start(WINDOW_UPDATE_DELAY);
+    }
 }
 
 void Pager::windowRemoved(WId id)
 {
     Q_UNUSED(id)
-    m_timer->start();
+
+    if (!m_timer->isActive()) {
+        m_timer->start(WINDOW_UPDATE_DELAY);
+    }
 }
 
 void Pager::activeWindowChanged(WId id)
 {
     Q_UNUSED(id)
-    m_timer->start();
+
+    if (!m_timer->isActive()) {
+        m_timer->start(WINDOW_UPDATE_DELAY);
+    }
 }
 
 void Pager::numberOfDesktopsChanged(int num)
@@ -294,27 +311,38 @@ void Pager::numberOfDesktopsChanged(int num)
     }
     m_rects.clear();
     recalculateGeometry();
-    m_timer->start();
+
+    if (!m_timer->isActive()) {
+        m_timer->start(WINDOW_UPDATE_DELAY);
+    }
 }
 
 void Pager::stackingOrderChanged()
 {
-    m_timer->start();
+    if (!m_timer->isActive()) {
+        m_timer->start(WINDOW_UPDATE_DELAY);
+    }
 }
 
-void Pager::windowChanged(WId id)
+void Pager::windowChanged(WId id, unsigned int properties)
 {
     Q_UNUSED(id)
-    m_timer->start();
+
+    if (properties & NET::WMGeometry) {
+        if (!m_timer->isActive()) {
+            m_timer->start(WINDOW_UPDATE_DELAY);
+        }
+    }
 }
 
 void Pager::showingDesktopChanged(bool showing)
 {
     Q_UNUSED(showing)
-    m_timer->start();
+    if (!m_timer->isActive()) {
+        m_timer->start(WINDOW_UPDATE_DELAY);
+    }
 }
 
-
 void Pager::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
     if (event->buttons() != Qt::RightButton)
@@ -326,6 +354,8 @@ void Pager::mousePressEvent(QGraphicsSceneMouseEvent *event)
                 if (m_dragOriginal.isEmpty()) {
                     m_dragOriginal = m_rects[i].toRect();
                 }
+                
+                update();
 
                 return;
             }
@@ -402,18 +432,29 @@ void Pager::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
         if (m_dragHighlightedDesktop != -1) {
             QPointF dest = m_dragCurrentPos - m_rects[m_dragHighlightedDesktop].topLeft() - m_dragOriginalPos + m_dragOriginal.topLeft();
             dest = QPointF(dest.x()/m_scaleFactor, dest.y()/m_scaleFactor);
-            KWindowSystem::setOnDesktop(m_dragId, m_dragHighlightedDesktop+1);
-            XMoveWindow(QX11Info::display(), m_dragId, dest.toPoint().x(), dest.toPoint().y());
+            if( !KWindowSystem::mapViewport()) {
+                KWindowSystem::setOnDesktop(m_dragId, m_dragHighlightedDesktop+1);
+                // use _NET_MOVERESIZE_WINDOW rather than plain move, so that the WM knows this is a pager request
+                NETRootInfo i( QX11Info::display(), 0 );
+                int flags = ( 0x20 << 12 ) | ( 0x03 << 8 ) | 1; // from tool, x/y, northwest gravity
+                i.moveResizeWindowRequest( m_dragId, flags, dest.toPoint().x(), dest.toPoint().y(), 0, 0 );
+            } else {
+                // setOnDesktop() with viewports is also moving a window, and since it takes a moment
+                // for the WM to do the move, there's a race condition with figuring out how much to move,
+                // so do it only as one move
+                dest += KWindowSystem::desktopToViewport( m_dragHighlightedDesktop+1, false );
+                QPoint d = KWindowSystem::constrainViewportRelativePosition( dest.toPoint());
+                NETRootInfo i( QX11Info::display(), 0 );
+                int flags = ( 0x20 << 12 ) | ( 0x03 << 8 ) | 1; // from tool, x/y, northwest gravity
+                i.moveResizeWindowRequest( m_dragId, flags, d.x(), d.y(), 0, 0 );
+            }
         }
         m_timer->start();
     } else {
-        for (int i = 0; i < m_desktopCount; i++) {
-            if (m_rects[i].contains(event->pos().toPoint()) && m_currentDesktop != i+1) {
-                KWindowSystem::setCurrentDesktop(i+1);
-                m_currentDesktop = i+1;
-                update();
-                break;
-            }
+        // only change the desktop if the user presses and releases the mouse on the same desktop
+        if (m_dragStartDesktop != -1 && m_rects[m_dragStartDesktop].contains(event->pos().toPoint()) && m_currentDesktop != m_dragStartDesktop + 1) {
+            KWindowSystem::setCurrentDesktop(m_dragStartDesktop + 1);
+            m_currentDesktop = m_dragStartDesktop + 1;
         }
     }
 
@@ -423,6 +464,7 @@ void Pager::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
     m_dragStartDesktop = -1;
     m_dragOriginalPos = m_dragCurrentPos = QPointF();
 
+    update();
     Applet::mouseReleaseEvent(event);
 }
 
@@ -454,6 +496,21 @@ void Pager::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
         m_hoverRect = QRectF();
         update();
     }
+    
+    // The applet doesn't always get mouseReleaseEvents, for example when starting a drag
+    // on the panel and releasing the mouse on the desktop or another window. This can cause
+    // weird bugs because the pager still thinks a drag is going on.
+    // The only reliable event I found is the hoverLeaveEvent, so we just stop the drag
+    // on this event.
+    if (m_dragId || m_dragStartDesktop != -1) {
+        m_dragId = 0;
+        m_dragOriginal = QRect();
+        m_dragHighlightedDesktop = -1;
+        m_dragStartDesktop = -1;
+        m_dragOriginalPos = m_dragCurrentPos = QPointF();
+        update();
+    }
+    
     Applet::hoverLeaveEvent(event);
 }
 
@@ -462,9 +519,35 @@ void Pager::paintInterface(QPainter *painter, const QStyleOptionGraphicsItem *op
     Q_UNUSED( option );
     Q_UNUSED( contentsRect );
 
-    // paint desktop background
-    QBrush hoverBrush(QColor(255,255,255,50));
+    KColorScheme plasmaColorTheme = KColorScheme(QPalette::Active, KColorScheme::View, Plasma::Theme::self()->colors());
+    painter->setFont(KGlobalSettings::taskbarFont());
+
+    // Desktop background
+    QColor textColor = Plasma::Theme::self()->textColor();
+    textColor.setAlpha(64);
+    QBrush hoverBrush(textColor);
     QBrush defaultBrush(Qt::NoBrush);
+
+    // Inactive windows
+    QColor drawingColor = plasmaColorTheme.foreground(KColorScheme::InactiveText).color();
+    drawingColor.setAlpha(192);
+    QBrush windowBrush(drawingColor);
+
+    // Inactive window borders
+    drawingColor = plasmaColorTheme.foreground(KColorScheme::NeutralText).color();
+    drawingColor.setAlpha(238);
+    QPen windowPen(drawingColor);
+
+    // Active window borders
+    QPen activeWindowPen(Plasma::Theme::self()->textColor());
+
+    // Active windows
+    drawingColor.setAlpha(238);
+    QBrush activeWindowBrush(drawingColor);
+
+    //kDebug() << "InActive (brush, pen): " << windowBrush.color() << windowPen.color();
+    //kDebug() << "Active (brush, pen)  : " << activeWindowBrush.color() << activeWindowPen.color();
+
     painter->setPen(Qt::NoPen);
     for (int i = 0; i < m_desktopCount; i++) {
         if (m_rects[i] == m_hoverRect) {
@@ -475,18 +558,17 @@ void Pager::paintInterface(QPainter *painter, const QStyleOptionGraphicsItem *op
         painter->drawRect(m_rects[i]);
     }
 
-    // draw window thumbnails
-    QPen windowPen(Qt::white);
-    QBrush windowBrush(QColor(200,200,200));
-    QBrush activeWindowBrush(QColor(100,100,255));
     painter->setPen(windowPen);
+
     for (int i = 0; i < m_windowRects.count(); i++) {
         for (int j = 0; j < m_windowRects[i].count(); j++) {
             QRect rect = m_windowRects[i][j].second;
             if (m_activeWindows.contains(rect)) {
                 painter->setBrush(activeWindowBrush);
+                painter->setPen(activeWindowPen);
             } else {
                 painter->setBrush(windowBrush);
+                painter->setPen(windowPen);
             }
             if (m_dragId == m_windowRects[i][j].first) {
                 rect.translate((m_dragCurrentPos - m_dragOriginalPos).toPoint());
@@ -498,21 +580,23 @@ void Pager::paintInterface(QPainter *painter, const QStyleOptionGraphicsItem *op
         }
     }
 
-    // draw desktop foreground
+    // draw desktop frame and number
     painter->setClipRect(option->exposedRect);
-    QPen activePen(Qt::white);
-    QPen defaultPen(QColor(120,120,120));
+    QPen activePen(Plasma::Theme::self()->textColor());
+    QPen drawingPen = QPen();
     painter->setBrush(Qt::NoBrush);
+
     for( int i = 0; i < m_desktopCount; i++) {
         if (i + 1 == m_currentDesktop || i == m_dragHighlightedDesktop) {
-            painter->setPen(activePen);
+            drawingPen = QPen(Plasma::Theme::self()->textColor());
         } else {
-            painter->setPen(defaultPen);
+            drawingPen = QPen(plasmaColorTheme.foreground(KColorScheme::InactiveText).color());
         }
-
+        painter->setPen(drawingPen);
         painter->drawRect(m_rects[i]);
 
         if (m_showDesktopNumber) {
+            painter->setPen(activePen);
             painter->drawText(m_rects[i], Qt::AlignCenter, QString::number(i+1));
         }
     }
@@ -524,4 +608,18 @@ void Pager::lostDesktopLayoutOwner()
     m_desktopLayoutOwner = NULL;
 }
 
+// KWindowSystem does not translate position when mapping viewports
+// to virtual desktops (it'd probably break more things than fix),
+// so the offscreen coordinates need to be fixed
+QRect Pager::fixViewportPosition( const QRect& r )
+{
+    int x = r.center().x() % qApp->desktop()->width();
+    int y = r.center().y() % qApp->desktop()->height();
+    if( x < 0 )
+        x = x + qApp->desktop()->width();
+    if( y < 0 )
+        y = y + qApp->desktop()->height();
+    return QRect( x - r.width() / 2, y - r.height() / 2, r.width(), r.height());
+}
+
 #include "pager.moc"
