@@ -43,7 +43,8 @@ QSizeF SystemTray::contentSizeHint() const
     if (!(m_systemTrayWidget && v)) {
         return QSizeF();
     }
-    QRect widgetRect(QPoint(0, 0), m_systemTrayWidget->minimumSizeHint());
+    QRect widgetRect(QPoint(0, 0), m_systemTrayWidget->minimumSizeHint() +
+            QSize(SystemTrayWidget::MARGIN * 2, SystemTrayWidget::MARGIN * 2));
     return mapFromView(v, widgetRect).size();
 }
 
@@ -90,13 +91,10 @@ void SystemTray::updateWidgetGeometry()
     }
 
     if (!m_systemTrayWidget || m_systemTrayWidget->parentWidget() != parentView) {
-        if (m_systemTrayWidget) {
-            m_systemTrayWidget->setParent(parentView);
-        } else {
-            m_systemTrayWidget = new SystemTrayWidget(parentView);
-            connect(m_systemTrayWidget, SIGNAL(sizeShouldChange()),
-                    this, SLOT(updateSize()));
-        }
+        delete m_systemTrayWidget;
+        m_systemTrayWidget = new SystemTrayWidget(parentView);
+        connect(m_systemTrayWidget, SIGNAL(sizeShouldChange()),
+                this, SLOT(updateSize()));
         updateWidgetOrientation();
         m_systemTrayWidget->setVisible(true);
     }
