@@ -29,6 +29,7 @@
 #include <KColorButton>
 #include <KDebug>
 #include <KDirSelectDialog>
+#include <KDirWatch>
 #include <KFileDialog>
 #include <KGlobalSettings>
 #include <KLocalizedString>
@@ -117,11 +118,13 @@ public:
     void reload(const QStringList &selected);
     void addBackground(const QString &path);
     int indexOf(const QString &path) const;
+    void removeBackground(const QString &path);
     virtual bool contains(const QString &bg) const;
 private:
     QObject *m_listener;
     QList<Background*> m_packages;
     float m_ratio;
+    KDirWatch m_dirwatch;
 };
 
 class BackgroundDelegate : public QAbstractItemDelegate
@@ -150,6 +153,17 @@ BackgroundListModel::BackgroundListModel(float ratio, QObject *listener)
 : m_listener(listener)
 , m_ratio(ratio)
 {
+    connect(&m_dirwatch, SIGNAL(deleted(QString)), listener, SLOT(removeBackground(QString)));
+}
+
+void BackgroundListModel::removeBackground(const QString &path)
+{
+    int index;
+    while ((index = indexOf(path)) != -1) {
+        beginRemoveRows(QModelIndex(), index, index);
+        m_packages.removeAt(index);
+        endRemoveRows();
+    }
 }
 
 void BackgroundListModel::reload() 
@@ -162,7 +176,7 @@ void BackgroundListModel::reload(const QStringList& selected)
     QStringList dirs = KGlobal::dirs()->findDirs("wallpaper", "");
     QList<Background *> tmp;
     foreach (QString file, selected) {
-        if (!contains(file)) {
+        if (!contains(file) && QFile::exists(file)) {
             tmp << new BackgroundFile(file, m_ratio);
         }
     }
@@ -170,6 +184,13 @@ void BackgroundListModel::reload(const QStringList& selected)
         tmp += findAllBackgrounds(this, dir, m_ratio);
     }
     
+    // add new files to dirwatch
+    foreach (Background *b, tmp) {
+        if (!m_dirwatch.contains(b->path())) {
+            m_dirwatch.addFile(b->path());
+        }
+    }
+    
     if (!tmp.isEmpty()) {
         beginInsertRows(QModelIndex(), 0, tmp.size() - 1);
         m_packages = tmp + m_packages;
@@ -179,6 +200,9 @@ void BackgroundListModel::reload(const QStringList& selected)
 
 void BackgroundListModel::addBackground(const QString& path) {
     if (!contains(path)) {
+        if (!m_dirwatch.contains(path)) {
+            m_dirwatch.addFile(path);
+        }
         beginInsertRows(QModelIndex(), 0, 0);
         m_packages.prepend(new BackgroundFile(path, m_ratio));
         endInsertRows();
@@ -188,7 +212,7 @@ void BackgroundListModel::addBackground(const QString& path) {
 int BackgroundListModel::indexOf(const QString &path) const
 {
     for (int i = 0; i < m_packages.size(); i++) {
-        if (m_packages[i]->path() == path) {
+        if (path.startsWith(m_packages[i]->path())) {
             return i;
         }
     }
@@ -301,8 +325,11 @@ void BackgroundDelegate::paint(QPainter *painter,
                    option.rect.width() - x - MARGIN * 2,
                    maxheight);
     QString text = title.replace("_", " ");
+    QString authorCaption;
     if (!author.isEmpty()) {
-        text += "\n" + author;
+        authorCaption = i18nc("Caption to wallpaper preview, %1 author name",
+                              "by %1", author);
+        text += "\n" + authorCaption;
     }
     QRect boundingRect = painter->boundingRect(
         textRect, Qt::AlignVCenter | Qt::TextWordWrap, text);
@@ -311,7 +338,7 @@ void BackgroundDelegate::paint(QPainter *painter,
         QRect titleRect = painter->boundingRect(boundingRect, Qt::TextWordWrap, title);
         QRect authorRect(titleRect.bottomLeft(), textRect.size());
         painter->setFont(KGlobalSettings::smallestReadableFont());
-        painter->drawText(authorRect, Qt::TextWordWrap, "by " + author);
+        painter->drawText(authorRect, Qt::TextWordWrap, authorCaption);
     }
 
     painter->restore();
@@ -337,59 +364,24 @@ BackgroundDialog::BackgroundDialog(const QSize &res,
     setCaption(i18n("Configure Desktop"));
     setButtons(Ok | Cancel | Apply);
 
-    QWidget *main = new QWidget(this);
-    QVBoxLayout *layout = new QVBoxLayout;
-    QHBoxLayout *backgroundLayout = new QHBoxLayout;
-    QVBoxLayout *leftLayout = new QVBoxLayout;
-    QVBoxLayout *rightLayout = new QVBoxLayout;
-    QHBoxLayout *iconLayout = new QHBoxLayout;
-    
+    QWidget * main = new QWidget(this);
+    setupUi(main);
+
     // static or slideshow?
-    m_mode = new QComboBox(main);
-    m_mode->addItem(i18n("Wallpaper Image"));
-    m_mode->addItem(i18n("Slideshow"));
-    leftLayout->addWidget(m_mode);
     connect(m_mode, SIGNAL(currentIndexChanged(int)),
             this, SLOT(changeBackgroundMode(int)));
-    
-    // stacked widget
-    QStackedWidget *stack = new QStackedWidget(main);
-    leftLayout->addWidget(stack);
-    connect(m_mode, SIGNAL(currentIndexChanged(int)),
-            stack, SLOT(setCurrentIndex(int)));
-    
+
     // static picture
-    QWidget *staticPictureWidget = new QWidget(stack);
-    stack->addWidget(staticPictureWidget);
-    QGridLayout *staticPictureLayout = new QGridLayout;
-    //staticPictureLayout->setColumnStretch(2, 10);
-    staticPictureWidget->setLayout(staticPictureLayout);
-    
-    // combo with backgrounds
-    QLabel *pictureLabel = new QLabel("&Picture:", staticPictureWidget);
-    QHBoxLayout *pictureLayout = new QHBoxLayout;    
-    m_view = new QComboBox(main);
     m_model = new BackgroundListModel(m_ratio, this);
     m_view->setModel(m_model);
     m_view->setItemDelegate(new BackgroundDelegate(m_view->view(), m_ratio, this));
     connect(m_view, SIGNAL(currentIndexChanged(int)),
             this, SLOT(update()));
-    pictureLabel->setBuddy(m_view);
-    QToolButton *pictureUrlButton = new QToolButton(this);
-    pictureUrlButton->setIcon(KIcon("document-open"));
-    pictureUrlButton->setToolTip(i18n("Browse"));
-    connect(pictureUrlButton, SIGNAL(clicked()), this, SLOT(browse()));
-    
-    pictureLayout->addWidget(m_view);
-    pictureLayout->addWidget(pictureUrlButton);
-    
-    staticPictureLayout->addWidget(pictureLabel, 0, 0, Qt::AlignRight);
-    staticPictureLayout->addLayout(pictureLayout, 0, 1, 1, 2);
+    m_pictureUrlButton->setIcon(KIcon("document-open"));
+    connect(m_pictureUrlButton, SIGNAL(clicked()), this, SLOT(showFileDialog()));
 
     // resize method
-    QLabel *resizeMethodLabel = new QLabel(i18n("P&ositioning:"), staticPictureWidget);
-    m_resizeMethod = new QComboBox(main);
-    m_resizeMethod->addItem(i18n("Scale and crop"),
+    m_resizeMethod->addItem(i18n("Scale & Crop"),
                             Background::ScaleCrop);
     m_resizeMethod->addItem(i18n("Scaled"), 
                             Background::Scale);
@@ -397,86 +389,25 @@ BackgroundDialog::BackgroundDialog(const QSize &res,
                             Background::Center);
     m_resizeMethod->addItem(i18n("Tiled"),
                             Background::Tiled);
-    m_resizeMethod->addItem(i18n("Center tiled"),
+    m_resizeMethod->addItem(i18n("Center Tiled"),
                             Background::CenterTiled);
     connect(m_resizeMethod, SIGNAL(currentIndexChanged(int)),
             this, SLOT(update()));
-    resizeMethodLabel->setBuddy(m_resizeMethod);
-    staticPictureLayout->addWidget(resizeMethodLabel, 1, 0, Qt::AlignRight);
-    staticPictureLayout->addWidget(m_resizeMethod, 1, 1);
 
     // color
-    QLabel *colorLabel = new QLabel(i18n("&Color:"), staticPictureWidget);
-    m_color = new KColorButton(this);
     m_color->setColor(palette().color(QPalette::Window));
     connect(m_color, SIGNAL(changed(QColor)), main, SLOT(update()));
-    colorLabel->setBuddy(m_color);
-    staticPictureLayout->addWidget(colorLabel, 2, 0, Qt::AlignRight);
-    staticPictureLayout->addWidget(m_color, 2, 1);
-
-    m_authorLabel = new QLabel(staticPictureWidget);
-    m_emailLabel = new QLabel(staticPictureWidget);
-    m_licenseLabel = new QLabel(staticPictureWidget);
-
-    m_authorLabel->setText("<qt><b> "+i18n("Author:")+" </b></qt>");
-    m_emailLabel->setText("<qt><b> "+i18n("E-Mail:")+" </b></qt>");
-    m_licenseLabel->setText("<qt><b> "+i18n("License:")+" </b></qt>");
-
-    m_authorLine = new QLabel(staticPictureWidget);
-    m_emailLine = new QLabel(staticPictureWidget);
-    m_licenseLine = new QLabel(staticPictureWidget);
-
-    staticPictureLayout->addWidget(m_authorLabel, 3, 0, Qt::AlignRight);
-    staticPictureLayout->addWidget(m_authorLine, 3, 1);
-    staticPictureLayout->addWidget(m_emailLabel, 4, 0, Qt::AlignRight);
-    staticPictureLayout->addWidget(m_emailLine, 4, 1);
-    staticPictureLayout->addWidget(m_licenseLabel, 5, 0, Qt::AlignRight);
-    staticPictureLayout->addWidget(m_licenseLine, 5, 1);
-    //staticPictureLayout->setRowStretch(7, 10);
 
     // slideshow
-    QWidget *slideshowWidget = new QWidget(stack);
-    stack->addWidget(slideshowWidget);
-    QVBoxLayout *slideshowLayout = new QVBoxLayout;
-    slideshowWidget->setLayout(slideshowLayout);
-        
-    QHBoxLayout *dirlistLayout = new QHBoxLayout;
-    m_dirlist = new QListWidget(slideshowWidget);
-    connect(m_dirlist, SIGNAL(currentRowChanged(int)), this, SLOT(updateSlideshow()));
-    QVBoxLayout *dirlistButtons = new QVBoxLayout;
-    m_addDir = new QPushButton(
-        KIcon("list-add"),
-        i18n("&Add directory..."),
-        slideshowWidget);
+    m_addDir->setIcon(KIcon("list-add"));
     connect(m_addDir, SIGNAL(clicked()), this, SLOT(slotAddDir()));
-    m_removeDir = new QPushButton(
-        KIcon("list-remove"),
-        i18n("&Remove directory"),
-        slideshowWidget);
+    m_removeDir->setIcon(KIcon("list-remove"));
     connect(m_removeDir, SIGNAL(clicked()), this, SLOT(slotRemoveDir()));
-    
-    QHBoxLayout *slideshowDelayLayout = new QHBoxLayout;
-    QLabel *slideshowDelayLabel = new QLabel(
-        i18n("&Change images every:"), 
-        slideshowWidget);
-    m_slideshowDelay = new QTimeEdit(slideshowWidget);
-    m_slideshowDelay->setDisplayFormat("hh:mm:ss");
+    connect(m_dirlist, SIGNAL(currentRowChanged(int)), this, SLOT(updateSlideshow()));
+
     m_slideshowDelay->setMinimumTime(QTime(0, 0, 30));
-    slideshowDelayLabel->setBuddy(m_slideshowDelay);
-    slideshowDelayLayout->addWidget(slideshowDelayLabel);
-    slideshowDelayLayout->addWidget(m_slideshowDelay);
-    slideshowDelayLayout->addStretch();
-    
-    dirlistLayout->addWidget(m_dirlist);
-    dirlistLayout->addLayout(dirlistButtons);
-    dirlistButtons->addWidget(m_addDir);
-    dirlistButtons->addWidget(m_removeDir);
-    dirlistButtons->addStretch();
-    slideshowLayout->addLayout(dirlistLayout);
-    slideshowLayout->addLayout(slideshowDelayLayout);
-    
+
     // preview
-    QLabel *monitor = new QLabel(main);
     QString monitorPath = KStandardDirs::locate("data",  "kcontrol/pics/monitor.png");
     
     // Size of monitor image: 200x186
@@ -486,56 +417,24 @@ BackgroundDialog::BackgroundDialog(const QSize &res,
     QRect previewRect(23, int(14 * previewRatio), 151, int(115 * previewRatio));
     m_preview_renderer.setSize(previewRect.size());
     
-    monitor->setPixmap(QPixmap(monitorPath).scaled(monitorSize));
-    monitor->setWhatsThis(i18n(
+    m_monitor->setPixmap(QPixmap(monitorPath).scaled(monitorSize));
+    m_monitor->setWhatsThis(i18n(
         "This picture of a monitor contains a preview of "
         "what the current settings will look like on your desktop."));
-    m_preview = new QLabel(monitor);
+    m_preview = new QLabel(m_monitor);
     m_preview->setScaledContents(true);
     m_preview->setGeometry(previewRect);
-    
-    // get new stuff
-    QHBoxLayout *newStuffLayout = new QHBoxLayout;
-    m_newStuff = new QPushButton(i18n("&New wallpaper..."), main);
+
     connect(m_newStuff, SIGNAL(clicked()), this, SLOT(getNewStuff()));
-    newStuffLayout->addStretch();
-    newStuffLayout->addWidget(m_newStuff);
-    newStuffLayout->addStretch();
 
-    //icon settings
-    QLabel *showIconsLabel = new QLabel(i18n("&Show Icons"), main);
-    QLabel *alignToGridLabel = new QLabel(i18n("&Align To Grid"), main);
-    m_showIcons = new QCheckBox(main);
-    m_alignToGrid = new QCheckBox(main);
-    showIconsLabel->setBuddy(m_showIcons);
-    alignToGridLabel->setBuddy(m_alignToGrid);
-    iconLayout->addWidget(showIconsLabel);
-    iconLayout->addWidget(m_showIcons);
-    iconLayout->addWidget(alignToGridLabel);
-    iconLayout->addWidget(m_alignToGrid);
-    iconLayout->addStretch();
-    
-    rightLayout->addWidget(monitor);
-    rightLayout->addStretch();
-    rightLayout->addLayout(newStuffLayout);
-    rightLayout->addStretch();
-    
-    backgroundLayout->addLayout(leftLayout, 1);
-    backgroundLayout->addLayout(rightLayout);
-
-    layout->addLayout(backgroundLayout);
-    layout->addLayout(iconLayout);
-    
-    main->setLayout(layout);
-    
     qRegisterMetaType<QImage>("QImage");
     connect(&m_preview_timer, SIGNAL(timeout()), this, SLOT(updateSlideshowPreview()));
     connect(&m_preview_renderer, SIGNAL(done(int, const QImage &)), 
             this, SLOT(previewRenderingDone(int, const QImage &)));
     connect(this, SIGNAL(finished(int)), this, SLOT(cleanup()));
-    
+
     setMainWidget(main);
-    
+
     reloadConfig(config);
 }
 
@@ -621,12 +520,26 @@ void BackgroundDialog::getNewStuff()
     }
 }
 
+void BackgroundDialog::showFileDialog()
+{
+    m_dialog = new KFileDialog(KUrl(), "*.png *.jpeg *.jpg *.svg *.svgz", this);
+    m_dialog->setOperationMode(KFileDialog::Opening);
+    m_dialog->setCaption(i18n("Select Wallpaper Image File"));
+    m_dialog->setModal(false);
+    m_dialog->show();
+    m_dialog->raise();
+    m_dialog->activateWindow();
+
+    connect(m_dialog, SIGNAL(okClicked()), this, SLOT(browse()));
+}
+
 void BackgroundDialog::browse()
 {
-    QString wallpaper = KFileDialog::getOpenFileName(KUrl(), 
-                                                     "*.png *.jpeg *.jpg *.svg *.svgz",
-                                                     this, 
-                                                     i18n("Select a wallpaper image file"));
+    QString wallpaper = m_dialog->selectedFile();
+    disconnect(m_dialog, SIGNAL(okClicked()), this, SLOT(browse()));
+
+    m_dialog->deleteLater();
+
     if (wallpaper.isEmpty()) {
         return;
     }
@@ -795,3 +708,8 @@ void BackgroundDialog::cleanup()
 {
     m_preview_timer.stop();
 }
+
+void BackgroundDialog::removeBackground(const QString &path)
+{
+    m_model->removeBackground(path);
+}
