@@ -48,6 +48,7 @@
 #include "krunner_interface.h"
 #include "ksmserver_interface.h"
 #include "screensaver_interface.h"
+#include "ksmserver_interface.h"
 
 #include "backgrounddialog.h"
 
@@ -87,19 +88,32 @@ DefaultDesktop::~DefaultDesktop()
 
 void DefaultDesktop::init()
 {
-    reloadConfig();
+    reloadConfig(true);
     Containment::init();
 }
 
-void DefaultDesktop::nextSlide()
+void DefaultDesktop::nextSlide(bool skipUpdates)
 {
     if (++m_currentSlide >= m_slideFiles.size()) {
         m_currentSlide = 0;
     }
 
     if (m_slideFiles.size() > 0) {
+        // do not change to the same background (same path)
+        if (m_wallpaperPath == m_slideFiles[m_currentSlide]) {
+            if (m_slideFiles.size() == 1) {
+                return;
+            }
+            // try next one, they can't be the same (at least the same path)
+            if (++m_currentSlide >= m_slideFiles.size()) {
+                m_currentSlide = 0;
+            }
+        }
+
         m_wallpaperPath = m_slideFiles[m_currentSlide];
-        updateBackground();
+        if (!skipUpdates) {
+            updateBackground();
+        }
     }
 }
 
@@ -110,17 +124,14 @@ QSize DefaultDesktop::resolution() const
 
 void DefaultDesktop::constraintsUpdated(Plasma::Constraints constraints)
 {
-    Q_UNUSED(constraints);
-
     if (constraints & ScreenConstraint) {
         if (screen() == 0 && !s_icons) {
             s_icons = new IconLoader(this);
-            s_icons->init(this);
         }
     }
 
     if (constraints & Plasma::SizeConstraint) {
-        m_renderer.setSize(resolution()); 
+        m_renderer.setSize(resolution());
         updateBackground();
     }
 
@@ -128,7 +139,6 @@ void DefaultDesktop::constraintsUpdated(Plasma::Constraints constraints)
         // we need to update the menu items that have already been created
         bool locked = isImmutable();
         m_appletBrowserAction->setVisible(!locked);
-        m_setupDesktopAction->setVisible(!locked);
         if (locked) {
             m_lockDesktopAction->setIcon(KIcon("object-unlocked"));
             m_lockDesktopAction->setText(i18n("Unlock Widgets"));
@@ -143,12 +153,12 @@ void DefaultDesktop::configure()
 {
     KConfigGroup cg = config();
     if (m_configDialog == 0) {
-        const QSize resolution = 
+        const QSize resolution =
             QApplication::desktop()->screenGeometry(screen()).size();
         m_configDialog = new BackgroundDialog(resolution, cg, 0);
-        connect(m_configDialog, SIGNAL(okClicked()), 
+        connect(m_configDialog, SIGNAL(okClicked()),
                 this, SLOT(applyConfig()));
-        connect(m_configDialog, SIGNAL(applyClicked()), 
+        connect(m_configDialog, SIGNAL(applyClicked()),
                 this, SLOT(applyConfig()));
     }
     else {
@@ -162,24 +172,26 @@ void DefaultDesktop::applyConfig()
 {
     Q_ASSERT(m_configDialog);
     m_configDialog->saveConfig(config());
-    config().config()->sync();
-    
+    emit configNeedsSaving();
+
     reloadConfig();
 }
 
-void DefaultDesktop::reloadConfig()
+void DefaultDesktop::reloadConfig(bool skipUpdates)
 {
     qsrand(QTime(0,0,0).secsTo(QTime::currentTime()));
 
     KConfigGroup cg = config();
 
-    m_wallpaperPath = cg.readEntry("wallpaper",
-            KStandardDirs::locate("wallpaper", "EOS/contents/images/1920x1200.jpg"));
+    // If no wallpaper is set, a default will be set in updateBackground()
+    // which is called as soon as constraints are updated.
+    QString oldWallpaperPath(m_wallpaperPath);
+    m_wallpaperPath = cg.readEntry("wallpaper", "");
+    if (!m_wallpaperPath.isEmpty()) {
+        kDebug() << "Using configured wallpaper" << m_wallpaperPath;
+    }
 
-    kDebug() << "Default would be" << KStandardDirs::locate("wallpaper", "EOS/contents/images/1920x1200.jpg");
-    kDebug() << "but we're loading" << m_wallpaperPath << "instead";
-    
-    m_backgroundMode = cg.readEntry("backgroundmode", 
+    m_backgroundMode = cg.readEntry("backgroundmode",
         (int) BackgroundDialog::kStaticBackground);
 
     // used in both modes, so read it no matter which mode we are in
@@ -187,15 +199,17 @@ void DefaultDesktop::reloadConfig()
     m_wallpaperColor = cg.readEntry("wallpapercolor", QColor(Qt::black));
 
     if (m_backgroundMode == BackgroundDialog::kStaticBackground) {
-
         m_slideshowTimer.stop();
-        updateBackground();
-    }
-    else {
+        // Only set the wallpaper if constraints have been loaded
+        // and background image has changed
+        if (!skipUpdates && screen() != -1 && oldWallpaperPath != m_wallpaperPath) {
+            updateBackground();
+        }
+    } else {
         QStringList dirs = cg.readEntry("slidepaths", QStringList());
         QStringList filters;
         filters << "*.png" << "*.jpeg" << "*.jpg" << "*.svg" << "*.svgz";
-        
+
         m_slideFiles.clear();
 
         for (int i = 0; i < dirs.size(); ++i) {
@@ -225,10 +239,10 @@ void DefaultDesktop::reloadConfig()
             m_slideshowTimer.start();
         }
         m_currentSlide = -1;
-        nextSlide();
+        nextSlide(true);
     }
 
-    if(s_icons) {
+    if (s_icons) {
         s_icons->setShowIcons(cg.readEntry("showIcons",true));
         s_icons->setGridAligned(cg.readEntry("alignToGrid",true));
     }
@@ -236,11 +250,27 @@ void DefaultDesktop::reloadConfig()
 
 void DefaultDesktop::updateBackground()
 {
-    m_current_renderer_token = 
+    if (m_wallpaperPath.isEmpty()) {
+        QString defaultPath = QString("EOS/contents/images/%1x%2.jpg");
+
+        QString testPath = defaultPath.arg(geometry().width()).arg(geometry().height());
+        m_wallpaperPath = KStandardDirs::locate("wallpaper", testPath);
+
+        if (m_wallpaperPath.isEmpty()) {
+            kDebug() << "Trying" << defaultPath.arg(1920).arg(1200);
+            m_wallpaperPath = KStandardDirs::locate("wallpaper", defaultPath.arg(1920).arg(1200));
+        }
+
+        kDebug() << "Setting wallpaper to default" << m_wallpaperPath;
+        emit configNeedsSaving();
+    }
+
+    m_current_renderer_token =
         m_renderer.render(m_wallpaperPath,
                           m_wallpaperColor,
                           (Background::ResizeMethod)m_wallpaperPosition,
-                          Qt::SmoothTransformation);                       
+                          Qt::SmoothTransformation);
+    suspendStartup( true ); // during KDE startup, make ksmserver until the wallpaper is ready
 }
 
 void DefaultDesktop::updateBackground(int token, const QImage &img)
@@ -248,6 +278,7 @@ void DefaultDesktop::updateBackground(int token, const QImage &img)
     if (m_current_renderer_token == token) {
         m_bitmapBackground = QPixmap::fromImage(img);
         update();
+        suspendStartup( false );
     }
 }
 
@@ -265,6 +296,17 @@ void DefaultDesktop::runCommand()
     }
 }
 
+void DefaultDesktop::suspendStartup(bool suspend)
+{
+    org::kde::KSMServerInterface ksmserver("org.kde.ksmserver", "/KSMServer", QDBusConnection::sessionBus());
+    const QString startupID("desktop wallaper");
+    if (suspend) {
+        ksmserver.suspendStartup(startupID);
+    } else {
+        ksmserver.resumeStartup(startupID);
+    }
+}
+
 void DefaultDesktop::lockScreen()
 {
     if (!KAuthorized::authorizeKAction("lock_screen")) {
@@ -313,6 +355,9 @@ QList<QAction*> DefaultDesktop::contextActions()
 
         m_separator = new QAction(this);
         m_separator->setSeparator(true);
+
+        m_separator2 = new QAction(this);
+        m_separator2->setSeparator(true);
     }
 
     QList<QAction*> actions;
@@ -326,10 +371,12 @@ QList<QAction*> DefaultDesktop::contextActions()
 
     actions.append(m_separator);
 
-    //icon actions
-    actions << s_icons->contextActions();
+    if (s_icons && s_icons->showIcons()) {
+        //icon actions
+        actions << s_icons->contextActions();
+        actions.append(m_separator2);
+    }
 
-    actions.append(m_separator);
     actions.append(m_lockDesktopAction);
 
     if (KAuthorized::authorizeKAction("lock_screen")) {
@@ -387,12 +434,10 @@ void DefaultDesktop::paintInterface(QPainter *painter,
     // blit the background (saves all the per-pixel-products that blending does)
     painter->setCompositionMode(QPainter::CompositionMode_Source);
 
-    if (!m_bitmapBackground.isNull()) {
-        // for pixmaps we draw only the exposed part (untransformed since the
-        // bitmapBackground already has the size of the viewport)
-        painter->drawPixmap(option->exposedRect, m_bitmapBackground, option->exposedRect);
-        //kDebug() << "draw pixmap of background to" << option->exposedRect;
-    }
+    // for pixmaps we draw only the exposed part (untransformed since the
+    // bitmapBackground already has the size of the viewport)
+    painter->drawPixmap(option->exposedRect, m_bitmapBackground, option->exposedRect);
+    //kDebug() << "draw pixmap of background to" << option->exposedRect;
 
     // restore transformation and composition mode
     painter->restore();
