@@ -23,15 +23,6 @@
 #include "plasma/plasma.h"
 #include "plasma/view.h"
 
-class QPixmap;
-
-namespace Plasma
-{
-    class Svg;
-    class Corona;
-    class AppletBrowser;
-}
-
 class DashboardView;
 
 class DesktopView : public Plasma::View
@@ -46,7 +37,6 @@ public slots:
     void zoomIn();
     void zoomOut();
     void showAppletBrowser();
-    void appletBrowserDestroyed();
     void toggleDashboard();
     void adjustSize();
 
@@ -55,7 +45,6 @@ protected:
 
 private:
     Plasma::ZoomLevel m_zoomLevel;
-    Plasma::AppletBrowser *m_appletBrowser;
     DashboardView *m_dashboard;
 };
 
