@@ -31,12 +31,19 @@
 #include <plasma/plasma.h>
 #include <plasma/svg.h>
 
+#include "plasmaapp.h"
+
 PanelView::PanelView(Plasma::Containment *panel, QWidget *parent)
     : Plasma::View(panel, parent)
 {
     Q_ASSERT(qobject_cast<Plasma::Corona*>(panel->scene()));
     updatePanelGeometry();
 
+    if (containment()) {
+        connect(containment(), SIGNAL(showAddWidgets()), this, SLOT(showAppletBrowser()));
+        connect(panel, SIGNAL(destroyed(QObject*)), this, SLOT(deleteLater()));
+    }
+
     connect(panel, SIGNAL(geometryChanged()), this, SLOT(updatePanelGeometry()));
     kDebug() << "Panel geometry is" << panel->geometry();
 
@@ -111,32 +118,47 @@ void PanelView::updatePanelGeometry()
     setGeometry(geom);
 }
 
+void PanelView::showAppletBrowser()
+{
+    PlasmaApp::self()->showAppletBrowser(containment());
+}
+
 void PanelView::updateStruts()
 {
     NETExtendedStrut strut;
 
+    QRect thisScreen = QApplication::desktop()->screenGeometry(containment()->screen());
+    QRect wholeScreen = QApplication::desktop()->screenGeometry();
+
+    // extended struts are to the combined screen geoms, not the single screen
+    int leftOffset = wholeScreen.x() - thisScreen.x();
+    int rightOffset = wholeScreen.right() - thisScreen.right();
+    int bottomOffset = wholeScreen.bottom() - thisScreen.bottom();
+    int topOffset = wholeScreen.top() - thisScreen.top();
+    kDebug() << "screen l/r/b/t offsets are:" << leftOffset << rightOffset << bottomOffset << topOffset;
+
     switch (location())
     {
         case Plasma::TopEdge:
-            strut.top_width = height();
+            strut.top_width = height() + topOffset;
             strut.top_start = x();
             strut.top_end = x() + width() - 1;
             break;
 
         case Plasma::BottomEdge:
-            strut.bottom_width = height();
+            strut.bottom_width = height() + bottomOffset;
             strut.bottom_start = x();
             strut.bottom_end = x() + width() - 1;
             break;
 
         case Plasma::RightEdge:
-            strut.right_width = width();
+            strut.right_width = width() + rightOffset;
             strut.right_start = y();
             strut.right_end = y() + height() - 1;
             break;
 
         case Plasma::LeftEdge:
-            strut.left_width = width();
+            strut.left_width = width() + leftOffset;
             strut.left_start = y();
             strut.left_end = y() + height() - 1;
             break;
