@@ -25,6 +25,8 @@
 #include <QItemDelegate>
 #include <QListWidgetItem>
 #include <QList>
+#include <QPainterPath>
+#include <QRectF>
 
 class KCModuleInfo;
 
@@ -34,6 +36,12 @@ class ModuleIconItemDelegate : public QItemDelegate
 		ModuleIconItemDelegate(QObject *parent);
 		
 		void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
+
+	private:
+		// Method taken from KFileItemDelegate. Check whether it has been moved to
+		// kdefx/kdrawutil.cpp as the comment says on Fredrik's code. If so, remove
+		// this code (duplication), and use the library one.
+		QPainterPath roundedRectangle(const QRectF &rect, qreal radius) const;
 };
 
 /**
@@ -44,9 +52,9 @@ class ModuleIconItem : public QListWidgetItem
 {
 
 public:
-  ModuleIconItem( QListWidget *parent, const KCModuleInfo& module );
+	ModuleIconItem( QListWidget *parent, const KCModuleInfo& module );
 	
-  ModuleIconItem( QListWidget *parent, const QString &text, const QString &imageName );
+	ModuleIconItem( QListWidget *parent, const QString &text, const QString &imageName );
 
 	/**
 	 * Update the icon to either be enabled or not.
@@ -59,7 +67,6 @@ public:
 private:
 	void setSize();
 
-	int currentState;
 	QString imageName;
 };
 
